(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    777937,      26440]*)
(*NotebookOutlinePosition[    940942,      30305]*)
(*  CellTagsIndexPosition[    934834,      30119]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["TH\[Exists]OREM\[ForAll]",
    FontColor->RGBColor[0, 0, 1]],
  "\nA Short Demo"
}], "Subtitle",
  TextAlignment->Center,
  TextJustification->0,
  CellTags->"title"],

Cell[TextData[StyleBox["Bruno Buchberger, C. Dupre', T. Jebelean, K. Kriftner\
\nK. Nakagawa, D. Vasaru,  W. Windsteiger",
  FontSlant->"Plain"]], "Subsubtitle",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "Research Institute for Symbolic Computation\nJohannes Kepler University, \
A4040 Linz, Austria\n                ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "@",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ".org   "
}], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  StyleBox["Copyright Bruno Buchberger and ",
    FontWeight->"Bold"],
  StyleBox["Theorema",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" Working Group 1999",
    FontWeight->"Bold"],
  ": Copying, storing in data bases etc. is granted under the condition that \
the file is kept unchanged and this copyright note is included in the copy. \
Usage of the material contained in this talk has be cited appropriately."
}], "Text"],

Cell[TextData[{
  StyleBox["Version",
    FontWeight->"Bold"],
  ": 2000-1-22"
}], "Text"],

Cell[TextData[{
  "\.03",
  StyleBox["Acknowledgements",
    FontWeight->"Bold"],
  ": This research is partially supported by the Austrian Science Foundation \
(FWF-SFB-project FO-1302) and the Upper Austrian Government  (project \
``PROVE'')."
}], "Text"],

Cell[CellGroupData[{

Cell["The Purpose of this Demo", "Subsection",
  Background->None],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " system is a system for proving, solving, and simplifying mathematical \
formulae. It is programmed in the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "language, version 3.0 or later, and also heavily uses the front-end of ",
  StyleBox["Mathematica. Theorema ",
    FontSlant->"Italic"],
  "can therefore be used on all machines on which Mathematica, version 3.0 or \
later, is installed. "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " is being developed by the ",
  StyleBox["TH\[Exists]OREM\[ForAll] Working Group",
    FontSlant->"Plain"],
  " at the RISC institute under the direction of Bruno Buchberger. The \
current members of the ",
  StyleBox["TH\[Exists]OREM\[ForAll] Working Group",
    FontSlant->"Plain"],
  " are B. Buchberger, C. Dupre, F.Kriftner, T. Jebelean, K. Nakagawa, D. \
Vasaru, and W.Windsteiger. "
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " demo presented in this notebook demonstrates the most important \
functionalities of  ",
  StyleBox["Theorema Version 1.0 (1999). ",
    FontSlant->"Italic"],
  "I used this demo 1999 in a couple of talks on ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " at various occasions. The varying parts of these talks, emphasizing \
various different aspects of the system,  are contained in extra files (which \
will soon be available over the web) and refer to this file for the demo \
part."
}], "Text"],

Cell[TextData[{
  "This file can be read if you have Mathematica installed on your machine. \
If not, you can read the postscript version ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999.ps of this file. "
}], "Text"],

Cell[TextData[{
  "If you are an alpha tester of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " you can execute and play with the commands given in this file. Currently, \
we do not accept any more alpha testers. The beta version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " will most probably be released in Fall 2000. If you want to be informed \
about the release, i.e. if you want to become a beta tester, please, write to \
",
  StyleBox["Theorema@Theorema.org.",
    FontSlant->"Italic"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Greatest Common Divisor", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["Start Theorema", "Subsubsection",
  Background->None],

Cell[TextData[{
  "The following command loads the basic ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " files. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Needs["\<Theorema`\>"]\)], "Input",
  Background->None],

Cell[BoxData[
    \("You can specify your personal preferences in a file `Setup.m` in the \
directory (folder) \"Theorema -> User\" in your private Theorema \
directory!"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "The subsequent commands load a version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "'s predicate logic prover and initializes certain options. All this is \
necessary for running the example in this section."
}], "Text"],

Cell[BoxData[
    \(\(InitializeGlobals[
        Evaluator \[Rule] EvaluateFromInnermost];\)\)], "Input",
  Background->None],

Cell[BoxData[
    \(Use[\[LeftAngleBracket]Built\[Dash]in["\<Quantifiers\>"], 
        Built\[Dash]in["\<Connectives\>"], 
        Built\[Dash]in["\<Numbers\>"]\[RightAngleBracket]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(SetGlobals[TraceLevel -> 0, SearchDepth -> 100, 
      DebugLevel -> 0]; $RecursionLimit = 1024; 
    Needs["\<Theorema`Provers`UserProvers`PCS`\>"]; \ Off[General::spell]; 
    Off[General::spell1]; $TmaQRTarget = {"\<kb\>", "\<goal\>"}; \
$TmaProofPresentation = "\<SuccessBranch\>";\)], "Input",
  Background->None,
  CellTags->{"4-ary limit", "distance of sum", "maximum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell[TextData[{
  "This examples shows how, in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", the entire cycle of \"doing mathematics\", i.e."
}], "Text"],

Cell["defining a new notion", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["formulating conjectures about the notion", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["proving the conjectures", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
using proved theorems as \"methods\" (\"algorithms\") for particular inputs\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["can be fully supported.", "Text"],

Cell[TextData[{
  "In particular, we emphasize the unique feature of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " that, without leaving the system, mathematical formulae can be both \
viewed as statements (e.g. definitions or theorems that need to be proved) \
and also as algorithms (that can be executed on particular inputs, in case \
the statements are \"algorithmic\")."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition", "Subsubsection",
  Background->None],

Cell[TextData[{
  "Here, is a definition of the notion \"greatest common divisor\", which can \
be made known to ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " by typing it into an input cell:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", \("\<greatest common divisor\>", 
      any[m, n], \n\t
      gcd[m, n] = \(\(max\+\(d = 1, \[Ellipsis], 
                  m\)\)\+\(\((d \[VerticalBar] 
                    m)\) \[And] \((d \[VerticalBar] n)\)\)\) d\), 
      "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit of sum", "Divides Sum", "greatest common divisor", 
    "Greatest Common Divisor"}],

Cell[TextData[{
  "This formula can be viewed as a logical statement that is true for all ",
  StyleBox["m, n ",
    FontSlant->"Italic"],
  "(in the universe of natural numbers, which we do not specify explicitly \
here, i.e. we consider the domain of natural numbers as the \"universe of \
discourse\"). However, it can also be viewed as a statement that describes \
how, for arbitrary ",
  StyleBox["m, n",
    FontSlant->"Italic"],
  ", gcd[",
  StyleBox["m,n",
    FontSlant->"Italic"],
  "] can be computed. If we want to use this formula in this way for \
computing, say, gcd[24,32] we enter:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[24, 32], 
      using \[Rule] Definition["\<greatest common divisor\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(8\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that by setting the option 'using' to 'Definition[\"greatest common \
divisor\"]' the system is told to use, as its only knowledge - except some \
built-in knowledge about the maximum quantifier and the like - the above \
definition. (Built-in knowledge can be specified by the 'Use' command, see \
the subsubsection on Starting ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " above)."
}], "Text"],

Cell["\<\
Here are some other calls of 'gcd' together with their timings:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[24, 32], 
        using \[Rule] Definition["\<greatest common divisor\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({0.110000000000127329`\ Second, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[240, 320], 
        using \[Rule] Definition["\<greatest common divisor\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({0.15999999999985448`\ Second, 80}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[2400, 3200], 
        using \[Rule] Definition["\<greatest common divisor\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({0.820000000000163709`\ Second, 800}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[24000, 32000], 
        using \[Rule] Definition["\<greatest common divisor\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({8.01000000000021827`\ Second, 8000}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As expected, the computing time roughly grows linearly. (The absolute \
timings are quite high. This is so because the formulae are \"interpreted\" \
not \"compiled\". In this version, ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " is a research and teaching tool and not a tool to be used for serious \
computations. A later version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " will make the execution of formulae much faster.)"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Euclid's Theorem", "Subsubsection",
  Background->None],

Cell["\<\
Now, somebody like Euclid (300 B.C) may come up with the following, \
nontrivial, conjecture about the notion '\[VerticalBar]' ('divides'):\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<divides difference\>", 
      any[d, m, 
        n], \n\t\((d \[VerticalBar] m \[And] 
            d \[VerticalBar] 
              n)\)\ \ \ \ \ \ \ \ \ \[DoubleLongRightArrow]\ \ \ \ \ \ \ \((d \
\[VerticalBar] m - n)\)\), "]"}]], "Input",
  Background->None,
  CellTags->{"2-ary limit of sum", "divides difference", "Divides Sum"}],

Cell["from which the following variant ", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<common divisors and difference\>", 
      any[d, m, 
        n], \n\t\((d \[VerticalBar] m \[And] 
            d \[VerticalBar] 
              n)\)\ \ \ \ \ \ \ \ \ \[DoubleLongLeftRightArrow]\ \ \ \ \ \ \ \
\((d \[VerticalBar] m - n\ \ \  \[And] \ \ \ \ d \[VerticalBar] n)\)\), 
      "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit of sum", "common divisors and difference", 
    "divides difference", "Divides Sum"}],

Cell["and also the following theorem on 'gcd'", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", \("\<Euclid's Theorem\>", any[d, m, n], \n\t
      gcd[m, n] = \[LeftDoubleBracketingBar]gcd[m - n, n] \[DoubleLeftArrow] 
            m > n, \n\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ gcd[m, 
              n - m] \[DoubleLeftArrow] 
            n > m, \n\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ m\
\[RightDoubleBracketingBar]\), "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit of sum", "divides difference", "Divides Sum", 
    "Euclid's Theorem"}],

Cell[TextData[{
  "easily follow. (In ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", the symbol '\[LeftDoubleBracketingBar]...\[RightDoubleBracketingBar]' is \
used for the case statement.)"
}], "Text"],

Cell["\<\
The benefit we get from the mathematical knowledge described in this \
proposition is enormous:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[24, 32], 
        using \[Rule] Proposition["\<Euclid's Theorem\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({0.160000000000309228`\ Second, 8}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[240, 320], 
        using \[Rule] Proposition["\<Euclid's Theorem\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({0.110000000000127329`\ Second, 80}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[2400, 3200], 
        using \[Rule] Proposition["\<Euclid's Theorem\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({0.109999999999672581`\ Second, 800}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[gcd[24000, 32000], 
        using \[Rule] Proposition["\<Euclid's Theorem\>"]] // 
      Timing\)], "Input",
  Background->None],

Cell[BoxData[
    \({0.15999999999985448`\ Second, 8000}\)], "Output"]
}, Open  ]],

Cell["\<\
We see that, for drastically increasing input, the computing time only \
increases mildly.\
\>", "Text"],

Cell["\<\
This examples shows the essence of mathematics and the value of mathematical \
knowledge: Spend your time for thinking once about why a certain knowledge is \
true (i.e. spend your time once for proving), then you can save time \
infinitely many times.\
\>", "Text",
  CellFrame->True],

Cell["Now the question is: Can we automate proving?", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["An Automated Proof of Euclid's Theorem", "Subsubsection",
  Background->None],

Cell[TextData[{
  "We now demonstrate, how ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " can be used not only for computing but also for proving. We show this in \
the example of the essential proposition on which Euclid's Theorem is based:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<divides difference\>\"", ",", \(any[d, m, n]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((d \[VerticalBar] m \[And] 
                    d \[VerticalBar] 
                      n)\)\ \ \ \ \ \ \ \ \ \[DoubleLongRightArrow]\ \ \ \ \ \
\ \ \((d \[VerticalBar] m - n\ \ \  \[And] \ \ \ \ d \[VerticalBar] n)\)\), 
              "\"\<divdiff\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"divides difference"],

Cell["\<\
Of course, in order to prove this, we need the definition of \
'\[VerticalBar]':\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<divides\>\"", ",", \(any[d, m]\), ",", "\n", "\t", GridBox[{
            {\(\((d \[VerticalBar] 
                    m)\)\ \ \ \ \ \ \ \ \ \ \ \ \[DoubleLongLeftRightArrow]\ \
\ \ \ \ \ \ \ \ \ \(\[Exists] \+f\((\((d\ f)\) = m)\)\)\), "\"\<div:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{"divides", "divides difference"}],

Cell["\<\
and also the fundamental knowledge about the interplay of multiplication and \
subtraction:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distributivity\>\"", ",", \(any[d, u, v, m, n]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\((d\ u = m)\) \[And] \((d\ v = 
                        n)\))\)\ \ \ \ \ \ \ \ \ \ \ \ \
\[DoubleLongRightArrow]\ \ \ \ \ \ \ \ \ \((\ d \((u - v)\) = m - n)\)\), 
              "\"\<distr\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{"distributivity", "divides", "divides difference"}],

Cell[TextData[{
  "Now, for proving the proposition, all we have to do in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " is to call one of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " provers (whose name is \"PC\" for \"prove by applying Proof and \
Computation steps\", which is a new prover for predicate logic formulae \
developed by the author):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[
      Proposition["\<divides difference\>"], \n\t\ using \[Rule] \
\[LeftAngleBracket]Definition["\<divides\>"], 
          Proposition["\<distributivity\>"]\[RightAngleBracket], \n\t\ by \
\[Rule] PC]\)], "Input",
  Background->None],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell["i.e. we just have to tell the system ", "Text"],

Cell[TextData[{
  "the ",
  StyleBox["proof goal ",
    FontSlant->"Italic"],
  "'Proposition[\"divides difference\"]', "
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "the ",
  StyleBox["knowledge base",
    FontSlant->"Italic"],
  "  'Definition[\"divides\"]' and 'Proposition[\"distributivity\"]' which we \
allow the prover to use in the proof, "
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "and the particular ",
  StyleBox["prover",
    FontSlant->"Italic"],
  " 'PC' we want to try on this proof problem."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers, we have stored this notebook  under the name \
",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo- 1999-Proof-GDC.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-Proof-GDC.ps.) Note that every single (English) word and \
every formula in this proof is generated automatically by the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " prover 'PC' (i.e. without any further help and interaction by the user). \
Also, we hope you will appreciate that the proof text is very natural and \
resembles the style a (good) mathematician would present the proof.  If you \
don't want to see all the details of the proof, you can use the nested cell \
brackets at the right-hand margin for \"closing\" (making invisible) certain \
parts of the proof. Of course, the closed parts are still there, they just \
are not shown any more. You can re-open closed cells by clicking again into \
the respective bracket."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Analysis", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell[TextData[{
  "This examples shows how, in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", a typical portion of mathematical text can be formalized and the \
respective proofs can be generated automatically."
}], "Text"],

Cell["\<\
It is interesting to note in this example that, in contrast to wide-spread \
but wrong opinion, formal proving does not mean \"proving from first \
principles\", that formal proving does not necessarily imply that the proofs \
generated are long or \"hard to read\", and that amazingly small knowledge \
bases suffice for the proof of interesting theorems in advanced areas of \
mathematics. This is not amazing for people who understand that good \
mathematics is well structured in \"layers\" of knowledge about the various \
mathematical notions in the same way as good software is well structured in \
layers of  algorithms (modules).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Clear", "Subsubsection",
  Background->None],

Cell["\<\
In this section we do not want to use any \"built-in\" knowledge. For this, \
we just say\
\>", "Text"],

Cell[BoxData[
    \(Use[{}]\)], "Input",
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell["Limit of Sum: Preliminaries", "Subsubsection",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[TextData[{
  "We show the example of a proof in elementary analysis. Here is the usual \
definition of the predicate 'limit[",
  StyleBox["f,a",
    FontSlant->"Italic"],
  "]' ('",
  StyleBox["a",
    FontSlant->"Italic"],
  " is the limit of the sequence ",
  StyleBox["f",
    FontSlant->"Italic"],
  "'):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], 
      "[", \("\<2-ary limit\>", \n\t\[ForAll] \+\(f, a, \[Epsilon], N\)limit[
            f, a]\[DoubleLongLeftRightArrow]\ \(\(\[ForAll] \
\+\[Epsilon]\)\+\(\[Epsilon] > 0\)\(\[Exists] \+N\(\(\[ForAll] \+n\)\+\(n \
\[GreaterEqual] N\)\[LeftBracketingBar]f[n] - 
                      a\[RightBracketingBar] < \[Epsilon]\)\)\)\), 
      "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(limit\)\" is similar to \
existing symbol \"\!\(Limit\)\"."\)], "Message"]
}, Open  ]],

Cell["We want to prove the following theorem:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<2-ary limit of sum\>\"", ",", \(any[f, a, g, b]\), ",", "\n", "\t",
         "\n", "\t", GridBox[{
            {\(\((limit[f, a] \[And] limit[g, b])\)\[DoubleLongRightArrow]
                limit[f + g, a + b]\), \(\(\ \ \ \ \ \ \ \)\("\<l2+\>"\)\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell["\<\
In fact, with a stronger version of the prover 'PC', namely 'PCS' (see next \
section), we can produce a proof of this theorem completely automatically. \
However, here, we want to demonstrate how the proof can be built up in \
several \"layers\" that correspond to the layers naturally suggested by the \
\"alternating quantifiers\" in the definition of the limit notion. For this, \
we decompose the definition into several auxiliary definitions so that in \
each definition only one quantifier is introduced:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, \[Epsilon], N\)limit[f, a, \[Epsilon], 
                    N]\[DoubleLongLeftRightArrow]\(\(\[ForAll] \+n\)\+\(n \
\[GreaterEqual] N\)\[LeftBracketingBar]f[n] - 
                          a\[RightBracketingBar] < \[Epsilon]\)\), 
              "\"\<l4:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, \[Epsilon]\)limit[f, 
                    a, \[Epsilon]]\[DoubleLongLeftRightArrow]\(\[Exists] \+N 
                      limit[f, a, \[Epsilon], N]\)\), "\"\<l3:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a\)limit[f, 
                    a]\[DoubleLongLeftRightArrow]\(\(\[ForAll] \+\[Epsilon]\)\
\+\(\[Epsilon] > 0\)limit[f, a, \[Epsilon]]\)\), "\"\<l2:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell["\<\
Note that, in these definitions, \"4-ary limit\", \"l4:\" etc. are labels. \
They do not add to the logical meaning of the formulae but are introduced \
only for being able to refer easily to these formulae in proofs etc.\
\>", "Text"],

Cell[TextData[{
  "Making these layers in the definition explicit will not only help the 'PC' \
prover to find the proof without user interaction but we found, in teaching \
experiments with students, that breaking down such definitions according to \
the quantifier structure also helps in understanding notions introduced by \
alternating quantifiers. (Please, think about the intuitive and graphical \
meaning of each of these notions. For example, 'limit[f,a,\[Epsilon],N]' \
means that the sequence ",
  StyleBox["f",
    FontSlant->"Italic"],
  " stays closer to the value ",
  StyleBox["a",
    FontSlant->"Italic"],
  " than ",
  StyleBox["\[Epsilon] ",
    FontSlant->"Italic"],
  "from index ",
  StyleBox["N",
    FontSlant->"Italic"],
  " on.)"
}], "Text"],

Cell["\<\
Correspondingly, we also break down the proposition into three layers. Each \
of these propositions describes the effect of addition on sequences for the \
corresponding layer of the limit notion:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<4-ary limit of sum\>\"", 
        ",", \(any[f, a, \[Delta], M, g, b, \[Epsilon], N]\), ",", "\n", "\t",
         GridBox[{
            {\(\((limit[f, a, \[Delta], M] \[And] 
                    limit[g, b, \[Epsilon], N])\) \[Implies] \n\t
                limit[f + g, a + b, \[Delta] + \[Epsilon], max[M, N]]\), 
              "\"\<lim+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(max\)\" is similar to \
existing symbol \"\!\(Max\)\"."\)], "Message"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit of sum\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, \[Delta], g, b, \[Epsilon]\)\((\((limit[f, 
                          a, \[Delta]] \[And] 
                        limit[g, b, \[Epsilon]])\)\n\t\[DoubleLongRightArrow]
                    limit[f + g, a + b, \[Delta] + \[Epsilon]])\)\), 
              "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<2-ary limit of sum\>\"", ",", \(any[f, a, g, b]\), ",", "\n", "\t",
         "\n", "\t", GridBox[{
            {\(\((limit[f, a] \[And] limit[g, b])\)\[DoubleLongRightArrow]
                limit[f + g, a + b]\), \(\(\ \ \)\("\<l2+\>"\)\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proof of the Proposition on the 4-ary Limit", "Subsubsection",
  Background->None],

Cell["\<\
For proving Proposition[\"4-ary limit of sum\"], in addition to \
Definition[\"4-ary limit\"], the following knowledge is sufficient:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<sum of sequences\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((f + g)\)[x] = f[x] + g[x]\), "\"\<+:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of sum\>\"", 
        ",", \(any[x, y, a, b, \[Delta], \[Epsilon]]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\[LeftBracketingBar]\((x + y)\) - \((a + 
                            b)\)\[RightBracketingBar] < \((\[Delta] + \
\[Epsilon])\))\)\[DoubleLongLeftArrow]\n\t\((\[LeftBracketingBar]x - 
                          a\[RightBracketingBar] < \[Delta] \[And] \
\[LeftBracketingBar]y - b\[RightBracketingBar] < \[Epsilon])\)\), 
              "\"\<| + |\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<maximum\>\"", ",", \(any[m, M1, M2]\), ",", "\n", "\t", GridBox[{
            {\(m \[GreaterEqual] 
                  max[M1, M2] \[Implies] \((m \[GreaterEqual] M1 \[And] 
                    m \[GreaterEqual] M2)\)\), "\"\<\[GreaterEqual]max \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[TextData[{
  "We collect this knowledge in one little \"theory\" by entering the \
following ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " instruction:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<4-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<4-ary limit\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<sum of sequences\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<distance of sum\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<maximum\>\"", "]"}]}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell[TextData[{
  "Now the proof of Proposition[\"4-ary limit of sum\"] can be generated, \
fully automatically, by the following ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " call:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<4-ary limit of sum\>"], 
      using \[Rule] Theory["\<4-ary limit\>"], by \[Rule] PC]\)], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "max-greater", "maximum", "sum of sequences"}],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers, we have stored this notebook under the name \
",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999- Proof-4-ary-Limit.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-4-ary-Limit.ps.) "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proof of the Proposition on the 3-ary Limit", "Subsubsection",
  Background->None],

Cell["\<\
For proving Proposition[\"3-ary limit of sum\"], the following knowledge is \
sufficient:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<3-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Proposition["\<4-ary limit of sum\>"]\)},
            {\(Definition["\<3-ary limit\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{"2-ary limit", "3-ary limit"}],

Cell[TextData[{
  "Here is the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " call for generating the proof:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<3-ary limit of sum\>"], 
      using \[Rule] Theory["\<3-ary limit\>"], by \[Rule] PC\), 
      "]"}]], "Input",
  Background->None],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers, we have stored this notebook under the name \
",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof- 3-ary-Limit.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-3-ary-Limit.ps.) "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proof of the Proposition on the 2-ary Limit", "Subsubsection",
  Background->None],

Cell["\<\
For proving Proposition[\"2-ary limit of sum\"], the following property is \
necessary:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<positiveness\>\"", ",", "\n", "\t", GridBox[{
            {\(\(\[ForAll] \+a\)\+\(a > 0\)\((a/2)\) > 0\), "\"\</2>\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "3-ary continuity of sum: variant", "3-ary limit of sum: variant", 
    "positiveness"}],

Cell["\<\
Also, we need a slight variant of Proposition[\"3-ary limit of sum\"]:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<3-ary limit of sum: variant\>\"", ",", "\n", "\t", GridBox[{
            {\(\[ForAll] \+\(f, a, g, b, \[Epsilon]\)\((\((limit[f, 
                          a, \[Epsilon]/2] \[And] 
                        limit[g, 
                          b, \[Epsilon]/2])\)\n\t\[DoubleLongRightArrow]
                    limit[f + g, a + b, \[Epsilon]])\)\), "\"\<l3+\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->"3-ary limit of sum: variant"],

Cell["\<\
which could be proved easily from Proposition[\"3-ary limit of sum\"].\
\>", "Text"],

Cell["Now, the prerequisite knowledge base for the proof is:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<2-ary limit\>"]\)},
            {\(Proposition["\<3-ary limit of sum: variant\>"]\)},
            {\(Proposition["\<positiveness\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{"2-ary limit", "3-ary limit of sum: variant", "positiveness"}],

Cell[TextData[{
  "Here is the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " call for generating the proof:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], "[", \(Proposition["\<2-ary limit of sum\>"], 
      using \[Rule] Theory["\<2-ary limit\>"], by \[Rule] PC\), 
      "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "max-greater"}],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers, the notebook generated is available under \
the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo- 1999-Proof-2-ary-Limit.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-2-ary-Limit.ps.) "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuity of Product", "Subsubsection",
  Background->None],

Cell["\<\
Similarly, we could now start to prove theorems about the notion of \
cotinuity:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<2-ary continuity\>\"", ",", \(any[f, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(continuous[f, 
                  x]\[DoubleLongLeftRightArrow]\(\(\[ForAll] \+\[Epsilon]\)\+\
\(\[Epsilon] > 0\)continuous[f, x, \[Epsilon]]\)\), "\"\<c2:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "2-ary continuity", "4-ary limit", "continuity", "continuity 2-ary"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<3-ary continuity\>\"", ",", \(any[f, x, \[Epsilon]]\), ",", "\n", 
        "\t", GridBox[{
            {\(continuous[f, 
                  x, \[Epsilon]]\[DoubleLongLeftRightArrow]\(\(\[Exists] \+\
\[Delta]\)\+\(\[Delta] > 0\)continuous[f, x, \[Epsilon], \[Delta]]\)\), 
              "\"\<c3:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "3-ary continuity", "4-ary limit", "continuity", "continuity3", 
    "continuity 3-ary"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<4-ary continuity\>\"", ",", \(any[f, x, \[Epsilon], \[Delta]]\), 
        ",", "\n", "\t", GridBox[{
            {\(continuous[f, 
                  x, \[Epsilon], \[Delta]]\[DoubleLongLeftRightArrow]\(\(\
\[ForAll] \+y\)\+\(\[LeftBracketingBar]x - y\[RightBracketingBar] < \
\[Delta]\)\[LeftBracketingBar]f[x] - 
                        f[y]\[RightBracketingBar] < \[Epsilon]\)\), 
              "\"\<c4:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
    "continuity3", "continuity 3-ary", "continuity4", "continuity 4-ary"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<4-ary continuity of product\>\"", 
        ",", \(any[f1, x, \[Epsilon]1, \[Delta]1, 
          f2, \[Epsilon]2, \[Delta]2]\), ",", "\n", "\t", GridBox[{
            {\(\((continuous[f1, x, \[Epsilon]1, \[Delta]1] \[And] 
                    continuous[f2, 
                      x, \[Epsilon]2, \[Delta]2])\) \[Implies] \n\t
                continuous[f1*f2, 
                  x, \[Epsilon]1*\((\[Epsilon]2 + \[LeftBracketingBar]f2[
                              x]\[RightBracketingBar])\) + \
\[LeftBracketingBar]f1[x]\[RightBracketingBar]*\[Epsilon]2, 
                  min[\[Delta]1, \[Delta]2]]\), "\"\<cont[ * ]\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum", 
    "continuity 2-ary", "continuity 3-ary", "limit of sum"}],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(\\[Delta]1\)\" is \
similar to existing symbol \"\!\(\\[Epsilon]1\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(\\[Delta]2\)\" is \
similar to existing symbol \"\!\(\\[Epsilon]2\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(min\)\" is similar to \
existing symbol \"\!\(Min\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(General :: \"spell1\"\) will be suppressed \
during this calculation."\)], "Message",
  CellTags->"4-ary continuity of product"]
}, Open  ]],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<product of functions\>\"", ",", \(any[f, g, x]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((f*g)\)[x] = f[x]*g[x]\), "\"\<f*g\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{"fprod", "fsum", "product of functions"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<distance of product\>\"", 
        ",", \(any[a1, a2, b1, b2, \[Delta]1, \[Delta]2]\), ",", "\n", "\t", 
        GridBox[{
            {\(\((\[LeftBracketingBar]\((b1*b2)\) - \((a1*
                            a2)\)\[RightBracketingBar] < \((\[Delta]1*\((\
\[Delta]2 + \[LeftBracketingBar]b2\[RightBracketingBar])\) + \
\[LeftBracketingBar]b1\[RightBracketingBar]*\[Delta]2)\))\)\
\[DoubleLongLeftArrow]\n\t\((\[LeftBracketingBar]b1 - 
                          a1\[RightBracketingBar] < \[Delta]1 \[And] \
\[LeftBracketingBar]b2 - a2\[RightBracketingBar] < \[Delta]2)\)\), 
              "\"\<| * |\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{"distance of prod", "distance of product", "distance of sum"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Lemma",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<minimum\>\"", ",", \(any[m, M1, M2]\), ",", "\n", GridBox[{
            {\(m < min[M1, M2] \[Implies] \((m < M1 \[And] m < M2)\)\), 
              "\"\<min<\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "continuity", "continuity 2-ary", "continuity 3-ary", "continuity 4-ary", 
    "distance of sum", "fsum", "max-greater", "minimum", "min-lower"}],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<4-ary continuity of product\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<4-ary continuity\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<product of functions\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<distance of product\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<minimum\>\"", "]"}]}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "2-ary continuity", "3-ary continuity", "4-ary continuity", 
    "4-ary continuity of product", "4-ary limit", 
    "continuity of 4-ary product", "continuity prod 4-ary", 
    "continuity sum 4-ary", "cont sum", "distance of product", 
    "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
    "minimum", "product of functions"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<4-ary continuity of product\>"], 
      using \[Rule] Theory["\<4-ary continuity of product\>"], \n\t
      by \[Rule] PC]\)], "Input",
  Background->None],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers, we stored this notebook under the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo- 1999-Proof-4-ary-Continuity.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-2-ary-Continuity.ps.) "
}], "Text"],

Cell[TextData[{
  "We hope that now it should be clear how the proof of the 3-ary and 2-ary \
variants of the continuity proof could be generated in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example: Predicate Logic Proving by \"Prove - Compute - Solve\"\
\>", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell[TextData[{
  "This examples shows how, in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", with a much more powerful prover, which we call the \"PCS-prover\" \
(\"Prove, Compute, Solve\"), the proof of the above theorems and similar \
theorems can be generated completely automatically without inventing the \
intermediate 3-ary and 4-ary variants of the theorems. The PCS-method has \
been proposed recently by the author and is currently one of the main \
research topics within the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " project."
}], "Text"],

Cell["\<\
The essential new ingredient into the PCS-prover is a method by which a proof \
problem, after the PC-phase, is converted into the problem of  \"finding\" \
appropriate values that make certain formulae true under the assumptions in \
the current knowledge base and this problem is then solved by calling a \
solver (like, for example, Collins' method) for formulae of the theory of \
real closed fields or another appropriate solver depending on the type of the \
variables involved.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Limit of Sum: Preliminaries", "Subsubsection",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],

Cell["\<\
With the PCS-prover, for the proof of Proposition[\"2-ary limit of sum\"], it \
suffices to provide the following knowledge base:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<2-ary limit\>\"", ",", "\n", "\t", GridBox[{
            {
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<2-ary limit\>\"", "]"}]},
            {
              RowBox[{
                StyleBox["Definition",
                  FontWeight->"Bold"], "[", "\"\<sum of sequences\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<distance of sum\>\"", 
                "]"}]},
            {
              RowBox[{
                StyleBox["Lemma",
                  FontWeight->"Bold"], "[", "\"\<maximum\>\"", "]"}]}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Limit of Sum: Proof", "Subsubsection",
  Background->None],

Cell["\<\
With the PCS-prover, the  automatic generation of the proof does not need any \
more user interaction. In particular, it does not need the invention of the \
intermediate lemmata for the 4-ary and 3-ary versions of the limit notion:\
\>", "Text"],

Cell[BoxData[
    \(Prove[Proposition["\<2-ary limit of sum\>"], 
      using \[Rule] Theory["\<2-ary limit\>"], by \[Rule] PCS]\)], "Input",
  Background->None,
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "max-greater", "maximum", "sum of sequences"}],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you have the \
latest, January 2000, version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " available you can execute the above command and actually generate this \
notebook. For the other readers we stored this notebook  under the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-2-ary-Limit-with-PCS.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo- 1999-Proof-2-ary-Limit-with-PCS.ps.) "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Set Theory Proving", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["Load Prover", "Subsubsection",
  Background->None],

Cell[TextData[{
  "For generating proofs involving set theory notions, we have to load the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " set theory prover:"
}], "Text"],

Cell[BoxData[
    \(Needs["\<Theorema`Provers`UserProvers`SetTheoryProver`\>"]\)], "Input",
  Background->None],

Cell[BoxData[
    \(MakeBoxes[Floor[a_], StandardForm] := 
      RowBox[{"\<\[LeftFloor]\>", 
          MakeBoxes[a, StandardForm], "\<\[RightFloor]\>"}]\)], "Input",
  Background->None,
  CellTags->{
  "Classes Modulo a Predicate", "Classes Modulo Symmetric Predicates", 
    "Symmetry"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell[TextData[{
  "This examples shows how, in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", with an extension of the PCS-prover for predicate logic, proofs for \
theorems involving notions of set theory can be generated. The style of the \
proofs generated is very much the same as the style of the proofs generated \
by the predicate logic prover (PC or PCS). The basic properties of the set \
theoretic notions (like the extensionality axiom for equality between sets) \
are not added to the knowledge base but, rather, are incorporated as \
additional inference rules."
}], "Text"],

Cell[TextData[{
  "The example also shows, how playing with ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " can reveal the exact dependence of certain theorems on a minimal \
knowledge base. For example, the proof of  Proposition[\"Classes Modulo \
Symmetric Predicates\"] in the next section needs only the symmetry of the \
relation ~ considered and does not need reflexivity nor transitivity."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classes Modulo Relations", "Subsubsection",
  Background->None],

Cell["\<\
We demonstrate the set theory prover (which currently, January 2000, is only \
in its initial state of development) by an easy example proof of a statement \
on residue classes. We start with the definition of the notion of a symmetric \
relation:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Symmetry\>\"", ",", \(any[ \[Tilde] ]\), ",", "\n", "\t", 
        GridBox[{
            {\(is\[Dash]symmetric[ \[Tilde] ] \[DoubleLeftRightArrow] \(\
\[ForAll] \+\(a, b\)\((a \[Tilde] b \[Implies] b \[Tilde] a)\)\)\), 
              "\"\<symm:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{"is symmetric", "is\[Dash]symmetric", "Reflexivity", "Symmetry"}],

Cell["\<\
Note that, in this definition, \"~\" is a variable (in fact, a higher-order \
variable) for arbitrary binary predicates.\
\>", "Text"],

Cell[TextData[{
  "Now we define the residue class of ",
  StyleBox["a",
    FontSlant->"Italic"],
  " modulo ~:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Classes Modulo a Predicate\>\"", 
        ",", \(any[\(\[Tilde]\)\(\(,\)\(a\)\)]\), ",", "\n", "\t", GridBox[{
            {\(\(\[LeftFloor]a\[RightFloor]\_ \[Tilde] \)\ \  = {b\( \
\[VerticalSeparator] \+b\)\((b \[Tilde] a)\)}\), 
              "\"\<\[LeftFloor] \[RightFloor]:\>\""}
            }]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "Classes Modulo a Predicate", "equivalence class", "Equivalence class", 
    "Equivalence Classes"}],

Cell["We now prove the following proposition:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Classes Modulo Symmetric Predicates\>\"", ",", \(any[ \[Tilde] ]\),
         ",", "\n", "\t", GridBox[{
            {\(is\[Dash]symmetric[ \[Tilde] ] \[Implies] \[ForAll] \+\(a, b\)\
\((a \[Element] \(\[LeftFloor]b\[RightFloor]\_ \[Tilde] \) \[Implies] 
                      b \[Element] \(\[LeftFloor]a\[RightFloor]\_ \[Tilde] \
\))\)\), "\"\<symm\[Implies]\[LeftFloor]\[RightFloor]\>\""}
            }]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{
  "Classes Modulo a Predicate", 
    "Classes Modulo Predicates with Special Properties", 
    "Classes Modulo Reflexive Predicates", 
    "Classes Modulo Symmetric Predicates", "equivalence class", 
    "Equivalence class", "Equivalence Classes"}],

Cell[TextData[{
  "Here is the proof call in ",
  StyleBox["Theorema:",
    FontSlant->"Italic"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Proposition["\<Classes Modulo Symmetric Predicates\>"], \n\t
      using \[Rule] \[LeftAngleBracket]Definition["\<Symmetry\>"], 
          Definition["\<Classes Modulo a Predicate\>"]\[RightAngleBracket], \n\
\tby \[Rule] SetTheoryPCProver, 
      presentation \[Rule] "\<SuccessBranch\>"]\)], "Input",
  Background->None],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell["\<\
The option 'presentation\[Rule]\"SuccessBranch\"' is chosen for suppressing, \
in the output, all intermediate proof attempts so that only the successful \
attempt is finally shown.\
\>", "Text"],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you have the \
latest, January 2000, version of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " available you can execute the above command and actually generate this \
notebook. For the other readers we stored this notebook under the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-Symmetric-Relations.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999- Proof-Symmetric-Relations.ps.) "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Inventing Lemmata on Natural Numbers", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["Load Induction Provers", "Subsubsection",
  Background->None],

Cell["\<\
Now we load an induction prover for proving equalities on natural numbers:\
\>", "Text"],

Cell[BoxData[
    \(\(\( (*\ \(Needs["\<Theorema`Language`Semantics`UserLanguage`\>"];\)*) \
\)\(SetGlobals[LabelStyle \[Rule] "\<Numeric\>", 
      Prover \[Rule] NNEqIndProver]; 
    Needs["\<Theorema`Provers`Cascade`Cascade`\>"]; 
    Needs["\<Theorema`Provers`Cascade`ConjectureGenerator`\>"]\)\)\)], "Input",\

  Background->None,
  CellTags->"addition"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell[TextData[{
  "In this section, we do not only demonstrate how a typical ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " induction prover works but, more importantly how any prover ",
  StyleBox["P, ",
    FontSlant->"Italic"],
  "for example the induction prover for equalities over natural numbers, can \
be combined with a \"conjecture generator\" ",
  StyleBox["C ",
    FontSlant->"Italic"],
  "in a process which we call \"cascade\" for obtaining a new prover  which, \
often, is much more powerful than the original prover and, in addition, \
during the process of generating proofs, invents and adds useful new \
knowledge to the knowledge base without any user interaction."
}], "Text"],

Cell[TextData[{
  "What the meta-algorithm Cascade[",
  StyleBox["P,C",
    FontSlant->"Italic"],
  "] (that depends on the prover ",
  StyleBox["P",
    FontSlant->"Italic"],
  " and the conjecture generator ",
  StyleBox["C",
    FontSlant->"Italic"],
  ") does  is, roughly, the following:"
}], "Text"],

Cell[TextData[{
  "For proving a goal ",
  StyleBox["G",
    FontSlant->"Italic"],
  " relative to a knowledge base ",
  StyleBox["K, ",
    FontSlant->"Italic"],
  "it attempts to generate a proof by using ",
  StyleBox["P.",
    FontSlant->"Italic"]
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
If the attempt is successful, we are done, and the proof is output.\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "If the attempt fails, ",
  StyleBox["C",
    FontSlant->"Italic"],
  " analyzes the failing proof and produces, from the line in which the proof \
fails, a conjecture (\"lemma\") ",
  StyleBox["L. ",
    FontSlant->"Italic"]
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "Now, Cascade[",
  StyleBox["P,C",
    FontSlant->"Italic"],
  "] is called recursively for attempting to generate a proof for ",
  StyleBox["L",
    FontSlant->"Italic"],
  " relative to the knowledge base ",
  StyleBox["K",
    FontSlant->"Italic"],
  ". (Note that this recursive call may produce and prove more conjectures \
than just ",
  StyleBox["L",
    FontSlant->"Italic"],
  "!) "
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "If this call succeeds, i.e. ",
  StyleBox["L ",
    FontSlant->"Italic"],
  "can be proved, Cascade[",
  StyleBox["P,C",
    FontSlant->"Italic"],
  "] is called recursively for the goal ",
  StyleBox["G",
    FontSlant->"Italic"],
  " but, now, relative to the new knowledge base ",
  StyleBox["K ",
    FontSlant->"Italic"],
  "augmented by ",
  StyleBox["L",
    FontSlant->"Italic"],
  " and all proved lemmata that have been produced during the proof of ",
  StyleBox["L",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["\<\
If this call fails, the cascade stops unsuccessful. (Note, however, that even \
in the unsuccessful case a couple of lemmata may have been proved!)\
\>", "Text",
  CellDingbat->"\[FilledSmallCircle]"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inductive Definition of Addition", "Subsubsection",
  Background->None],

Cell["\<\
We show the effect of the cascade in the case of proving, by induction, \
commutativity for addition on the natural numbers:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<addition\>\"", ",", \(any[m, n]\), ",", "\n", "\t", GridBox[{
            {\(m + 0 = m\), "\"\< +0:\>\""},
            {\(m + \(n\^+\) = \(\((m + n)\)\^+\)\), "\"\< + .:\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{"addition", "Addition", "Multiplication"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Failing Proof", "Subsubsection",
  Background->None],

Cell[TextData[{
  "We now try to prove commutativity of addition with one of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " induction provers (whose name is '",
  "NNEqIndProver')",
  " for natural numbers:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<commutativity of addition\>\"", ",", \(any[m, n]\), ",", "\n", 
        "\t", GridBox[{
            {\(m + n = n + m\), "\"\< + = \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "Addition", "comm*", "comm+", "commutativity of addition", "Multiplication"}
    ],

Cell[BoxData[
    \(\(Prove[Proposition["\<commutativity of addition\>"], \n\t
        using \[Rule] \[LeftAngleBracket]Definition["\<addition\>"]\
\[RightAngleBracket], \n\tby \[Rule] NNEqIndProver, \n\t
        ProverOptions \[Rule] {TermOrder \[Rule] LeftToRight}, 
        presentation \[Rule] 100];\)\)], "Input",
  Background->None,
  CellTags->{
  "Addition", "assoc+", "comm*", "comm+", "commutativity of addition", 
    "left addition", "Multiplication"}],

Cell[BoxData[
    RowBox[{
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"], "=", 
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]}]], "Input",
  Background->None],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. Otherwise, please, open the file ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-Attempt-Commutativity.nb or, alternatively, the file ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-Attempt-Commutativity.ps.) "
}], "Text"],

Cell[TextData[{
  "If you study this proof carefully you will immediately understand how the \
prover 'NNEqIndProver' works. It turns out that it cannot complete the proof \
because it would have to \"know\", for some \"arbitrary but fixed\"  ",
  Cell[BoxData[
      StyleBox[\(m\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]]],
  ", that"
}], "Text"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"], "=", 
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]}]], "Input",
  Background->None],

Cell["\<\
A human reader would probably immediately conjecture that, maybe, 0 is also a \
left-zero for addition, i.e.\
\>", "Text"],

Cell[BoxData[
    \(\[ForAll] \+m m = 0 + m\)], "Input",
  Background->None],

Cell[TextData[{
  "and that, if this formula was true and was added to the knowledge base, \
the proof of commutativity could be continued and, maybe, could be completed. \
(In fact, as we will see this formula is true and the proof of commutativity \
can be continued ",
  StyleBox["but",
    FontSlant->"Italic"],
  " it cannot yet be completed. Rather, the proof will again be stuck at an \
equality that cannot be proved because, before this, another lemma should \
have been proved!) All this is now automatically done by the \"meta-algorithm\
\" 'Cascade':"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Learning from Failure: The 'Cascade'", "Subsubsection",
  Background->None],

Cell["\<\
We now call, instead of just 'NNEqIndProver', the \
'Cascade[NNEqIndProver,ConjectureGenerator]', in which 'NNEqIndProver' is \
combined in the way described above with a 'ConjectureGenerator' that \
simulates, essentially, the conjecturing strategy of a human:\
\>", "Text"],

Cell[BoxData[
    \(\(Prove[Proposition["\<commutativity of addition\>"], \n\t
        using \[Rule] Definition["\<addition\>"], 
        by \[Rule] Cascade[NNEqIndProver, ConjectureGenerator], 
        ProverOptions \[Rule] {TermOrder \[Rule] LeftToRight}];\)\)], "Input",\

  Background->None,
  CellTags->{
  "Addition", "assoc+", "comm*", "comm+", "left addition", "Multiplication"}],

Cell[TextData[{
  "This call generates, without any user-interaction, a sequence of \
altogether five notebooks containing all intermediate proofs and proof \
attempts. The names of these notebooks are 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. Otherwise, please, open the files ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Cascade-1.nb until ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Cascade-5.nb or, alternatively, the files ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Cascade-1.ps until ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Cascade-5.ps.) In order to understand the effect of the cascade \
it is important to study these notebooks, at least to the extend that you see \
which goals are proved (are attempted to be proved) with respect to which \
knowledge bases. The final notebook contains not only a successful proof of \
commutativity but, in addition, contains two more lemmata in the knowledge \
base that have been invented (!) and proved in the course of the entire \
cascade. Also note that, in fact, the lemmata invented by the cascade are \
\"interesting\" and \"natural\" lemmata, namely:"
}], "Text"],

Cell["the property that 0 is also a left-zero and", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell["addition also obeys induction from left.", "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "In fact, it is quite natural that these two lemmata should be proved ",
  StyleBox["before",
    FontSlant->"Italic"],
  " one attempts to prove commutativity of addition and this is what the \
cascade detects completely automatically!"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Special Proof Rules for Natural Numbers", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell[TextData[{
  "In the previous example, we demonstrated how the proving power of a given \
prover ",
  StyleBox["P ",
    FontSlant->"Italic"],
  "can be increased drastically by combining it with a \"conjecture generator\
\" ",
  StyleBox["C",
    FontSlant->"Italic"],
  " in the cascade mode. Here, by \"increased proving power\" we mean that \
\"more theorems can be proved\"."
}], "Text"],

Cell[TextData[{
  "In the next example, we want to demonstrate how the proving power of a \
given prover ",
  StyleBox["P ",
    FontSlant->"Italic"],
  "can be increased by incorporating proved knowledge into the prover itself, \
i.e. by using proved knowledge not as a part of the knowledge base but as a \
new inference rule. In this approach, by \"increased proving power\" we mean \
that \"theorems can be proved in fewer steps\", i.e. by \"leaving out \
uninteresting steps\"."
}], "Text"],

Cell["\<\
As an example, we use commutativity and associativity of addition on natural \
numbers: \
\>", "Text"],

Cell["\<\
In the first of the two subsequent sections, we will first prove, by the \
induction prover 'NNEqIndProver' associativity of multiplication using (among \
other properties) commutativity and associativity of addition in the \
knowledge base. This will result in a successful proof that contains, \
however, long sequences of steps that do nothing else than to apply \
commutativity and associativity of addition and, at the stage of exploring \
the theory of multiplication, are not any more \"interesting\".\
\>", "Text"],

Cell["\<\
In the second of the two subsequent sections, we will prove commutativity of \
multiplication again by the induction prover 'NNEqIndProver' but in a variant \
in which iterated associativity of multiplication is used as a \"black box \
simplification step\" that brings any term immediately into a \"normal form\" \
w.r.t. to associativity and commutativity (AC) of addition. Roughly, this \
simplification \"uniquely orders the terms in a sum and brings all \
parentheses to their left-most position\". This variant of the prover \
'NNEqIndProver' produces a proof that replaces every  sequence of \
\"uninteresting\" AC-steps by one \"AC-simplification\" step.\
\>", "Text"],

Cell[TextData[{
  "This principle of \"elevating knowledge (like the laws of associativity \
and commutativity) to the level of inference rule (like AC-simplification)\" \
is of utmost importance to making automated proving feasible and, in fact, is \
a key strategy in human proving. This strategy, so far, is not really \
systematically studied in the literature and will be one of the key \
techniques in the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " project."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Using Associativity and Commutativity as Part of the Knowledge Base\
\>", "Subsubsection",
  Background->None],

Cell["We start from an exhaustive knowledge base for addition", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Propositions",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equational Properties of Addition\>\"", ",", \(any[m, n, p]\), ",",
         "\n", "\t", GridBox[{
            {\(m + 0 = m\), "\"\< +0\>\""},
            {\(m + \(n\^+\) = \(\((m + n)\)\^+\)\), "\"\< + ^+\>\""},
            {\(0 + n = n\), "\"\<0+ \>\""},
            {\(\(m\^+\) + n = \(\((m + n)\)\^+\)\), "\"\<^++ \>\""},
            {\(m + n = n + m\), "\"\< + \>\""},
            {\(\((m + n)\) + p = m + \((n + p)\)\), "\"\<( + ) + \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"Equational Properties of Addition"],

Cell["and a partial knowledge base for multiplication:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[
        RowBox[{
          StyleBox["Proposition",
            FontWeight->"Bold"], "s"}]], "[", 
      RowBox[{
      "\"\<Some Equational Properties of Multiplication\>\"", 
        ",", \(any[m, n]\), ",", "\n", "\t", GridBox[{
            {\(m*0 = 0\), "\"\< *0\>\""},
            {\(m*\(n\^+\) = \((m*n)\) + m\), "\"\< *  ^+\>\""},
            {\(0*n = 0\), "\"\<0*\>\""},
            {\(\(m\^+\)*n = \((m*n)\) + n\), "\"\< ^+*\>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "Multiplication", "Some Equational Properties of Multiplication"}],

Cell["\<\
Now, we prove associativity of multiplication using, first, the prover \
'NNEqIndProver' in its original form:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Proposition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Associativity of Multiplication\>\"", ",", \(any[m, n, p]\), ",", 
        "\n", "\t", GridBox[{
            {\(\((m*n)\)*p = m*\((n*p)\)\), "\"\<( * ) * \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{
  "Associativity of Multiplication", "Associativity of Multiplicatios", 
    "Multiplication"}],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Associativity of Multiplication\>"], \n\t
      using \[Rule] {Propositions["\<Some Equational Properties of \
Multiplication\>"], 
          Propositions["\<Equational Properties of Addition\>"]}, \ \n\t
      by \[Rule] NNEqIndProver, presentation \[Rule] "\<SuccessBranch\>"\), 
      "]"}]], "Input",
  Background->None],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers we have stored this file under the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999- Proof-Associativity.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-Associativity.ps.) "
}], "Text"],

Cell["\<\
In order to really understand the essence of the strategy, it is important \
that you study this proof. In particular, analyze the sequences of steps in \
which associativity and commutativity of addition is used. Two important \
examples of such sequences are the ones occurring right at the end (in the \
most important part) of the proof.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Associativity and Commutativity as Inference Rules", \
"Subsubsection",
  Background->None],

Cell["\<\
Now we remove associativity and commutativity of addition from the knowledge \
base:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Propositions",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Equational Properties of Addition\>\"", ",", \(any[m, n, p]\), ",",
         "\n", "\t", GridBox[{
            {\(m + 0 = m\), "\"\< +0\>\""},
            {\(m + \(n\^+\) = \(\((m + n)\)\^+\)\), "\"\< + ^+\>\""},
            {\(0 + n = n\), "\"\<0+ \>\""},
            {\(\(m\^+\) + n = \(\((m + n)\)\^+\)\), "\"\<^++ \>\""}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"Equational Properties of Addition"],

Cell[TextData[{
  "Instead, we call 'NNEqIndProver' in a variant that uses associativity and \
commutativity of addition for special simplification. This variant can be \
called by setting the option 'built\[Dash]in \[Rule] {Property[+\[Rule]  \
{Associative, Commutative}]}'. (Of course, AC-simplification must be \
implemented extra in ",
  StyleBox["Theorema, ",
    FontSlant->"Italic"],
  "it does not \"come for free\".)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Prove",
        FontWeight->"Bold"], 
      "[", \(Proposition["\<Associativity of Multiplication\>"], \n\t
      using \[Rule] {Propositions["\<Some Equational Properties of \
Multiplication\>"], 
          Propositions["\<Equational Properties of Addition\>"]}, \ \n\t
      built\[Dash]in -> {Property[\(+\(\(\[Rule]\)\({Associative, 
                  Commutative}\)\)\)]}, \n\tby \[Rule] NNEqIndProver, 
      proof\[Dash]object \[Rule] "\<SuccessBranch\>"\), "]"}]], "Input",
  Background->None,
  CellTags->"Equational Properties of Addition"],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers we stored the file under the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999- Proof-Associativity-with-AC.nb or, alternatively, the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof- Attempt-Associativity-with-AC.ps.) "
}], "Text"],

Cell[TextData[{
  "Again, we ask you to study the proof carefully in order to see the effect \
of AC-simplification: The proof is much shorter, it replaces every sequences \
of AC-steps by a standard AC-simplification step (marked by '(SpecialSimp)') \
in the proof. Also, if you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " tester, you will notice that the computing time for the proof is much \
shorter!"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Proving Booleans of Equalities by Groebner Bases", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell["\<\
In the next example, we want to demonstrate how the technique of  using \
proved knowledge not as a part of the knowledge base but as a new inference \
rule can be made arbitrarily powerful. Entire mathematical theories can be \
turned into \"black box\" inference rules (i.e. into inference rules whose \
application may involve millions of individual steps that are, however, not \
shown to the user because their correctness has been proved, once and for \
all, by the underlying mathematical theory).\
\>", "Text"],

Cell[TextData[{
  "One such method is the method of \"Groebner bases\" invented by the author \
in his PhD thesis 1965 and published in B. Buchberger, ",
  StyleBox["An Algorithmic Criterion for the Solvability of Nonlinear Systems \
of Algebraic Equations, ",
    FontSlant->"Italic"],
  "Aequationes Mathematicae, ",
  StyleBox["4/3",
    FontWeight->"Bold"],
  ", pp. 374-383, (1970). The original version of this paper is in German, an \
English version is re-printed in B. Buchberger, F. Winkler (eds.), ",
  StyleBox["Groebner Bases and Applications,",
    FontSlant->"Italic"],
  " Cambridge University Press, 1998, pp. 535-545. In this book (pp. 3-31), \
there is also a survey paper on Groebner bases that contains a  detailed but \
concise version of the proof of the author's main theorem of Groebner bases \
theory: B. Buchberger, ",
  StyleBox["Introduction to Groebner Bases",
    FontSlant->"Italic"],
  ". Proving and disproving arbitrary universally quantified Boolean \
combinations of equalities over any algebraically closed field can be reduced \
to the decision about the solvability of systems of nonlinear multivariate \
polynomials equations. It can be proved, once and for all, that any such \
decision can be made by checking whether or not the constant 1 is in the \
corresponding Groebner basis and an algorithm can be established that \
computes the \"corresponding\" Groebner basis for any set of nonlinear \
multivariate polynomials."
}], "Text"],

Cell[TextData[{
  "Implementation of this proof method into ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " is quite easy since the algorithm for computing Groebner bases is already \
available as a Mathematica function."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load Groebner Bases Prover", "Subsubsection",
  Background->None],

Cell[TextData[{
  "By the subsequent command, the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " Groebner Bases Prover is loaded:"
}], "Text"],

Cell[BoxData[
    \(Needs["\<Theorema`Provers`UserProvers`GroebnerBasesProver`\>"]; \
$TmaProofPresentation\  = \ 100;\)], "Input",
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
  Background->None],

Cell["\<\
Here is an example of a universally quantified boolean combination of \
equalities over the complex numbers:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Formula",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Test\>\"", ",", \(any[x, y]\), ",", "\n", "\t", GridBox[{
            {\(\((\ \ \((\(x\^2\) y - 3  x\ )\) \[NotEqual] 
                    0)\) \[Or] \((\((x\ y + x + y)\) \[NotEqual] 
                    0)\) \[Or] \n\t\t\((\((\((\(x\^2\) y + 3  x = 
                            0)\) \[Or] \((\((\(-2\)\ x\^2 + \(-7\)\ x\ y + 
                                x\^2\ y + 
                                x\^3\ y + \(-2\)\ y\^2 + \(-2\)\ x\ y\^2 + 
                                2\ x\^2\ y\^2)\) = 
                            0)\))\)\n\t \[And] \((\((x\^2 + \(-x\)\ y + 
                            x\^2\ y + \(-2\)\ y\^2 + \(-2\)\ x\ y\^2)\) = 
                        0)\))\)\), \(\(\ \ \ \ \ \ \ \ \ \ \)\("\<B1\>"\)\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"Test"],

Cell["\<\
A proof for this formula can be generated  by the following call:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Formula["\<Test\>"], using \[Rule] {}, 
      by \[Rule] GroebnerBasesProver]\)], "Input",
  Background->None],

Cell[BoxData[
    \(\[SkeletonIndicator]\ ProofObject\ \[SkeletonIndicator]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result of calling the prover is a proof of the proposition. The proof \
is stored in an extra notebook with name 'Untitled-...'. (If you are a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " alpha tester you can execute the above command and actually generate this \
notebook. For the other readers the file is stored under the name ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999- Proof-by-Groebner-Bases.nb or, alternatively, the file ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "-Demo-1999-Proof-by-Groebner-Bases.ps.) "
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example: Proving Combinatorial Identities by Zeilberger / Paule\
\>", "Subsection",
  Background->None,
  CellTags->{"Equational Properties of Addition", "Test"}],

Cell[CellGroupData[{

Cell["The Purpose of this Example", "Subsubsection",
  Background->None],

Cell["\<\
The next example is along the same lines as the Groebner bases proving \
method. This time, the class of theorems one is interested in is the class of \
combinatorial identities (terms involving elementary functions over the \
natural numbers and the summation quantifier). In the past 10 years, by \
Gosper, Zeilberger, Paule, and others, a powerful special automated proving \
technique has also been developed  for this class of formulae,  see the \
literature given in P. Paule's computer-solution of Problem 94-2, SIAM REVIEW \
Vol.37 (1995), 105-106.\
\>", "Text"],

Cell["\<\
Again, the method is based on some quite heavy mathematical machinery. Its \
proof has to be established once and for all and, then, it can be used for \
proving an infinite class of - quite nontrivial and hard - combinatorial \
identities.\
\>", "Text"],

Cell[TextData[{
  "The implementation of this method in ",
  StyleBox["Theorema ",
    FontSlant->"Italic"],
  "together with essential mathematical improvements of the method was done \
by P. Paule and M. Schorn."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load Prover", "Subsubsection",
  Background->None],

Cell["We first load the prover:", "Text"],

Cell[BoxData[
    \(Needs["\<Theorema`Provers`PauleSchorn`Simplifier`\>"]\)], "Input",
  InitializationCell->True,
  Background->None],

Cell["\<\
We also have to load a couple of built-in algorithms for basic logical and \
mathematical operators.\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Built\[Dash]in",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<PauleSchorn\>\"", ",", "\n", "\t", GridBox[{
            {\(Built\[Dash]in["\<Quantifiers\>"]\)},
            {\(Built\[Dash]in["\<Operators\>"]\)},
            {\(Built\[Dash]in["\<Numbers\>"]\)},
            {\(Built\[Dash]in["\<Number Domains\>"]\)},
            {\(Built\[Dash]in["\<Forward Difference\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  InitializationCell->True,
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"PauleSchorn"],

Cell[BoxData[{
    \(\(Use[Built\[Dash]in["\<PauleSchorn\>"]];\)\), "\n", 
    \(\(FormatVariables[\n\tFontWeight \[Rule] "\<Plain\>"\ , \n\t
        FontSlant \[Rule] "\<Italic\>"\n];\)\), "\n", 
    \(FormatArbitraryButFixedConstants[\n\t
      FontWeight \[Rule] "\<Plain\>"\ , \n\t
      FontSlant \[Rule] "\<Plain\>"\n]\)}], "Input",
  InitializationCell->True,
  Background->None,
  CellTags->"PauleSchorn"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Invent and Prove", "Subsubsection",
  Background->None,
  CellTags->"Gauss"],

Cell["\<\
We start with one of the most elementary (and historically important) formula \
in the class of combinatorial identities:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Formula",
        FontWeight->"Bold"], 
      "[", \("\<Gauss\>", \n\t\[Sum]\+\(k = 0, \[Ellipsis], n\)k\), 
      "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"Gauss"],

Cell[TextData[{
  "The following call does actually more than just proving a theorem about \
the Gauss sum: It ",
  StyleBox["invents",
    FontSlant->"Italic"],
  " a closed form for this sum ",
  StyleBox["and",
    FontSlant->"Italic"],
  " proves it.  In the present version, the proof consists in producing a \
summation-free expression that can be considered as a \"test expression\". If \
this expression can be simplified to 1, the closed form is correct. Hence, in \
the present version, in order to complete the proof, the user must call a \
simplifier for checking whether the output test expression reduces to 1. \
Also, in the present version, the proof text is shown right in the \
Mathematica notebook from which the prover is called, i.e. here it is shown \
just below the call. A future version of this prover will be adjusted to the \
usual style of the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " provers."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Formula["\<Gauss\>"], by \[Rule] PauleSchorn\[Dash]Telescope, 
      built\[Dash]in \[Rule] Built\[Dash]in["\<PauleSchorn\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Theorem:\\n\"\>", "\[InvisibleSpace]", 
        InterpretationBox[
          
          RowBox[{"\<\"If \"\>", "\[InvisibleSpace]", "\<\" \"\>", 
            "\[InvisibleSpace]", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Plain",
              Background->None], "\[InvisibleSpace]", "\<\" \"\>", 
            "\[InvisibleSpace]", "\<\" is a natural number, then:\"\>"}],
          SequenceForm[ "If ", " ", 
            \[Bullet]fix[ n], " ", " is a natural number, then:"],
          Editable->False], "\[InvisibleSpace]", "\<\"\\n\"\>", 
        "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            UnderscriptBox["\[Sum]", 
              RowBox[{
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "=", "0"}], ",", "\[Ellipsis]", ",", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  Background->None]}]], 
            StyleBox["k",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "=", 
          RowBox[{\(1\/2\), " ", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Plain",
              Background->None], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  Background->None]}], ")"}]}]}]}],
      SequenceForm[ "Theorem:\n", 
        SequenceForm[ "If ", " ", 
          \[Bullet]fix[ n], " ", " is a natural number, then:"], "\n", 
        \[Trademark]Equal[ 
          \[Trademark]SumOf[ 
            \[Bullet]range[ 
              \[Bullet]integerRange[ 
                \[Bullet]var[ k], 0, 
                \[Bullet]fix[ n]]], True, 
            \[Bullet]var[ k]], 
          Times[ 
            Rational[ 1, 2], 
            \[Bullet]fix[ n], 
            Plus[ 1, 
              \[Bullet]fix[ n]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Proof:\\n\"\>", "\[InvisibleSpace]", "\<\"Let \"\>", 
        "\[InvisibleSpace]", 
        SubscriptBox[
          StyleBox["\[CapitalDelta]",
            FontColor->RGBColor[0.549996, 0, 0.8]], 
          StyleBox["k",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]], 
        "\[InvisibleSpace]", "\<\" denote the forward difference operator in \
\"\>", "\[InvisibleSpace]", 
        StyleBox["k",
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[InvisibleSpace]", "\<\" then\\n\"\>", 
        "\[InvisibleSpace]", "\<\"the Theorem follows from summing the \
equation\\n\"\>", "\[InvisibleSpace]", 
        RowBox[{
          StyleBox["k",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "=", 
          RowBox[{
            SubscriptBox[
              StyleBox["\[CapitalDelta]",
                FontColor->RGBColor[0.549996, 0, 0.8]], 
              StyleBox["k",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "[", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                RowBox[{\(-1\), "+", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], " ", 
              StyleBox["k",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], 
        "\[InvisibleSpace]", "\<\"\\n\"\>", 
        "\[InvisibleSpace]", "\<\"over the range \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "=", "0"}], ",", "\[Ellipsis]", ",", 
          StyleBox["n",
            FontWeight->"Plain",
            FontSlant->"Plain",
            Background->None]}], "\[InvisibleSpace]", "\<\".\"\>"}],
      SequenceForm[ "Proof:\n", "Let ", 
        \[Trademark]\[CapitalDelta][ 
          \[Bullet]var[ k]], " denote the forward difference operator in ", 
        \[Bullet]var[ k], " then\n", 
        "the Theorem follows from summing the equation\n", 
        \[Trademark]Equal[ 
          \[Bullet]var[ k], 
          \[Trademark]\[CapitalDelta][ 
            \[Bullet]var[ k], 
            Times[ 
              Rational[ 1, 2], 
              Plus[ -1, 
                \[Bullet]var[ k]], 
              \[Bullet]var[ k]]]], "\n", "over the range ", 
        \[Bullet]displayAsRange[ 
          \[Bullet]range[ 
            \[Bullet]integerRange[ 
              \[Bullet]var[ k], 0, 
              \[Bullet]fix[ n]]]], "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"The equation is routinely verifiable\\n\"\>", 
        "\[InvisibleSpace]", "\<\"by dividing the right\[Dash]hand side by \
the left\[Dash]hand side\\n\"\>", 
        "\[InvisibleSpace]", "\<\"and simplifying the resulting rational \
function\\n\"\>", "\[InvisibleSpace]", 
        FractionBox[
          RowBox[{
            RowBox[{\(1\/2\), " ", 
              StyleBox["k",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " ", 
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], "-", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                RowBox[{\(-1\), "+", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], " ", 
              StyleBox["k",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], 
          StyleBox["k",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]], "\[InvisibleSpace]", "\<\"\\nto 1.\"\>"}],
      SequenceForm[ 
      "The equation is routinely verifiable\n", 
        "by dividing the right\[Dash]hand side by the left\[Dash]hand side\n",
         "and simplifying the resulting rational function\n", 
        \[Trademark]Divide[ 
          \[Trademark]Minus[ 
            Times[ 
              Rational[ 1, 2], 
              \[Bullet]var[ k], 
              Plus[ 1, 
                \[Bullet]var[ k]]], 
            Times[ 
              Rational[ 1, 2], 
              Plus[ -1, 
                \[Bullet]var[ k]], 
              \[Bullet]var[ k]]], 
          \[Bullet]var[ k]], "\nto 1."],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
The simplification can be done by called Mathematica's simplifier:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"System`Simplify", "[", 
      FractionBox[
        RowBox[{
          RowBox[{\(1\/2\), " ", 
            StyleBox["k",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0.549996, 0.110994],
              Background->None], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0.549996, 0.110994],
                  Background->None]}], ")"}]}], "-", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{\(-1\), "+", 
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  FontColor->RGBColor[1, 0.549996, 0.110994],
                  Background->None]}], ")"}], " ", 
            StyleBox["k",
              FontWeight->"Plain",
              FontSlant->"Italic",
              FontColor->RGBColor[1, 0.549996, 0.110994],
              Background->None]}]}], 
        StyleBox["k",
          FontWeight->"Plain",
          FontSlant->"Italic",
          FontColor->RGBColor[1, 0.500008, 0],
          Background->None]], "]"}]], "Input",
  Background->None],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Nontrivial Example", "Subsubsection",
  Background->None],

Cell[TextData[{
  "Now we show another example, which shows the mathematical power of the \
Gosper-Zeilberger-Paule-prover: The problem of constructing a closed form for \
the input expression in this example was an open problem for many years. The \
solution was given in P. Paule,  ",
  StyleBox["Computer-Solution of Problem 94-2,",
    FontSlant->"Italic"],
  " SIAM REVIEW Vol.37 (1995), 105-106."
}], "Text"],

Cell["Here is the expression:", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Formula",
        FontWeight->"Bold"], 
      "[", \("\<SIAM series\>", \n\t\[Sum]\+\(k = 1, \[Ellipsis], \
n\)\(\(\((\(-1\))\)\^\(k + 1\)\) \((4\ k + 1)\) \(\((2\ k)\)!\)\)\/\(\(2\^k\) \
\((2\ k - 1)\) \(\((k + 1)\)!\) \(2\^k\) \(k!\)\)\), "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"SIAM series"],

Cell["Here is the call of the prover:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prove[Formula["\<SIAM series\>"], 
      by \[Rule] PauleSchorn\[Dash]Telescope, 
      built\[Dash]in \[Rule] Built\[Dash]in["\<PauleSchorn\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Theorem:\\n\"\>", "\[InvisibleSpace]", 
        InterpretationBox[
          
          RowBox[{"\<\"If \"\>", "\[InvisibleSpace]", "\<\" \"\>", 
            "\[InvisibleSpace]", 
            RowBox[{\(-1\), "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Plain",
                Background->None]}], "\[InvisibleSpace]", "\<\" \"\>", 
            "\[InvisibleSpace]", "\<\" is a natural number, then:\"\>"}],
          SequenceForm[ "If ", " ", 
            Plus[ -1, 
              \[Bullet]fix[ n]], " ", " is a natural number, then:"],
          Editable->False], "\[InvisibleSpace]", "\<\"\\n\"\>", 
        "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            UnderscriptBox["\[Sum]", 
              RowBox[{
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "=", "1"}], ",", "\[Ellipsis]", ",", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  Background->None]}]], 
            RowBox[{"(", 
              FractionBox[
                RowBox[{
                  RowBox[{"-", 
                    SuperscriptBox[\((\(-1\))\), 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]]}], " ", 
                  SuperscriptBox["2", 
                    RowBox[{\(-2\), " ", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]], " ", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"2", " ", 
                        StyleBox["k",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "!"}], " ", 
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      RowBox[{"4", " ", 
                        StyleBox["k",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], 
                RowBox[{
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "!"}], " ", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        StyleBox["k",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "!"}], " ", 
                  RowBox[{"(", 
                    RowBox[{\(-1\), "+", 
                      RowBox[{"2", " ", 
                        StyleBox["k",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}]], ")"}]}], "=", 
          RowBox[{"1", "+", 
            FractionBox[
              RowBox[{
                RowBox[{"-", 
                  SuperscriptBox[\((\(-1\))\), 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      Background->None]]}], " ", 
                SuperscriptBox["2", 
                  RowBox[{\(-2\), " ", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      Background->None]}]], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"2", " ", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        Background->None]}], ")"}], "!"}]}], 
              RowBox[{
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    Background->None], "!"}], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        Background->None]}], ")"}], "!"}]}]]}]}]}],
      SequenceForm[ "Theorem:\n", 
        SequenceForm[ "If ", " ", 
          Plus[ -1, 
            \[Bullet]fix[ n]], " ", " is a natural number, then:"], "\n", 
        \[Trademark]Equal[ 
          \[Trademark]SumOf[ 
            \[Bullet]range[ 
              \[Bullet]integerRange[ 
                \[Bullet]var[ k], 1, 
                \[Bullet]fix[ n]]], True, 
            Times[ -1, 
              Power[ -1, 
                \[Bullet]var[ k]], 
              Power[ 2, 
                Times[ -2, 
                  \[Bullet]var[ k]]], 
              Power[ 
                Factorial[ 
                  \[Bullet]var[ k]], -1], 
              Factorial[ 
                Times[ 2, 
                  \[Bullet]var[ k]]], 
              Power[ 
                Factorial[ 
                  Plus[ 1, 
                    \[Bullet]var[ k]]], -1], 
              Power[ 
                Plus[ -1, 
                  Times[ 2, 
                    \[Bullet]var[ k]]], -1], 
              Plus[ 1, 
                Times[ 4, 
                  \[Bullet]var[ k]]]]], 
          Plus[ 1, 
            Times[ -1, 
              Power[ -1, 
                \[Bullet]fix[ n]], 
              Power[ 2, 
                Times[ -2, 
                  \[Bullet]fix[ n]]], 
              Power[ 
                Factorial[ 
                  \[Bullet]fix[ n]], -1], 
              Factorial[ 
                Times[ 2, 
                  \[Bullet]fix[ n]]], 
              Power[ 
                Factorial[ 
                  Plus[ 1, 
                    \[Bullet]fix[ n]]], -1]]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Proof:\\n\"\>", "\[InvisibleSpace]", "\<\"Let \"\>", 
        "\[InvisibleSpace]", 
        SubscriptBox[
          StyleBox["\[CapitalDelta]",
            FontColor->RGBColor[0.549996, 0, 0.8]], 
          StyleBox["k",
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]], 
        "\[InvisibleSpace]", "\<\" denote the forward difference operator in \
\"\>", "\[InvisibleSpace]", 
        StyleBox["k",
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[InvisibleSpace]", "\<\" then\\n\"\>", 
        "\[InvisibleSpace]", "\<\"the Theorem follows from summing the \
equation\\n\"\>", "\[InvisibleSpace]", 
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[\((\(-1\))\), 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]]}], " ", 
              SuperscriptBox["2", 
                RowBox[{\(-2\), " ", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"2", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  RowBox[{"4", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], 
            RowBox[{
              RowBox[{
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "!"}], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{\(-1\), "+", 
                  RowBox[{"2", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]], "=", 
          RowBox[{
            SubscriptBox[
              StyleBox["\[CapitalDelta]",
                FontColor->RGBColor[0.549996, 0, 0.8]], 
              StyleBox["k",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "[", 
            FractionBox[
              RowBox[{
                SuperscriptBox[\((\(-1\))\), 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]], " ", 
                SuperscriptBox["2", 
                  RowBox[{"1", "+", 
                    RowBox[{\(-2\), " ", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}]], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"2", " ", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "!"}], " ", 
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], 
              RowBox[{
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "!"}], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "!"}], " ", 
                RowBox[{"(", 
                  RowBox[{\(-1\), "+", 
                    RowBox[{"2", " ", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}]], "]"}]}], 
        "\[InvisibleSpace]", "\<\"\\n\"\>", 
        "\[InvisibleSpace]", "\<\"over the range \"\>", "\[InvisibleSpace]", 
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "=", "1"}], ",", "\[Ellipsis]", ",", 
          StyleBox["n",
            FontWeight->"Plain",
            FontSlant->"Plain",
            Background->None]}], "\[InvisibleSpace]", "\<\".\"\>"}],
      SequenceForm[ "Proof:\n", "Let ", 
        \[Trademark]\[CapitalDelta][ 
          \[Bullet]var[ k]], " denote the forward difference operator in ", 
        \[Bullet]var[ k], " then\n", 
        "the Theorem follows from summing the equation\n", 
        \[Trademark]Equal[ 
          Times[ -1, 
            Power[ -1, 
              \[Bullet]var[ k]], 
            Power[ 2, 
              Times[ -2, 
                \[Bullet]var[ k]]], 
            Power[ 
              Factorial[ 
                \[Bullet]var[ k]], -1], 
            Factorial[ 
              Times[ 2, 
                \[Bullet]var[ k]]], 
            Power[ 
              Factorial[ 
                Plus[ 1, 
                  \[Bullet]var[ k]]], -1], 
            Power[ 
              Plus[ -1, 
                Times[ 2, 
                  \[Bullet]var[ k]]], -1], 
            Plus[ 1, 
              Times[ 4, 
                \[Bullet]var[ k]]]], 
          \[Trademark]\[CapitalDelta][ 
            \[Bullet]var[ k], 
            Times[ 
              Power[ -1, 
                \[Bullet]var[ k]], 
              Power[ 2, 
                Plus[ 1, 
                  Times[ -2, 
                    \[Bullet]var[ k]]]], 
              Power[ 
                Factorial[ 
                  \[Bullet]var[ k]], -1], 
              Factorial[ 
                Times[ 2, 
                  \[Bullet]var[ k]]], 
              Power[ 
                Factorial[ 
                  Plus[ 1, 
                    \[Bullet]var[ k]]], -1], 
              Plus[ 1, 
                \[Bullet]var[ k]], 
              Power[ 
                Plus[ -1, 
                  Times[ 2, 
                    \[Bullet]var[ k]]], -1]]]], "\n", "over the range ", 
        \[Bullet]displayAsRange[ 
          \[Bullet]range[ 
            \[Bullet]integerRange[ 
              \[Bullet]var[ k], 1, 
              \[Bullet]fix[ n]]]], "."],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"The equation is routinely verifiable\\n\"\>", 
        "\[InvisibleSpace]", "\<\"by dividing the right\[Dash]hand side by \
the left\[Dash]hand side\\n\"\>", 
        "\[InvisibleSpace]", "\<\"and simplifying the resulting rational \
function\\n\"\>", "\[InvisibleSpace]", 
        FractionBox[
          RowBox[{
            FractionBox[
              RowBox[{
                SuperscriptBox[\((\(-1\))\), 
                  RowBox[{"1", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]], " ", 
                SuperscriptBox["2", 
                  RowBox[{"1", "+", 
                    RowBox[{\(-2\), " ", 
                      RowBox[{"(", 
                        RowBox[{"1", "+", 
                          StyleBox["k",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}]}]}]], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"2", " ", 
                      RowBox[{"(", 
                        RowBox[{"1", "+", 
                          StyleBox["k",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}]}], ")"}], "!"}], " ", 
                RowBox[{"(", 
                  RowBox[{"2", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "!"}], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"2", "+", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "!"}], " ", 
                RowBox[{"(", 
                  RowBox[{\(-1\), "+", 
                    RowBox[{"2", " ", 
                      RowBox[{"(", 
                        RowBox[{"1", "+", 
                          StyleBox["k",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}]}]}], ")"}]}]], "-", 
            FractionBox[
              RowBox[{
                SuperscriptBox[\((\(-1\))\), 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]], " ", 
                SuperscriptBox["2", 
                  RowBox[{"1", "+", 
                    RowBox[{\(-2\), " ", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}]], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"2", " ", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "!"}], " ", 
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], 
              RowBox[{
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "!"}], " ", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{"1", "+", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "!"}], " ", 
                RowBox[{"(", 
                  RowBox[{\(-1\), "+", 
                    RowBox[{"2", " ", 
                      StyleBox["k",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}]]}], 
          FractionBox[
            RowBox[{
              RowBox[{"-", 
                SuperscriptBox[\((\(-1\))\), 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]]}], " ", 
              SuperscriptBox["2", 
                RowBox[{\(-2\), " ", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"2", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  RowBox[{"4", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], 
            RowBox[{
              RowBox[{
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "!"}], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{\(-1\), "+", 
                  RowBox[{"2", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]]], 
        "\[InvisibleSpace]", "\<\"\\nto 1.\"\>"}],
      SequenceForm[ 
      "The equation is routinely verifiable\n", 
        "by dividing the right\[Dash]hand side by the left\[Dash]hand side\n",
         "and simplifying the resulting rational function\n", 
        \[Trademark]Divide[ 
          \[Trademark]Minus[ 
            Times[ 
              Power[ -1, 
                Plus[ 1, 
                  \[Bullet]var[ k]]], 
              Power[ 2, 
                Plus[ 1, 
                  Times[ -2, 
                    Plus[ 1, 
                      \[Bullet]var[ k]]]]], 
              Power[ 
                Factorial[ 
                  Plus[ 1, 
                    \[Bullet]var[ k]]], -1], 
              Factorial[ 
                Times[ 2, 
                  Plus[ 1, 
                    \[Bullet]var[ k]]]], 
              Power[ 
                Factorial[ 
                  Plus[ 2, 
                    \[Bullet]var[ k]]], -1], 
              Plus[ 2, 
                \[Bullet]var[ k]], 
              Power[ 
                Plus[ -1, 
                  Times[ 2, 
                    Plus[ 1, 
                      \[Bullet]var[ k]]]], -1]], 
            Times[ 
              Power[ -1, 
                \[Bullet]var[ k]], 
              Power[ 2, 
                Plus[ 1, 
                  Times[ -2, 
                    \[Bullet]var[ k]]]], 
              Power[ 
                Factorial[ 
                  \[Bullet]var[ k]], -1], 
              Factorial[ 
                Times[ 2, 
                  \[Bullet]var[ k]]], 
              Power[ 
                Factorial[ 
                  Plus[ 1, 
                    \[Bullet]var[ k]]], -1], 
              Plus[ 1, 
                \[Bullet]var[ k]], 
              Power[ 
                Plus[ -1, 
                  Times[ 2, 
                    \[Bullet]var[ k]]], -1]]], 
          Times[ -1, 
            Power[ -1, 
              \[Bullet]var[ k]], 
            Power[ 2, 
              Times[ -2, 
                \[Bullet]var[ k]]], 
            Power[ 
              Factorial[ 
                \[Bullet]var[ k]], -1], 
            Factorial[ 
              Times[ 2, 
                \[Bullet]var[ k]]], 
            Power[ 
              Factorial[ 
                Plus[ 1, 
                  \[Bullet]var[ k]]], -1], 
            Power[ 
              Plus[ -1, 
                Times[ 2, 
                  \[Bullet]var[ k]]], -1], 
            Plus[ 1, 
              Times[ 4, 
                \[Bullet]var[ k]]]]], "\nto 1."],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Again, the simplification can be accomplished by calling Mathematica's \
simplifier:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"System`FullSimplify", "[", 
      FractionBox[
        RowBox[{
          FractionBox[
            RowBox[{
              SuperscriptBox[\((\(-1\))\), 
                RowBox[{"1", "+", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]], " ", 
              SuperscriptBox["2", 
                RowBox[{"1", "+", 
                  RowBox[{\(-2\), " ", 
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        StyleBox["k",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}]}]}]], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        StyleBox["k",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{"2", "+", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], 
            RowBox[{
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"2", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{\(-1\), "+", 
                  RowBox[{"2", " ", 
                    RowBox[{"(", 
                      RowBox[{"1", "+", 
                        StyleBox["k",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}]}]}], ")"}]}]], "-", 
          FractionBox[
            RowBox[{
              SuperscriptBox[\((\(-1\))\), 
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]], " ", 
              SuperscriptBox["2", 
                RowBox[{"1", "+", 
                  RowBox[{\(-2\), " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}]], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"2", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], 
            RowBox[{
              RowBox[{
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "!"}], " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "!"}], " ", 
              RowBox[{"(", 
                RowBox[{\(-1\), "+", 
                  RowBox[{"2", " ", 
                    StyleBox["k",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]]}], 
        FractionBox[
          RowBox[{
            RowBox[{"-", 
              SuperscriptBox[\((\(-1\))\), 
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], " ", 
            SuperscriptBox["2", 
              RowBox[{\(-2\), " ", 
                StyleBox["k",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"2", " ", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "!"}], " ", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{"4", " ", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], 
          RowBox[{
            RowBox[{
              StyleBox["k",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "!"}], " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"1", "+", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "!"}], " ", 
            RowBox[{"(", 
              RowBox[{\(-1\), "+", 
                RowBox[{"2", " ", 
                  StyleBox["k",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}]]], "]"}]], "Input",
  Background->None],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Computing and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " within ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " "
}], "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["The Purpose of this Section", "Subsubsection",
  Background->None],

Cell[TextData[{
  "In this section, we demonstrate how ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " can be used in a way similar to Mathematica but with some additional \
functionalities:"
}], "Text"],

Cell[TextData[{
  "We demonstrate how all Mathematica functions can also be called from \
within ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "We demonstrate how, in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", the language construct \"functor\" can be used. This is an important \
construct that helps in structuring large mathematical  theories. The functor \
construct is not available in Mathematica. "
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"],

Cell[TextData[{
  "Finally, we demonstrate how ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " can be used in a special interactive style (which we call \"computational \
sessions\") that resembles the traditional input-evaluate-output style of \
Mathematica sessions. Note, however, that the syntax of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " (which we think is much closer to the usual syntax in mathematics \
textbooks) is preserved also in the computational sessions of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ". In particular, for example, the ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " notation for sets and operations on sets is exactly the one of set theory \
textbooks. This is in sharp contrast to Mathematica that uses set notation \
for tuples, which is quite confusing for mathematicians."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load Additionals", "Subsubsection",
  Background->None],

Cell["\<\
We first load a couple of built-in operations and special functions for \
demonstrating the functor construct.\
\>", "Text"],

Cell[BoxData[
    \(Use[{}]\)], "Input",
  Background->None],

Cell[BoxData[
    \(InitializeGlobals[Evaluator \[Rule] EvaluateFromInnermost]; 
    UseAlso[\[LeftAngleBracket]Built\[Dash]in["\<Quantifiers\>"], 
        Built\[Dash]in["\<Connectives\>"], Built\[Dash]in["\<Numbers\>"], 
        Built\[Dash]in["\<Tuples\>"], 
        Built\[Dash]in["\<Sets\>"]\[RightAngleBracket]]\)], "Input",
  Background->None],

Cell[BoxData[{
    \(ClearAll[LM]\), "\n", 
    \(LM[p_Plus] := Last[p]\), "\n", 
    \(LM[p_Times] := p\), "\n", 
    \(LM[p_Power] := p\), "\n", 
    \(LM[v_Symbol] := v\), "\n", 
    \(LM := c /; NumberQ[c]\)}], "Input",
  Background->None],

Cell[BoxData[{
    \(ClearAll[PP]\), "\n", 
    \(PP[Times[c_, pp___]] := Times[pp] /; NumberQ[c]\), "\n", 
    \(PP[c_] := 1 /; NumberQ[c]\), "\n", 
    \(PP[m_] := m\)}], "Input",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ClearAll[coefficient]\), "\n", 
    \(coefficient[Times[c_, pp___]] := c /; NumberQ[c]\), "\n", 
    \(coefficient[c_] := c /; NumberQ[c]\), "\n", 
    \(coefficient[m_] := 1\)}], "Input",
  Background->None],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(coefficient\)\" is \
similar to existing symbol \"\!\(Coefficient\)\"."\)], "Message"]
}, Open  ]],

Cell[BoxData[
    \(Remove[\[ScriptCapitalP]]\)], "Input",
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Make ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Functions Accessible"
}], "Subsubsection",
  Background->None],

Cell[TextData[{
  "Here is the way how functions form the Mathematica library or functions \
that had been defined by the user within Mathematica, like 'Expand', \
'PolynomialGCD', etc. can be made accessible, with new names, from within ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Built\[Dash]in",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Mathematica\>\"", ",", "\n", "\t", GridBox[{
            {\(polynomial \[Rule] Expand\)},
            {\(monomial \[Rule] Expand\)},
            {\(polynomial\[Dash]gcd \[Rule] PolynomialGCD\)},
            {\(polynomial\[Dash]lcm \[Rule] PolynomialLCM\)},
            {\(leading\[Dash]monomial \[Rule] LM\)},
            {\(power\[Dash]product \[Rule] PP\)},
            {\(are\[Dash]equal \[Rule] SameQ\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{"math", "Mathematica"}],

Cell[BoxData[
    \(UseAlso[\[LeftAngleBracket]Built\[Dash]in["\<Mathematica\>"]\
\[RightAngleBracket]]\)], "Input",
  Background->None,
  CellTags->"Mathematica"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define a Functor", "Subsubsection",
  Background->None],

Cell[TextData[{
  "Functors, like in ML etc., are a very powerful tool for building up and \
computing in 'towers' of abstract domains. By adding functors to ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ", everything that can be done e.g. in the system Axiom, can be done in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  ". Here is a first trivial functor that has no parameters and combines a \
couple of operations on polynomials (like '+', ..., 'gcd', etc.) in one \
\"domain\":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<Mathematica Polynomials\>\"", ",", "\n", "\t", 
        RowBox[{\(Mathematica\[Dash]Polynomials[]\), "=", 
          RowBox[{"Functor", "[", 
            RowBox[{
            "\[ScriptCapitalP]", ",", \(any[p, q, m, n]\), ",", "\n", "\t", 
              GridBox[{
                  {\(\[DoubleStruckS] = \[LeftAngleBracket]\
\[RightAngleBracket]\)},
                  {GridBox[{
                        {\(0\+\[ScriptCapitalP] = 0\)},
                        {\(p\( + \+\[ScriptCapitalP]\)q = 
                            polynomial[p + q]\)},
                        {\(\(-\+\[ScriptCapitalP] q\) = 
                            polynomial[\(-q\)]\)},
                        {\(p\( - \+\[ScriptCapitalP]\)q = 
                            polynomial[p - q]\)},
                        {\(1\+\[ScriptCapitalP] = 1\)},
                        {\(m\(*\+\[ScriptCapitalP]\)n = monomial[m\ *\ n]\)},
                        {\(m\(/\+\[ScriptCapitalP]\)n = monomial[m\ /\ n]\)},
                        {\(\((m\( \[VerticalBar] \+\[ScriptCapitalP]\)n)\)\
\[DoubleLongLeftRightArrow]\((are\[Dash]equal[power\[Dash]product[m], 
                                power\[Dash]product[
                                  polynomial\[Dash]gcd[m, n]]])\)\)},
                        {\(gcd\+\[ScriptCapitalP][m, n] = 
                            polynomial\[Dash]gcd[m, n]\)},
                        {\(lcm\+\[ScriptCapitalP][m, n] = 
                            polynomial\[Dash]lcm[m, n]\)},
                        {\(ldm\+\[ScriptCapitalP][p] = 
                            leading\[Dash]monomial[p]\)},
                        {\(rest\+\[ScriptCapitalP][p] = 
                            polynomial[p - leading\[Dash]monomial[p]]\)},
                        {\(poly\+\[ScriptCapitalP][m, p] = 
                            polynomial[m + p]\)}
                        },
                      ColumnAlignments->{Left}]}
                  },
                ColumnAlignments->{Left},
                RowLines->0.75]}], "\n", "\t", "]"}]}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"Mathematica Polynomials"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute in a Domain Defined by a Functor", "Subsubsection",
  Background->None],

Cell["\<\
Here is a call of the functor \"Mathematica\[Dash]Polynomials\" that creates \
a domain with name \"\[DoubleStruckCapitalP]\":\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], 
      "[", \("\<\[DoubleStruckCapitalP]\>", \n\t\[DoubleStruckCapitalP] = 
        Mathematica\[Dash]Polynomials[]\), "]"}]], "Input",
  Background->None,
  CellTags->{
  "\[DoubleStruckCapitalM]\[DoubleStruckCapitalP]", "\[DoubleStruckCapitalP]"}
    ],

Cell["\<\
The definition of the domain '\[DoubleStruckCapitalP]' and the functor \
'Mathematica-Polynomials' can now be combined in a theory:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<T\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<\[DoubleStruckCapitalP]\>"]\)},
            {\(Definition["\<Mathematica Polynomials\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  Background->None,
  CellTags->{"T", "\[DoubleStruckCapitalP]"}],

Cell[TextData[{
  "Now we can compute in the domain '\[DoubleStruckCapitalP]' by calling \
operations like '+', '*', etc. but with the distinctive subscript '\
\[DoubleStruckCapitalP]' that indicates that these operations are the ones \
defined in '\[DoubleStruckCapitalP]' (which may be completely different from \
the \"ordinary\" built-in operations of ",
  StyleBox["Theorema ",
    FontSlant->"Italic"],
  "and from the operations in other domains generated by other functors.)  In \
order to compute, for example,"
}], "Text"],

Cell[BoxData[
    \(\((\(x\^2\) 
          y\^2)\)\(*\+\[DoubleStruckCapitalP]\)\((\(-13\)/
            4\ x\ y)\)\)], "Input",
  Background->None],

Cell[TextData[{
  "we must, of course, tell ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " that we want it to use (only) the Theory[\"T\"]:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[\((\(x\^2\) 
            y\^2)\)\(*\+\[DoubleStruckCapitalP]\)\((\(-13\)/4\ x\ y)\), 
      using \[Rule] Theory["\<T\>"]]\)], "Input",
  Background->None],

Cell[TextData[{
  StyleBox[ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"Hyperlink"],
    FontFamily->"Times",
    FontColor->RGBColor[0.639994, 0, 1]],
  ":",
  "Definition",
  ":",
  StyleBox[ButtonBox["\[DoubleStruckCapitalP]",
    ButtonData:>"\[DoubleStruckCapitalP]",
    ButtonStyle->"Hyperlink"],
    FontFamily->"Times",
    FontColor->RGBColor[0.639994, 0, 1]]
}], "Message"],

Cell[TextData[{
  StyleBox[ButtonBox["T",
    ButtonData:>"T",
    ButtonStyle->"Hyperlink"],
    FontFamily->"Times",
    FontColor->RGBColor[0.639994, 0, 1]],
  ":",
  StyleBox[ButtonBox["Mathematica Polynomials",
    ButtonData:>"Mathematica Polynomials",
    ButtonStyle->"Hyperlink"],
    FontFamily->"Times",
    FontColor->RGBColor[0.639994, 0, 1]],
  ":",
  "Definition",
  ":",
  "6"
}], "Message"],

Cell[BoxData[
    \(\(-13\)\/4*x\^3*y\^3\)], "Output"]
}, Open  ]],

Cell["\<\
In addition to the result, we also obtain a trace of the most important steps \
in the evaluation. If we do not want to see this, we can turn the trace off \
by \
\>", "Text"],

Cell[BoxData[
    \(SetGlobals[TraceLevel \[Rule] 0]\)], "Input",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[\((\(x\^2\) 
            y\^2)\)\(/\+\[DoubleStruckCapitalP]\)\((\(-13\)/4\ x\ y)\), 
      using \[Rule] Theory["\<T\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(\(-4\)\/13*x*y\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[\((\(x\^2\) 
            y\^2)\)\( \[VerticalBar] \+\[DoubleStruckCapitalP]\)\((\(-13\)/
              4\ x\ y)\), using \[Rule] Theory["\<T\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[\((x\ y)\)\( \[VerticalBar] \+\[DoubleStruckCapitalP]\)\((\(-13\
\)/4\ x\^2\ y)\), using \[Rule] Theory["\<T\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extend a Functor", "Subsubsection",
  Background->None],

Cell["\<\
Now we demonstrate how a functor can be \"extended\" by adding more \
functions. This functor has a parameter: It depends on the domain '\
\[ScriptCapitalR]' which we want to extend:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Definition",
        FontWeight->"Bold"], "[", 
      RowBox[{
      "\"\<Reduction Domain\>\"", ",", \(any[\[ScriptCapitalP]]\), ",", "\n", 
        "\t", 
        RowBox[{\(Reduction\[Dash]Domain[\[ScriptCapitalP]]\), "=", 
          RowBox[{"Functor", "[", 
            
            RowBox[{\(\[LeftAngleBracket]\[ScriptCapitalR], 
                extends[\[ScriptCapitalP]]\[RightAngleBracket]\), 
              ",", \(any[p, q]\), ",", "\n", "\t", GridBox[{
                  {\(\[DoubleStruckS] = \[LeftAngleBracket]SP \[Colon] \
\[ScriptCapitalR]\[Cross]\[ScriptCapitalR] \[Rule] \[ScriptCapitalR]\
\[RightAngleBracket]\)},
                  {\(SP\+\[ScriptCapitalR][p, q] = 
                      where[\n\t
                        L = lcm\+\[ScriptCapitalP][ldm\+\[ScriptCapitalP][p], 
                            ldm\+\[ScriptCapitalP][q]], 
                        u = \((L\(/\+\[ScriptCapitalP]\)\((ldm\+\
\[ScriptCapitalP][p])\))\), 
                        v = \((L\(/\+\[ScriptCapitalP]\)\((ldm\+\
\[ScriptCapitalP][q])\))\), \n\t
                        u\(*\+\[ScriptCapitalP]\)rest\+\[ScriptCapitalP][
                              p]\( - \+\[ScriptCapitalP]\)v\(*\+\
\[ScriptCapitalP]\)rest\+\[ScriptCapitalP][q]]\)}
                  },
                ColumnAlignments->{Left},
                RowLines->0.75]}], "\n", "\t", "]"}]}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"Reduction Domain"],

Cell["\<\
The \"reduction domain\" of a given domain \[ScriptCapitalR] is identical to \
\[ScriptCapitalR] but provides also the function 'SP' (S-polynomial), which \
is defined exclusively in terms of the operations available in \
\[ScriptCapitalR]! The definition of SP is, hence, completely independent of \
the particular instance of the domain \[ScriptCapitalR].\
\>", "Text"],

Cell["\<\
Now we call this functor for generating the reduction domain of the \
Mathematica polynomials:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["Definition",
          FontWeight->"Bold"], 
        "[", \("\<RDMP\>", \n\t\[DoubleStruckCapitalP] = 
          Reduction\[Dash]Domain[Mathematica\[Dash]Polynomials[]]\), "]"}], 
      " "}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->"RDMP"],

Cell["\<\
We now combine all definitions that we need for computing in this domain in a \
theory:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox["Theory",
        FontWeight->"Bold"], "[", 
      RowBox[{"\"\<RDMP\>\"", ",", "\n", "\t", GridBox[{
            {\(Definition["\<RDMP\>"]\)},
            {\(Definition["\<Mathematica Polynomials\>"]\)},
            {\(Definition["\<Reduction Domain\>"]\)}
            },
          ColumnAlignments->{Left}]}], "]"}]], "Input",
  LimitsPositioningTokens->{},
  Background->None,
  CellTags->{"RD", "RDMP", "T", "\[DoubleStruckCapitalP]"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[\((x\ y\^2 - 3  x\ y\  + \ 
            x\^2)\)\( + \+\[DoubleStruckCapitalP]\)\((x\^2\ y\^2 + 
            3  x\ y\  + \ x\^2 - 3  x)\), 
      using \[Rule] Theory["\<RDMP\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(\(-3\)*x + 2*x\^2 + x*y\^2 + x\^2*y\^2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Compute[
      SP\+\[DoubleStruckCapitalP][\((x\ y\^3 - 3  x\ y\  + \ 
            x\^2)\), \((x\^2\ y\^2 + 3  x\ y\  + \ x\^2 - 3  x)\)], 
      using \[Rule] Theory["\<RDMP\>"]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(x\^3 + 3\ x\ y + \(-4\)\ x\^2\ y + \(-3\)\ x\ y\^2\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TextForm\`Theorema\ Computational\ Sessions\)], "Subsubsection",
  Background->None,
  CellTags->"computing-session"],

Cell[TextData[{
  "In a ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " computational session, like in a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, all definitions are automatically adjoined to a global knowledge \
base and 'Compute' need not be called explicitly. We enter a computational \
session by entering:"
}], "Text"],

Cell[BoxData[
    \(ComputationalSession[]\)], "Input",
  Background->None],

Cell["As an example, let's now do some computations with sets:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ \(i\)\( | \+\(i \[Element] {1, 2, 3}\)\)}\)], "Input",
  Background->None,
  CellTags->"sets"],

Cell[BoxData[
    \({1, 2, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ \((2\ i)\)\( | \+\(i = 1, \[Ellipsis], 3\)\)}\)], "Input",
  Background->None,
  CellTags->"sets"],

Cell[BoxData[
    \({2, 4, 6}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({i\( | \+\(i = 1, \[Ellipsis], 20\)\)is\[Dash]prime[i]}\)], "Input",
  Background->None],

Cell[BoxData[
    \({2, 3, 5, 7, 11, 13, 17, 19}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({2, 3, 1, 2, 3} = {1, 2, 3, 3, 3}\)], "Input",
  Background->None],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Note that this is true because the two terms, in fact, denote the same set:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({2, 3, 1, 2, 3}\)], "Input",
  Background->None],

Cell[BoxData[
    \({1, 2, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({1, 2, 3, 3, 3}\)], "Input",
  Background->None],

Cell[BoxData[
    \({1, 2, 3}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({1, 2, 1, 3} = {2, 1, 4, 3}\)], "Input",
  Background->None],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(2 \[Element] {2, 1, 2, 4}\)], "Input",
  Background->None],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Now we define two operations on sets that are not built in:", "Text"],

Cell[BoxData[
    RowBox[{\(any[IsSet[A, B]]\), "\[Colon]", "\n", "\t", GridBox[{
          {\(A\[CircleMinus]B := {\ 
                x\( | \+\(x \[Element] A\)\)\((x \[NotElement] B)\)}\)},
          {\(A \[SubsetEqual] 
                B := \[ForAll] \+\(x \[Element] A\)x \[Element] B\)}
          },
        ColumnAlignments->{Left}]}]], "Input",
  Background->None],

Cell[TextData[{
  "Note that these definitions are exactly in the style used in math \
textbooks, i.e. in ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " one can \"compute\" with ordinary mathematical formulae (as long as these \
formulae have an algorithmic meaning):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({2, 3, 1, 3}\[CircleMinus]{3, 5}\)], "Input",
  Background->None],

Cell[BoxData[
    \({1, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
Note that the new operator, before evaluating, checks whether the parameter \
terms denote sets. For example,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2\[CircleMinus]3\)], "Input",
  Background->None],

Cell[BoxData[
    \(2\[CircleMinus]3\)], "Output"]
}, Open  ]],

Cell["\<\
just stays unevaluated because the above definition of '\[CircleMinus]' was \
restricted to sets.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({3, 2, 5} \[SubsetEqual] {1, 2, 3, 4, 5}\)], "Input",
  Background->None],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["One can also check the type of objects:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(is\[Dash]set[{2, 3, 2}]\)], "Input",
  Background->None],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(is\[Dash]set[{2, 3}]\)], "Input",
  Background->None],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(is\[Dash]tuple[{2, 3, 2}]\)], "Input",
  Background->None],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(is\[Dash]tuple[\[LeftAngleBracket]2, 3, 
        2\[RightAngleBracket]]\)], "Input",
  Background->None],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
Some operators denote various different functions depending on the type of \
the objects provided as input:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftBracketingBar]\[LeftAngleBracket]2, 3, 
        2\[RightAngleBracket]\[RightBracketingBar]\)], "Input",
  Background->None],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftBracketingBar]{2, 3, 2}\[RightBracketingBar]\)], "Input",
  Background->None],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[LeftBracketingBar]\(-3\)\[RightBracketingBar]\)], "Input",
  Background->None],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell["\<\
The function '\[AE]' (\"an element in\") produces an element from a \
(non-empty) set:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[AE][{3}]\)], "Input",
  Background->None],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]],

Cell["\<\
Here is a property of the power set function that uses the function \[AE]:\
\>", "Text"],

Cell[BoxData[
    RowBox[{\(any[is\[Dash]set[A]]\), "\[Colon]", "\n", "\t", GridBox[{
          {\(\[GothicCapitalP][A] := {{}} \[DoubleLeftArrow] \((A = {})\)\)},
          {\(\[GothicCapitalP][A] := 
              where[a = \[AE][A], 
                P = \[GothicCapitalP][A\[CircleMinus]{a}], \ \n\t
                P \[Union] {\(({a} \[Union] 
                        B)\)\( | \+\(B \[Element] P\)\)}]\)}
          },
        ColumnAlignments->{Left}]}]], "Input",
  Background->None],

Cell[TextData[{
  "This property could be proved by the set prover. For finite sets ",
  StyleBox["A ",
    FontSlant->"Italic"],
  " this property can also be viewed as a recursive algorithm for computing \
the power set of ",
  StyleBox["A",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalP][{}]\)], "Input",
  Background->None],

Cell[BoxData[
    \({{}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalP][{3}]\)], "Input",
  Background->None],

Cell[BoxData[
    \({{}, {3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[GothicCapitalP][{1, 3}]\)\(\n\)\)\)], "Input",
  Background->None],

Cell[BoxData[
    \({{}, {1}, {3}, {1, 3}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalP][{1, 3, 4, 8}]\)], "Input",
  Background->None],

Cell[BoxData[
    \({{}, {1}, {3}, {4}, {8}, {1, 3}, {1, 4}, {1, 8}, {3, 4}, {3, 8}, {4, 
        8}, {1, 3, 4}, {1, 3, 8}, {1, 4, 8}, {3, 4, 8}, {1, 3, 4, 
        8}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We can go back to a standard session of ",
  StyleBox["Theorema",
    FontSlant->"Italic"],
  " by entering:"
}], "Text"],

Cell[BoxData[
    \(EndComputationalSession[]\)], "Input",
  Background->None],

Cell["\<\
Now the information on the power set function is not any more available:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[GothicCapitalP][{1, 3, 4, 8}]\)], "Input",
  Background->None],

Cell[BoxData[
    \(\[GothicCapitalP][{1, 3, 4, 8}]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Appendix:
Proofs\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["GCD", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["Divides Difference", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(divdiff)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["d",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["d",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[VerticalBar]", 
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                StyleBox["d",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[VerticalBar]", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "\[Implies]", 
            RowBox[{
              RowBox[{
                StyleBox["d",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[VerticalBar]", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "-", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], "\[And]", 
              RowBox[{
                StyleBox["d",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[VerticalBar]", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"divdiff"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(div:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["d",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["d",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[VerticalBar]", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["d",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["f",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "=", 
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"div:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(distr)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["d",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["u",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["v",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["d",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["u",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "=", 
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "\[And]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["d",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["v",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "=", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], "\[Implies]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["d",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["u",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "-", 
                      StyleBox["v",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], "=", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "-", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"distr"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(d\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[VerticalBar]", 
          StyleBox[\(m\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          StyleBox[\(d\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[VerticalBar]", 
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(d\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[VerticalBar]", 
          RowBox[{
            StyleBox[\(m\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "-", 
            StyleBox[\(n\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "\[And]", 
        RowBox[{
          StyleBox[\(d\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[VerticalBar]", 
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["2.1",
      ButtonData:>"2.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(d\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[VerticalBar]", 
        RowBox[{
          StyleBox[\(m\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "-", 
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["div:",
      ButtonData:>"div:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(d\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["f",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox[\(m\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(d\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(m\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["div:",
      ButtonData:>"div:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(d\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["f",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox[\(n\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(d\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(f\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(n\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"6"],

Cell[TextData[{
  "By modus ponens, from ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and an appropriate instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["distr",
      ButtonData:>"distr",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " follows:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(d\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "-", 
              StyleBox[\(f\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}], "=", 
        RowBox[{
          StyleBox[\(m\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "-", 
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2.1",
      ButtonData:>"2.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["div:",
      ButtonData:>"div:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(d\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["f",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox[\(m\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "-", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved because ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is an instance of it."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["2.2",
      ButtonData:>"2.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(d\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[VerticalBar]", 
        StyleBox[\(n\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2.2",
      ButtonData:>"2.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Analysis", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["4-ary Limit", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(lim+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{"max", "[", 
                  RowBox[{
                    StyleBox["M",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "]"}]}], "]"}]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"lim+"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l4:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["N",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[GreaterEqual]", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[Implies]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox["f",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "[", 
                          StyleBox["n",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}], "-", 
                        StyleBox["a",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "\[RightBracketingBar]"}], "<",
                     
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"l4:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(+:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "+", 
              RowBox[{
                StyleBox["g",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"+:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(| + |)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "-", 
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Delta]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "-", 
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "-", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["a",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["b",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"| + |"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(\[GreaterEqual]max )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              RowBox[{"max", "[", 
                RowBox[{
                  StyleBox["M1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["M1",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["M2",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"\[GreaterEqual]max "],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(M\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(N\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{"max", "[", 
            RowBox[{
              StyleBox[\(M\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(N\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l4:",
      ButtonData:>"l4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              StyleBox[\(M\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  StyleBox[\(a\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"3"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l4:",
      ButtonData:>"l4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              StyleBox[\(N\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(g\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  StyleBox[\(b\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["l4:",
      ButtonData:>"l4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              RowBox[{"max", "[", 
                RowBox[{
                  StyleBox[\(M\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox[\(N\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(g\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(a\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox[\(b\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox[\(\[Delta]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(\[Epsilon]\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[GreaterEqual]", 
        RowBox[{"max", "[", 
          RowBox[{
            StyleBox[\(M\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(N\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"6"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], "\[RightBracketingBar]"}], 
        "<", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[GreaterEqual]",
      ButtonData:>"\[GreaterEqual]max ",
      ButtonStyle->"Hyperlink"],
    ButtonBox["max ",
      ButtonData:>"\[GreaterEqual]max ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", 
          StyleBox[\(M\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          StyleBox[\(n\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "\[GreaterEqual]", 
          StyleBox[\(N\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8.1",
      ButtonData:>"8.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Delta]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8.2",
      ButtonData:>"8.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Epsilon]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["+:",
      ButtonData:>"+:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  StyleBox[\(n\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}], "+", 
                RowBox[{
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  StyleBox[\(n\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}]}], ")"}], "-", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], "\[RightBracketingBar]"}], 
        "<", 
        RowBox[{
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  ","
}], "Text"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["| + |",
      ButtonData:>"| + |",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(f\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(n\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "-", 
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(g\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(n\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "-", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["11.1",
      ButtonData:>"11.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Delta]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11.1",
      ButtonData:>"11.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["11.2",
      ButtonData:>"11.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(n\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Epsilon]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11.2",
      ButtonData:>"11.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3-ary Limit", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"l3+"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(lim+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{"max", "[", 
                  RowBox[{
                    StyleBox["M",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "]"}]}], "]"}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"lim+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[Exists]", 
                RowBox[{
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["N",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"l3:"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l3:",
      ButtonData:>"l3:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Delta]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(N\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l3:",
      ButtonData:>"l3:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take appropriate values such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(N\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"6"],

Cell[TextData[{
  "By modus ponens, from ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and an appropriate instance of ",
  Cell[TextData[{
    "(",
    ButtonBox["lim+",
      ButtonData:>"lim+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " follows:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(\[Delta]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{"max", "[", 
            RowBox[{
              StyleBox[\(N\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(N\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "]"}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["l3:",
      ButtonData:>"l3:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[Exists]", 
          RowBox[{
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"limit", "[", 
          RowBox[{
            RowBox[{
              StyleBox[\(f\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(g\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            RowBox[{
              StyleBox[\(\[Delta]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ",", 
            StyleBox["N",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is proved because ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is an instance of it."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2-ary Limit", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"l2+"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ">", "0"}], "\[Implies]", 
                  RowBox[{"limit", "[", 
                    RowBox[{
                      StyleBox["f",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["a",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["\[Epsilon]",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "]"}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"l2:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l3+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  FractionBox[
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "2"]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  FractionBox[
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "2"]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"l3+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(/2>)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ">", "0"}], "\[Implies]", 
            RowBox[{
              FractionBox[
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], ">", "0"}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"/2>"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l2:",
      ButtonData:>"l2:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ">", "0"}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox[\(f\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"3"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l2:",
      ButtonData:>"l2:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ">", "0"}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox[\(g\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["l2:",
      ButtonData:>"l2:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ">", "0"}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox[\(f\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(g\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox[\(a\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(b\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"6"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["/2>",
      ButtonData:>"/2>",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        FractionBox[
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "2"], ">", "0"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "2"]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"11"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "2"]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"12"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["l3+",
      ButtonData:>"l3+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            FractionBox[
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "2"]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            FractionBox[
              StyleBox[\(\[Epsilon]\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "2"]}], "]"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["13.1",
      ButtonData:>"13.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(f\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "2"]}], "]"}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["13.1",
      ButtonData:>"13.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["12",
      ButtonData:>"12",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["13.2",
      ButtonData:>"13.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          StyleBox[\(g\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          FractionBox[
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "2"]}], "]"}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["13.2",
      ButtonData:>"13.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuity of Product", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(cont[ * ])", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["f2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"continuous", "[", 
                RowBox[{
                  StyleBox["f1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"continuous", "[", 
                RowBox[{
                  StyleBox["f2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Epsilon]2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["\[Delta]2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"continuous", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["f2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Epsilon]1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox["\[Epsilon]2",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{"\[LeftBracketingBar]", 
                          RowBox[{
                            StyleBox["f2",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "[", 
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}], 
                          "\[RightBracketingBar]"}]}], ")"}]}], "+", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["f1",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "[", 
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}], "\[RightBracketingBar]"}],
                     "*", 
                    StyleBox["\[Epsilon]2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ",", 
                RowBox[{"min", "[", 
                  RowBox[{
                    StyleBox["\[Delta]1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["\[Delta]2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "]"}]}], "]"}]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"cont[ * ]"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(c4:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"continuous", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["\[Delta]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "-", 
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "\[RightBracketingBar]"}], "<",
                     
                    StyleBox["\[Delta]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[Implies]", 
                  RowBox[{
                    RowBox[{"\[LeftBracketingBar]", 
                      RowBox[{
                        RowBox[{
                          StyleBox["f",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "[", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}], "-", 
                        RowBox[{
                          StyleBox["f",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "[", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}]}], 
                      "\[RightBracketingBar]"}], "<", 
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"c4:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f*g)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "*", 
              RowBox[{
                StyleBox["g",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"f*g"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(| * |)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["a2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["b1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "-", 
                    StyleBox["a1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Delta]1",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox["b2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "-", 
                    StyleBox["a2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Delta]2",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox["b1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["b2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "-", 
                  RowBox[{
                    StyleBox["a1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["a2",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "\[RightBracketingBar]"}], "<", 
              RowBox[{
                RowBox[{
                  StyleBox["\[Delta]1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["\[Delta]2",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        StyleBox["b2",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "\[RightBracketingBar]"}]}], 
                    ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    StyleBox["b1",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[RightBracketingBar]"}], "*", 
                  StyleBox["\[Delta]2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"| * |"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(min<)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "<", 
              RowBox[{"min", "[", 
                RowBox[{
                  StyleBox["M1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "<", 
                StyleBox["M1",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "<", 
                StyleBox["M2",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"min<"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(x\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"continuous", "[", 
          RowBox[{
            StyleBox[\(f2\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(x\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]2\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"continuous", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(f2\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          StyleBox[\(x\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          RowBox[{
            RowBox[{
              StyleBox[\(\[Epsilon]1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(\[Epsilon]2\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f2\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox[\(x\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], "\[RightBracketingBar]"}]}],
                 ")"}]}], "+", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox[\(f1\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  StyleBox[\(x\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}], "\[RightBracketingBar]"}], "*", 
              
              StyleBox[\(\[Epsilon]2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ",", 
          RowBox[{"min", "[", 
            RowBox[{
              StyleBox[\(\[Delta]1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], ",", 
              StyleBox[\(\[Delta]2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "]"}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["c4:",
      ButtonData:>"c4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox[\(x\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "-", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Delta]1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f1\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  RowBox[{
                    StyleBox[\(f1\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}]}], "\[RightBracketingBar]"}], 
              "<", 
              StyleBox[\(\[Epsilon]1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"3"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["c4:",
      ButtonData:>"c4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox[\(x\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "-", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox[\(\[Delta]2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f2\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  RowBox[{
                    StyleBox[\(f2\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}]}], "\[RightBracketingBar]"}], 
              "<", 
              StyleBox[\(\[Epsilon]2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["c4:",
      ButtonData:>"c4:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  StyleBox[\(x\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "-", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              RowBox[{"min", "[", 
                RowBox[{
                  StyleBox[\(\[Delta]1\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox[\(\[Delta]2\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f1\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(f2\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(f1\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(f2\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}], "[", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}]}], "\[RightBracketingBar]"}], 
              "<", 
              RowBox[{
                RowBox[{
                  StyleBox[\(\[Epsilon]1\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(\[Epsilon]2\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          StyleBox[\(f2\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "[", 
                          StyleBox[\(x\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "]"}], 
                        "\[RightBracketingBar]"}]}], ")"}]}], "+", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox[\(f1\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox[\(x\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], "\[RightBracketingBar]"}], 
                  "*", 
                  StyleBox[\(\[Epsilon]2\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            StyleBox[\(x\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "-", 
            StyleBox[\(y\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "\[RightBracketingBar]"}], "<", 
        RowBox[{"min", "[", 
          RowBox[{
            StyleBox[\(\[Delta]1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(\[Delta]2\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"6"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(f1\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(f2\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(f1\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(f2\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox[\(y\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], "\[RightBracketingBar]"}], "<", 
        RowBox[{
          RowBox[{
            StyleBox[\(\[Epsilon]1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(\[Epsilon]2\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f2\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "\[RightBracketingBar]"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{
                StyleBox[\(f1\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "\[RightBracketingBar]"}], "*", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["min<",
      ButtonData:>"min<",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "-", 
              StyleBox[\(y\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]1\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "-", 
              StyleBox[\(y\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "\[RightBracketingBar]"}], "<", 
          StyleBox[\(\[Delta]2\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8.1",
      ButtonData:>"8.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(f1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            RowBox[{
              StyleBox[\(f1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(y\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Epsilon]1\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["8.2",
      ButtonData:>"8.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(f2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            RowBox[{
              StyleBox[\(f2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(y\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Epsilon]2\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["f*g",
      ButtonData:>"f*g",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\(f1\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "*", 
              RowBox[{
                StyleBox[\(f2\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}], "-", 
            RowBox[{
              RowBox[{
                StyleBox[\(f1\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(y\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "*", 
              RowBox[{
                StyleBox[\(f2\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(y\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]}], "\[RightBracketingBar]"}], 
        "<", 
        RowBox[{
          RowBox[{
            StyleBox[\(\[Epsilon]1\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(\[Epsilon]2\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    StyleBox[\(f2\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox[\(x\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "\[RightBracketingBar]"}]}], 
              ")"}]}], "+", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{
                StyleBox[\(f1\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "\[RightBracketingBar]"}], "*", 
            StyleBox[\(\[Epsilon]2\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"],
  ","
}], "Text"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["| * |",
      ButtonData:>"| * |",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(f1\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "-", 
              RowBox[{
                StyleBox[\(f1\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(y\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}], "\[RightBracketingBar]"}], "<", 
          
          StyleBox[\(\[Epsilon]1\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "\[And]", 
        RowBox[{
          RowBox[{"\[LeftBracketingBar]", 
            RowBox[{
              RowBox[{
                StyleBox[\(f2\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(x\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "-", 
              RowBox[{
                StyleBox[\(f2\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox[\(y\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}], "\[RightBracketingBar]"}], "<", 
          
          StyleBox[\(\[Epsilon]2\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "We prove the individual conjunctive parts of ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["11.1",
      ButtonData:>"11.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(f1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            RowBox[{
              StyleBox[\(f1\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(y\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Epsilon]1\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11.1",
      ButtonData:>"11.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["11.2",
      ButtonData:>"11.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
          RowBox[{
            RowBox[{
              StyleBox[\(f2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(x\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "-", 
            RowBox[{
              StyleBox[\(f2\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              StyleBox[\(y\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}]}], "\[RightBracketingBar]"}], "<", 
        StyleBox[\(\[Epsilon]2\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression",
    FontColor->RGBColor[1, 0, 0]],
  ":"
}], "Text"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11.2",
      ButtonData:>"11.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\"Prove - Compute - Solve\"", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["2-ary Limit with PCS", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l2+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}], "\[And]", 
              RowBox[{"limit", "[", 
                RowBox[{
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{"limit", "[", 
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ",", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], "]"}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"l2+"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(l)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"limit", "[", 
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox[
                UnderscriptBox["\[ForAll]", 
                  RowBox[{
                    StyleBox["\[Epsilon]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ">", "0"}]], 
              RowBox[{
                UnderscriptBox["\[Exists]", 
                  RowBox[{
                    StyleBox["N",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{
                  UnderscriptBox[
                    UnderscriptBox["\[ForAll]", 
                      RowBox[{
                        StyleBox["n",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], " "}]], 
                    RowBox[{
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "\[GreaterEqual]", 
                      StyleBox["N",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]], 
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{"\[LeftBracketingBar]", 
                        RowBox[{
                          RowBox[{
                            StyleBox["f",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "[", 
                            StyleBox["n",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "]"}], "-", 
                          StyleBox["a",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "\[RightBracketingBar]"}], 
                      "<", 
                      StyleBox["\[Epsilon]",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}]}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"l"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(dist+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["z",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["t",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Delta]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["z",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "-", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["t",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}]}], 
                "\[RightBracketingBar]"}], "<", 
              RowBox[{
                StyleBox["\[Delta]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "\[DoubleLeftArrow]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "-", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "\[RightBracketingBar]"}], "<", 
                  StyleBox["\[Delta]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[And]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      StyleBox["z",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "-", 
                      StyleBox["t",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "\[RightBracketingBar]"}], "<", 
                  StyleBox["\[Epsilon]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"dist+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(f+g)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["g",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["f",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["g",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "[", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["f",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}], "+", 
              RowBox[{
                StyleBox["g",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"f+g"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(max\[GreaterEqual])", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M1",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["M2",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              RowBox[{"max", "[", 
                RowBox[{
                  StyleBox["M1",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["M2",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "]"}]}], "\[Implies]", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["M1",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "\[And]", 
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["M2",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"max\[GreaterEqual]"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}], "\[And]", 
        RowBox[{"limit", "[", 
          RowBox[{
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "]"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"limit", "[", 
        RowBox[{
          RowBox[{
            StyleBox[\(f\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(g\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ",", 
          RowBox[{
            StyleBox[\(a\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(b\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.1",
      ButtonData:>"1.1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l",
      ButtonData:>"l",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ">", "0"}]], 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["N",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["N",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], "-", 
                    StyleBox[\(a\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"3"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take an appropriate Skolem function such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              RowBox[{
                StyleBox[\(N\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(f\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  StyleBox[\(a\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1.2",
      ButtonData:>"1.2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["l",
      ButtonData:>"l",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ">", "0"}]], 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["N",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["N",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], "-", 
                    StyleBox[\(b\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "By ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we can take an appropriate Skolem function such that:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ">", "0"}]], 
        RowBox[{
          UnderscriptBox[
            UnderscriptBox["\[ForAll]", 
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[GreaterEqual]", 
              RowBox[{
                StyleBox[\(N\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "[", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "]"}]}]], 
          RowBox[{"(", 
            RowBox[{
              RowBox[{"\[LeftBracketingBar]", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(g\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "]"}], "-", 
                  StyleBox[\(b\_0\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[RightBracketingBar]"}], "<", 
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"6"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["l",
      ButtonData:>"l",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["\[Epsilon]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            StyleBox["\[Epsilon]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ">", "0"}]], 
        RowBox[{
          UnderscriptBox["\[Exists]", 
            RowBox[{
              StyleBox["N",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox["N",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"\[LeftBracketingBar]", 
                  RowBox[{
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(f\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          StyleBox[\(g\_0\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}], "[", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], "-", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(a\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        StyleBox[\(b\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], ")"}]}], 
                  "\[RightBracketingBar]"}], "<", 
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(\[Epsilon]\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], ">", "0"}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"8"],

Cell["and have to find an N* such that", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "\[GreaterEqual]", 
            SuperscriptBox[
              StyleBox["N",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*"]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox[\(g\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "[", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "]"}], "-", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(a\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(b\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], "\[RightBracketingBar]"}],
             "<", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["f+g",
      ButtonData:>"f+g",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox[
          UnderscriptBox["\[ForAll]", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], " "}]], 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "\[GreaterEqual]", 
            StyleBox[\(N\^*\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"\[LeftBracketingBar]", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(f\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}], "+", 
                    RowBox[{
                      StyleBox[\(g\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "[", 
                      StyleBox["n",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "]"}]}], ")"}], "-", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(a\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(b\_0\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], "\[RightBracketingBar]"}],
             "<", 
            StyleBox[\(\[Epsilon]\_0\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["dist+",
      ButtonData:>"dist+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is proved if we can find \[Delta]*, \[Epsilon]* such that"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{\(\(\[Delta]\^*\) + \(\[Epsilon]\^*\)\), "=", 
        RowBox[{
          StyleBox[\(\[Epsilon]\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "  ", "\[And]", 
          RowBox[{
            UnderscriptBox[
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], " "}]], 
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "\[GreaterEqual]", 
                StyleBox[\(N\^*\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]], 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(f\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "[", 
                        StyleBox["n",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}], "-", 
                      StyleBox[\(a\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "\[RightBracketingBar]"}], "<", 
                  StyleBox[\(\[Delta]\^*\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[And]", 
                RowBox[{
                  RowBox[{"\[LeftBracketingBar]", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(g\_0\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "[", 
                        StyleBox["n",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "]"}], "-", 
                      StyleBox[\(b\_0\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "\[RightBracketingBar]"}], "<", 
                  StyleBox[\(\[Epsilon]\^*\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " and (",
  ButtonBox["4",
    ButtonData:>"4",
    ButtonStyle->"Hyperlink"],
  ") is,  implied by:"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example: Set Theory Proving", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["Classes Modulo Symmetric Predicates", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["\<\
(symm\[Implies]\[LeftFloor]\[RightFloor])\
\>", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Tilde]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"is\[Dash]symmetric", "[", 
              StyleBox["\[Tilde]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "\[Implies]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[Element]", 
                    SubscriptBox[
                      RowBox[{"(", 
                        RowBox[{"\[LeftFloor]", 
                          StyleBox["b",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[RightFloor]"}], ")"}], 
                      StyleBox["\[Tilde]",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]]}], "\[Implies]", 
                  RowBox[{
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[Element]", 
                    SubscriptBox[
                      RowBox[{"(", 
                        RowBox[{"\[LeftFloor]", 
                          StyleBox["a",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "\[RightFloor]"}], ")"}], 
                      StyleBox["\[Tilde]",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]]}]}], ")"}]}]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"symm\[Implies]\[LeftFloor]\[RightFloor]"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(symm:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Tilde]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"is\[Dash]symmetric", "[", 
              StyleBox["\[Tilde]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "]"}], "\[DoubleLeftRightArrow]", 
            RowBox[{
              UnderscriptBox["\[ForAll]", 
                RowBox[{
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], ",", 
                  StyleBox["b",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]], 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox["\[Tilde]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    RowBox[{
                      StyleBox["a",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["b",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "]"}], "\[Implies]", 
                  RowBox[{
                    StyleBox["\[Tilde]",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "[", 
                    RowBox[{
                      StyleBox["b",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], ",", 
                      StyleBox["a",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "]"}]}], ")"}]}]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"symm:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["\<\
(\[LeftFloor] \[RightFloor]:)\
\>", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["\[Tilde]",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            SubscriptBox[
              RowBox[{"(", 
                RowBox[{"\[LeftFloor]", 
                  StyleBox["a",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "\[RightFloor]"}], ")"}], 
              StyleBox["\[Tilde]",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]], "=", 
            RowBox[{"{", 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], 
                UnderscriptBox["\[VerticalSeparator]", 
                  RowBox[{
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], " "}]], 
                RowBox[{
                  StyleBox["\[Tilde]",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "[", 
                  RowBox[{
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], ",", 
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "]"}]}], "}"}]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"\[LeftFloor] \[RightFloor]:"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{"is\[Dash]symmetric", "[", 
        StyleBox[\( \[Tilde] \_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "]"}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"1"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["a",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", 
              SubscriptBox[
                RowBox[{"(", 
                  RowBox[{"\[LeftFloor]", 
                    StyleBox["b",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[RightFloor]"}], ")"}], 
                StyleBox[\( \[Tilde] \_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}], "\[Implies]", 
            RowBox[{
              StyleBox["b",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[Element]", 
              SubscriptBox[
                RowBox[{"(", 
                  RowBox[{"\[LeftFloor]", 
                    StyleBox["a",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "\[RightFloor]"}], ")"}], 
                StyleBox[\( \[Tilde] \_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"2"],

Cell["We assume", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(a\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[Element]", 
        SubscriptBox[
          RowBox[{"(", 
            RowBox[{"\[LeftFloor]", 
              StyleBox[\(b\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[RightFloor]"}], ")"}], 
          StyleBox[\( \[Tilde] \_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"3"],

Cell["and show", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(b\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[Element]", 
        SubscriptBox[
          RowBox[{"(", 
            RowBox[{"\[LeftFloor]", 
              StyleBox[\(a\_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "\[RightFloor]"}], ")"}], 
          StyleBox[\( \[Tilde] \_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["\[LeftFloor]",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ButtonBox[" ",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ButtonBox["\[RightFloor]",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ButtonBox[":",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(a\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[Element]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            UnderscriptBox["\[VerticalSeparator]", 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              StyleBox[\( \[Tilde] \_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(b\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], "}"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"5"],

Cell[TextData[{
  "From ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " we know"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\( \[Tilde] \_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "[", 
        RowBox[{
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"6"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["symm:",
      ButtonData:>"symm:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["a",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\( \[Tilde] \_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              RowBox[{
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}], "\[Implies]", 
            RowBox[{
              StyleBox[\( \[Tilde] \_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["a",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"7"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", by ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", implies:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\( \[Tilde] \_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "[", 
        RowBox[{
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", using ",
  Cell[TextData[{
    "(",
    ButtonBox["\[LeftFloor]",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ButtonBox[" ",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ButtonBox["\[RightFloor]",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ButtonBox[":",
      ButtonData:>"\[LeftFloor] \[RightFloor]:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(b\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[Element]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            UnderscriptBox["\[VerticalSeparator]", 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              StyleBox[\( \[Tilde] \_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], "}"}]}]], "Conclusion"],
  ","
}], "Text"],

Cell[TextData[{
  "which, using ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ", is implied by:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(b\_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "\[Element]", 
        RowBox[{"{", 
          RowBox[{
            StyleBox["b",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], 
            UnderscriptBox["\[VerticalSeparator]", 
              RowBox[{
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], " "}]], 
            RowBox[{
              StyleBox[\( \[Tilde] \_0\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "[", 
              RowBox[{
                StyleBox[\(a\_0\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], ",", 
                StyleBox["b",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "]"}]}], "}"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "In order to prove ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink",
      ButtonNote->"Membership in an abstraction"],
    ")"
  }], "Label"],
  " we have to show:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\( \[Tilde] \_0\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "[", 
        RowBox[{
          StyleBox[\(a\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], ",", 
          StyleBox[\(b\_0\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "]"}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "Formula ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is true because it is identical to ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Commutativity of Addition", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["Proof Attempt", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + = )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" + = "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" + .:"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" + = ",
      ButtonData:>" + = ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" + = ",
      ButtonData:>" + = ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", "0"}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"4"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"]
}], "Assumption",
  CellTags->"7"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"9"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"14"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Assumption"]
}], "Assumption",
  CellTags->"12"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"18"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"16"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cascade: Lemmata Generation", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["First Step: A Failing Proof of Commutativity of Addition", \
"Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + = )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" + = "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" + .:"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" + = ",
      ButtonData:>" + = ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" + = ",
      ButtonData:>" + = ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", "0"}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"4"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"5"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["5",
      ButtonData:>"5",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"]
}], "Assumption",
  CellTags->"7"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"8"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["8",
      ButtonData:>"8",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"9"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"11"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["11",
      ButtonData:>"11",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"14"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Assumption"]
}], "Assumption",
  CellTags->"12"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"18"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(No applicable inference rule was found.)"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(16)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"16"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second Step: A First Automatically Generated Lemma", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"19"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" + .:"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(0 + 0 = 0\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"20"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["20",
      ButtonData:>"20",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(21)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Assumption"]
}], "Assumption",
  CellTags->"21"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(22)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"22"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["22",
      ButtonData:>"22",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["21",
      ButtonData:>"21",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Third Step:  Proof Attempt of Commutativity of Addition With Increased \
Knowledge\
\>", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + = )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" + = "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"19"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" + .:"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[" + = ",
      ButtonData:>" + = ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(The Simplifier was unable to transform the proof situation.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" + = ",
      ButtonData:>" + = ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(20)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"20"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: proved", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["20",
      ButtonData:>"20",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(23)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"23"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["23",
      ButtonData:>"23",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Alternative proof 2: pending", "Text"],

Cell[TextData[Cell[TextData[{
  "Pending proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["20",
      ButtonData:>"20",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"]], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(21)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"21"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(22)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"22"],

Cell["\<\
As there are several methods which can be applied, we have different choices \
to proceed with the proof.\
\>", "Text"],

Cell["Alternative proof 1: failed", "Text"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["22",
      ButtonData:>"22",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(24)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"24"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(25)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"25"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["25",
      ButtonData:>"25",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(26)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"26"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["26",
      ButtonData:>"26",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(27)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Assumption"]
}], "Assumption",
  CellTags->"27"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(28)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"28"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["28",
      ButtonData:>"28",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["27",
      ButtonData:>"27",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(29)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], ")"}], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"29"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["29",
      ButtonData:>"29",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(No applicable inference rule was found.)"
}], "Text"],

Cell["Alternative proof 2: failed", "Text"],

Cell[TextData[{
  "We",
  " try to ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["22",
      ButtonData:>"22",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(30)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", "0"}], "=", 
        RowBox[{"0", "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"30"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["30",
      ButtonData:>"30",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(31)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"31"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(32)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"32"],

Cell[TextData[{
  "We simplify ",
  Cell[TextData[{
    "(",
    ButtonBox["32",
      ButtonData:>"32",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["31",
      ButtonData:>"31",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(n\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(33)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], ")"}], "+"], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_4\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"33"],

Cell[TextData[{
  "The proof of ",
  Cell[TextData[{
    "(",
    ButtonBox["33",
      ButtonData:>"33",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  "fails.",
  "(No applicable inference rule was found.)"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fourth Step:  A Second Automatically Generated Lemma", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(34)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"34"],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"19"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" + .:"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["34",
      ButtonData:>"34",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(35)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(0\^+\), "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"35"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["35",
      ButtonData:>"35",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(38)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"0", "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"38"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "+", 
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{"0", "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        StyleBox[\(m\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(39)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{\(0\^+\), "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"39"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["39",
      ButtonData:>"39",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(40)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\(0\^+\) + 0 = \(0\^+\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"40"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["40",
      ButtonData:>"40",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\) + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\(0\^+\)\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(41)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          StyleBox[\(m\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          StyleBox[\(m\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Assumption"]
}], "Assumption",
  CellTags->"41"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(42)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{\(0\^+\), "+", 
          SuperscriptBox[
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(m\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"42"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["42",
      ButtonData:>"42",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\(0\^+\), "+", 
        SuperscriptBox[
          StyleBox[\(m\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{\(0\^+\), "+", 
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["41",
      ButtonData:>"41",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(m\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(36)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"36"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(37)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[\(n\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], ")"}], "+"], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"37"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["37",
      ButtonData:>"37",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(43)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          StyleBox[\(m\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox[\(m\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"43"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", 
        StyleBox[\(m\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            StyleBox[\(m\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["36",
      ButtonData:>"36",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                StyleBox[\(m\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(44)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[\(n\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], ")"}], "+"], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      StyleBox["m",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "+"], ")"}], "+"]}], 
          ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"44"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["44",
      ButtonData:>"44",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(45)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", "0"}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", "0"}], ")"}], "+"], ")"}], 
          "+"]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"45"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["45",
      ButtonData:>"45",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", "0"}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", "0"}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(46)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          StyleBox[\(m\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox[\(m\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"], ")"}], "+"]}]], 
    "Assumption"]
}], "Assumption",
  CellTags->"46"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(47)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], ")"}], "+"], "+", 
          SuperscriptBox[
            StyleBox[\(m\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  SuperscriptBox[
                    StyleBox[\(m\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "+"], ")"}], "+"]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"47"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["47",
      ButtonData:>"47",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            SuperscriptBox[
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], ")"}], "+"], "+", 
        SuperscriptBox[
          StyleBox[\(m\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[\(n\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], ")"}], "+"], "+", 
            StyleBox[\(m\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["46",
      ButtonData:>"46",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(m\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], ")"}], "+"], ")"}], 
        "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                SuperscriptBox[
                  StyleBox[\(m\_4\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "+"], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          SuperscriptBox[
            RowBox[{"(", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    StyleBox[\(m\_4\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+"], ")"}], "+"], ")"}], 
        "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fifth Step: A Successful Proof of Commutativity of Addition", \
"Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + = )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->" + = "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(34)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"34"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"19"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0:"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + .:)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->" + .:"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox[" + = ",
      ButtonData:>" + = ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(35)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"35"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["35",
      ButtonData:>"35",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(38)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", "0"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"38"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["38",
      ButtonData:>"38",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", "0"}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0:",
      ButtonData:>" +0:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      StyleBox[\(n\_1\),
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(36)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"36"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(37)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"37"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["37",
      ButtonData:>"37",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(39)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"39"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["39",
      ButtonData:>"39",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["34",
      ButtonData:>"34",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["36",
      ButtonData:>"36",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + .:",
      ButtonData:>" + .:",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Associativity of Multiplication", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["\<\
Using Associativity and Commutativity as Part of the Knowledge Base\
\>", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"( * ) * "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *  ^+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" *  ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( ^+*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" ^+*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" + "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( + ) + )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"],
  "."
}], "Assumption",
  CellTags->"( + ) + "],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * ",
      ButtonData:>"( * ) * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "*", 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "*", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"5"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{"0", "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}]}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{"0", "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}], ")"}], "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}], "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\((0 + 0)\), "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(17)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", "0"}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", "0"}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", "0"}]}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"17"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["17",
      ButtonData:>"17",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "*", "0"}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", "0"}]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", "0"}], "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", "0"}], ")"}]}]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", "0"}], ")"}]}]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", "0"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(18)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          StyleBox[\(p\_6\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"18"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(19)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            SuperscriptBox[
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"19"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["19",
      ButtonData:>"19",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "*", 
        SuperscriptBox[
          StyleBox[\(p\_6\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          StyleBox[\(p\_6\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["18",
      ButtonData:>"18",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+", 
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}], ")"}], "+"]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_6\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(p\_6\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["^++ ",
      ButtonData:>"^++ ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}], "+", 
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_6\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}], "+"]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_6\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_6\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_6\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
            "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["( + ) + ",
      ButtonData:>"( + ) + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "+", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ",
      ButtonData:>" + ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_6\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(p\_6\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_6\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using Associativity and Commutativity as Inference Rules", \
"Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(( * ) * )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->"( * ) * "],

Cell["under the assumptions:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "=", "0"}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" *0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( *  ^+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" *  ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", "0"}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( ^+*)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" ^+*"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( +0)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", "0"}], "=", 
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->" +0"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["( + ^+)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["m",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              SuperscriptBox[
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  ","
}], "Assumption",
  CellTags->" + ^+"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(0+ )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"0", "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Assumption"],
  ","
}], "Assumption",
  CellTags->"0+ "],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(^++ )", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["m",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              StyleBox["n",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            SuperscriptBox[
              RowBox[{"(", 
                RowBox[{
                  StyleBox["m",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "+"]}], ")"}]}]], 
    "Assumption"],
  "."
}], "Assumption",
  CellTags->"^++ "],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["( * ) * ",
      ButtonData:>"( * ) * ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["m",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{"0", "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"1"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["1",
      ButtonData:>"1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(4)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "*", 
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{"0", "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"4"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["4",
      ButtonData:>"4",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "*", 
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_1\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"2"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(3)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "*", 
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["p",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], ")"}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"3"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["3",
      ButtonData:>"3",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(5)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"5"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}], "*", 
        StyleBox[\(p\_2\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "*", 
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(n\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "*", 
            StyleBox[\(p\_2\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(m\_1\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["2",
      ButtonData:>"2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(n\_2\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_2\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(6)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["n",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox["n",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox["n",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["n",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"6"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["6",
      ButtonData:>"6",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["n",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(7)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{"0", "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{"0", "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", "0"}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"7"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["7",
      ButtonData:>"7",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed and prove:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(10)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{"0", "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}]}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{"0", "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}], ")"}], "*", 
            StyleBox[\(p\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"10"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["10",
      ButtonData:>"10",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}]}], ")"}], "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{\((0 + 0)\), "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "*", 
        StyleBox[\(p\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], ")"}], "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"0", "*", 
          StyleBox[\(p\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["0*",
      ButtonData:>"0*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(8)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Assumption"]
}], "Assumption",
  CellTags->"8"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(9)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+"], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}]}], ")"}], "*", 
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "=", 
            RowBox[{
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+"]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}]}], ")"}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"9"],

Cell[TextData[{
  "We take in ",
  Cell[TextData[{
    "(",
    ButtonBox["9",
      ButtonData:>"9",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " all variables arbitrary but fixed:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(11)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "*", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], ")"}], "*", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}]}]], "Conclusion"]
}], "Conclusion",
  CellTags->"11"],

Cell["and simplify it.", "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"], "+", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], ")"}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            SuperscriptBox[
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "+", 
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "+"], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "+"], "*", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" ^+*",
      ButtonData:>" ^+*",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(p\_4\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}], "*", 
          StyleBox[\(p\_4\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(p\_4\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              StyleBox[\(p\_4\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}], ")"}]}]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Hence, it is sufficient to prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(12)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], " "}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}], "*", 
                StyleBox["p",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], "=", 
            RowBox[{
              StyleBox["p",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["p",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "*", 
                    StyleBox["p",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}]}], ")"}]}]], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"12"],

Cell[TextData[{
  "We",
  " ",
  "prove ",
  Cell[TextData[{
    "(",
    ButtonBox["12",
      ButtonData:>"12",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " by  induction on ",
  Cell[BoxData[
      StyleBox["p",
        FontWeight->"Plain",
        FontSlant->"Italic",
        Background->None]], "Expression"],
  "."
}], "Text"],

Cell["Induction Base: ", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(13)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"0", "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", "0"}]}], 
        "=", 
        RowBox[{"0", "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", "0"}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", "0"}]}], 
            ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"13"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["13",
      ButtonData:>"13",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", "0"}]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", "0"}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", "0"}]}], ")"}]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{"0", "+", 
        RowBox[{"(", 
          RowBox[{"0", "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", "0"}]}], ")"}]}]], 
    "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *0",
      ButtonData:>" *0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + \((0 + 0)\)\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(\((0 + 0)\) + 0\)], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" +0",
      ButtonData:>" +0",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      \(0 + 0\)], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Induction Step:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Hypothesis:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(14)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]}], "=", 
        RowBox[{
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None]}]}], ")"}]}]}]], "Assumption"]
}], "Assumption",
  CellTags->"14"],

Cell[TextData[{
  Cell["", "Indent"],
  "Induction Conclusion:"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(15)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "*", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}]}], "=", 
        RowBox[{
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"], "+", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}], "+", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}], "*", 
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"]}]}], ")"}]}]}]], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->"15"],

Cell[TextData[{
  "A proof by simplification of ",
  Cell[TextData[{
    "(",
    ButtonBox["15",
      ButtonData:>"15",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " works."
}], "Text"],

Cell["Simplification of the lhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox[\(m\_1\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}]}], ")"}], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}]}], ")"}], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "+", 
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{
                                StyleBox[\(m\_1\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}]}], ")"}], "*", 
                      
                      StyleBox[\(p\_5\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(n\_3\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}]}], ")"}], 
                          "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}]}], ")"}], 
            "+", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(n\_3\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}]}], ")"}], 
                          "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+"]],
     "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["14",
      ButtonData:>"14",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"(", 
                      RowBox[{
                        StyleBox[\(p\_5\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}]}], ")"}], "+"]],
     "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ")"}]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"],

Cell["Simplification of the rhs term:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[\(n\_3\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "*", 
          SuperscriptBox[
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+"]}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              StyleBox[\(n\_3\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            StyleBox[\(n\_3\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            SuperscriptBox[
              StyleBox[\(p\_5\),
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "+"]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  StyleBox[\(m\_1\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], ")"}], "*", 
              SuperscriptBox[
                StyleBox[\(p\_5\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+"]}], "+", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" *  ^+",
      ButtonData:>" *  ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        StyleBox[\(n\_3\),
          FontWeight->"Plain",
          FontSlant->"Italic",
          Background->None], "+", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "+", 
                      RowBox[{
                        StyleBox[\(m\_1\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox[\(n\_3\),
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(m\_1\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}]}], ")"}]}], ")"}], "+", 
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+"], "+", 
                RowBox[{
                  StyleBox[\(n\_3\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox[\(p\_5\),
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}]}], ")"}]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl",
      ButtonData:>"Special Simpl",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(m\_1\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      StyleBox[\(n\_3\),
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox[\(m\_1\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "+", 
                              RowBox[{
                                StyleBox[\(m\_1\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None], "*", 
                                StyleBox[\(n\_3\),
                                  FontWeight->"Plain",
                                  FontSlant->"Italic",
                                  Background->None]}]}], ")"}], "*", 
                          StyleBox[\(p\_5\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], ")"}]}], ")"}]}], ")"}]}], 
          ")"}], "+", 
        SuperscriptBox[
          StyleBox[\(p\_5\),
            FontWeight->"Plain",
            FontSlant->"Italic",
            Background->None], "+"]}]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox[" + ^+",
      ButtonData:>" + ^+",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(m\_1\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(n\_3\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ")"}]}], ")"}], "+", 
            StyleBox[\(p\_5\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}], ")"}], "+"]], "Expression"],
  " =",
  Cell["", "Blank"],
  "by ",
  Cell[TextData[{
    "(",
    ButtonBox["Special Simpl ",
      ButtonData:>"Special Simpl ",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"]
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell[BoxData[
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox[\(m\_1\),
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{"(", 
              RowBox[{
                StyleBox[\(n\_3\),
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "+", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox[\(p\_5\),
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "+", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{
                          StyleBox[\(m\_1\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox[\(n\_3\),
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox[\(n\_3\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}], "+", 
                            RowBox[{
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox[\(m\_1\),
                                    FontWeight->"Plain",
                                    FontSlant->"Italic",
                                    Background->None], "+", 
                                  RowBox[{
                                    StyleBox[\(m\_1\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None], "*", 
                                    StyleBox[\(n\_3\),
                                      FontWeight->"Plain",
                                      FontSlant->"Italic",
                                      Background->None]}]}], ")"}], "*", 
                              StyleBox[\(p\_5\),
                                FontWeight->"Plain",
                                FontSlant->"Italic",
                                Background->None]}]}], ")"}]}], ")"}]}], 
                  ")"}]}], ")"}]}], ")"}], "+"]], "Expression"],
  "\[RightFloor]"
}], "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Proving Booleans of Equalities by Groebner Bases", "Subsection",
  Background->None],

Cell[CellGroupData[{

Cell["\<\
Universally Quantified Boolean Combination of Equalities Over the Complex \
Numbers:\
\>", "Subsubsection",
  Background->None],

Cell["Prove:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["()", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{
        UnderscriptBox["\[ForAll]", 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], ",", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None]}]], 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "-", 
                  RowBox[{"3", "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "\[NotEqual]", "0"}], ")"}], 
            "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}], "\[NotEqual]", "0"}], ")"}], "\[Or]",
             
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{
                          SuperscriptBox[
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"], "*", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{"3", "*", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}]}], "=", "0"}], ")"}], "\[Or]",
                   
                  RowBox[{"(", 
                    RowBox[{
                      RowBox[{
                        RowBox[{\((\(-2\))\), "*", 
                          SuperscriptBox[
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"]}], "+", 
                        RowBox[{\((\(-7\))\), "*", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{
                          SuperscriptBox[
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"], "*", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{
                          SuperscriptBox[
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "3"], "*", 
                          StyleBox["y",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], "+", 
                        RowBox[{\((\(-2\))\), "*", 
                          SuperscriptBox[
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"]}], "+", 
                        RowBox[{\((\(-2\))\), "*", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None], "*", 
                          SuperscriptBox[
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"]}], "+", 
                        RowBox[{"2", "*", 
                          SuperscriptBox[
                            StyleBox["x",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"], "*", 
                          SuperscriptBox[
                            StyleBox["y",
                              FontWeight->"Plain",
                              FontSlant->"Italic",
                              Background->None], "2"]}]}], "=", "0"}], 
                    ")"}]}], ")"}], "\[And]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "+", 
                    RowBox[{
                      RowBox[{"(", 
                        RowBox[{"-", 
                          StyleBox["x",
                            FontWeight->"Plain",
                            FontSlant->"Italic",
                            Background->None]}], ")"}], "*", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    RowBox[{
                      SuperscriptBox[
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "2"], "*", 
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None]}], "+", 
                    RowBox[{\((\(-2\))\), "*", 
                      SuperscriptBox[
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "2"]}], "+", 
                    RowBox[{\((\(-2\))\), "*", 
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "*", 
                      SuperscriptBox[
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "2"]}]}], "=", "0"}], ")"}]}]}], 
          ")"}]}]], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->""],

Cell["with no assumptions.", "Text"],

Cell["Proved.", "Text"],

Cell["\<\
The Theorem is proved by the Groebner Bases method.      

      The formula in the scope of the universal quantifier is transformed \
into an equivalent formula that is a conjunction of disjunctions of \
equalities and negated equalities. The universal quantifier can then be \
distributed over the individual parts of the conjunction. By this, we obtain:\
\
\>", "Text"],

Cell["Independent proof problems:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.1)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{\(\[ForAll] \+\(x, y\)\), 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  SuperscriptBox[
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "2"], "+", 
                  RowBox[{"(", 
                    RowBox[{"-", 
                      RowBox[{
                        StyleBox["x",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None], "*", 
                        StyleBox["y",
                          FontWeight->"Plain",
                          FontSlant->"Italic",
                          Background->None]}]}], ")"}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{\(-2\), "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-2\), "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}]}], "=", "0"}], ")"}], 
            "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{\(-3\), "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "\[NotEqual]", "0"}], ")"}], 
            "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "\[NotEqual]", "0"}], ")"}]}], 
          ")"}]}]], "Conclusion"],
  " "
}], "Conclusion",
  CellTags->".1"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.2)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      RowBox[{\(\[ForAll] \+\(x, y\)\), 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{"3", "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "=", "0"}], ")"}], "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{\(-2\), "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-7\), "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "3"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{\(-2\), "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{\(-2\), "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}], "+", 
                  RowBox[{"2", "*", 
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    SuperscriptBox[
                      StyleBox["y",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"]}]}], "=", "0"}], ")"}], 
            "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  RowBox[{\(-3\), "*", 
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}], "+", 
                  RowBox[{
                    SuperscriptBox[
                      StyleBox["x",
                        FontWeight->"Plain",
                        FontSlant->"Italic",
                        Background->None], "2"], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "\[NotEqual]", "0"}], ")"}], 
            "\[Or]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "+", 
                  RowBox[{
                    StyleBox["x",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None], "*", 
                    StyleBox["y",
                      FontWeight->"Plain",
                      FontSlant->"Italic",
                      Background->None]}]}], "\[NotEqual]", "0"}], ")"}]}], 
          ")"}]}]], "Conclusion"],
  " "
}], "Conclusion",
  CellTags->".2"],

Cell["We now prove the above individual problems separately:", "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[".1",
      ButtonData:>".1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell["This proof problem has the following structure:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.1.structure)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[ForAll] \+\(x, y\)\((\((Poly[1] \[NotEqual] 
                0)\) \[Or] \((Poly[2] \[NotEqual] 0)\) \[Or] \((Poly[3] = 
                0)\))\)\)], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->".1.structure"],

Cell["where", "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {\(\(Poly[1]\)\(\ \)\(=\)\), 
          RowBox[{
            RowBox[{\(-3\), "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]},
        {\(\(Poly[2]\)\(\ \)\(=\)\), 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]},
        {\(\(Poly[3]\)\(\ \)\(=\)\), 
          RowBox[{
            SuperscriptBox[
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "2"], "+", 
            RowBox[{"(", 
              RowBox[{"-", 
                RowBox[{
                  StyleBox["x",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None], "*", 
                  StyleBox["y",
                    FontWeight->"Plain",
                    FontSlant->"Italic",
                    Background->None]}]}], ")"}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{\(-2\), "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}], "+", 
            RowBox[{\(-2\), "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}]}]}
        },
      ColumnAlignments->{Left}]]]], "Text"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox[".1.structure",
      ButtonData:>".1.structure",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is equivalent to"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.1.implication)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[ForAll] \+\(x, y\)\((\((Poly[1] = 0)\) \[And] \((Poly[2] = 
                  0)\) \[Implies] \((Poly[3] = 0)\))\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->".1.implication"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox[".1.implication",
      ButtonData:>".1.implication",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is equivalent to"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.1.not-exists)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[NotExists] \+\(x, y\)\((\((\((Poly[1] = 0)\) \[And] \((Poly[2] = 
                    0)\))\) \[And] \((Poly[3] \[NotEqual] 0)\))\)\)], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->".1.not-exists"],

Cell["By introducing the slack variable(s)", "Text"],

Cell["{\[Xi]}", "Text"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox[".1.not-exists",
      ButtonData:>".1.not-exists",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is transformed into the equivalent formula"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.1.not-exists-slack)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[NotExists] \+\(x, y, \[Xi]\)\((\((\((Poly[1] = 
                    0)\) \[And] \((Poly[2] = 
                    0)\))\) \[And] \((\(-1\) + \[Xi]\ Poly[3] = 0)\))\)\)], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->".1.not-exists-slack"],

Cell["\<\
Hence, we see that the proof problem is transformed into the question on \
whether or not a system of polynomial equations has a solution or not. This \
question can be answered by checking whether or not the (reduced) Groebner \
basis of\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \({Poly[1], Poly[2], \(-1\) + \[Xi]\ Poly[3]}\)]]], "Text"],

Cell["\<\
is exactly {1}.                  

Hence, we compute the Groebner basis for the following polynomial list:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \({\(-1\) + x\^2\ \[Xi] + \(-x\)\ y\ \[Xi] + 
        x\^2\ y\ \[Xi] + \(-2\)\ y\^2\ \[Xi] + \(-2\)\ x\ y\^2\ \[Xi], \(-3\)\
\ x + x\^2\ y, x + y + x\ y}\)]]], "Text"],

Cell["The Groebner basis:", "Text"],

Cell[TextData[Cell[BoxData[
    \({1}\)]]], "Text"],

Cell[TextData[{
  "Hence, ",
  Cell[TextData[{
    "(",
    ButtonBox[".1",
      ButtonData:>".1",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is ",
  "proved."
}], "Text"],

Cell[TextData[{
  "Proof of ",
  Cell[TextData[{
    "(",
    ButtonBox[".2",
      ButtonData:>".2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  ":"
}], "Text"],

Cell["This proof problem has the following structure:", "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.2.structure)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[ForAll] \+\(x, y\)\((\((Poly[1] \[NotEqual] 
                0)\) \[Or] \((Poly[2] \[NotEqual] 0)\) \[Or] \((Poly[3] = 
                0)\) \[Or] \((Poly[4] = 0)\))\)\)], "Conclusion"],
  ","
}], "Conclusion",
  CellTags->".2.structure"],

Cell["where", "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
        {\(\(Poly[1]\)\(\ \)\(=\)\), 
          RowBox[{
            RowBox[{\(-3\), "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]},
        {\(\(Poly[2]\)\(\ \)\(=\)\), 
          RowBox[{
            StyleBox["x",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            StyleBox["y",
              FontWeight->"Plain",
              FontSlant->"Italic",
              Background->None], "+", 
            RowBox[{
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]},
        {\(\(Poly[3]\)\(\ \)\(=\)\), 
          RowBox[{
            RowBox[{"3", "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}]}]},
        {\(\(Poly[4]\)\(\ \)\(=\)\), 
          RowBox[{
            RowBox[{\(-2\), "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}], "+", 
            RowBox[{\(-7\), "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "3"], "*", 
              StyleBox["y",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None]}], "+", 
            RowBox[{\(-2\), "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}], "+", 
            RowBox[{\(-2\), "*", 
              StyleBox["x",
                FontWeight->"Plain",
                FontSlant->"Italic",
                Background->None], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}], "+", 
            RowBox[{"2", "*", 
              SuperscriptBox[
                StyleBox["x",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"], "*", 
              SuperscriptBox[
                StyleBox["y",
                  FontWeight->"Plain",
                  FontSlant->"Italic",
                  Background->None], "2"]}]}]}
        },
      ColumnAlignments->{Left}]]]], "Text"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox[".2.structure",
      ButtonData:>".2.structure",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is equivalent to"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.2.implication)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[ForAll] \+\(x, y\)\((\((Poly[1] = 0)\) \[And] \((Poly[2] = 
                  0)\) \[Implies] \((Poly[3] = 0)\) \[Or] \((Poly[4] = 
                  0)\))\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->".2.implication"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox[".2.implication",
      ButtonData:>".2.implication",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is equivalent to"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.2.not-exists)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[NotExists] \+\(x, y\)\((\((\((Poly[1] = 0)\) \[And] \((Poly[2] = 
                    0)\))\) \[And] \((\((Poly[3] \[NotEqual] 
                    0)\) \[And] \((Poly[4] \[NotEqual] 0)\))\))\)\)], 
    "Conclusion"],
  "."
}], "Conclusion",
  CellTags->".2.not-exists"],

Cell["By introducing the slack variable(s)", "Text"],

Cell["{\[Xi]1, \[Xi]2}", "Text"],

Cell[TextData[{
  Cell[TextData[{
    "(",
    ButtonBox[".2.not-exists",
      ButtonData:>".2.not-exists",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is transformed into the equivalent formula"
}], "Text"],

Cell[TextData[{
  Cell["", "Indent"],
  Cell["(.2.not-exists-slack)", "Label"],
  Cell["", "Blank"],
  Cell[BoxData[
      \(\[NotExists] \+\(x, y, \[Xi]1, \[Xi]2\)\((\((\((Poly[1] = 
                    0)\) \[And] \((Poly[2] = 
                    0)\))\) \[And] {\(-1\) + \[Xi]1\ Poly[3] = 
                0, \(-1\) + \[Xi]2\ Poly[4] = 0})\)\)], "Conclusion"],
  "."
}], "Conclusion",
  CellTags->".2.not-exists-slack"],

Cell["\<\
Hence, we see that the proof problem is transformed into the question on \
whether or not a system of polynomial equations has a solution or not. This \
question can be answered by checking whether or not the (reduced) Groebner \
basis of\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \({Poly[1], 
      Poly[2], \(-1\) + \[Xi]1\ Poly[3], \(-1\) + \[Xi]2\ Poly[
            4]}\)]]], "Text"],

Cell["\<\
is exactly {1}.                  

Hence, we compute the Groebner basis for the following polynomial list:\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    \({\(-1\) + 3\ x\ \[Xi]1 + 
        x\^2\ y\ \[Xi]1, \(-1\) + \(-2\)\ x\^2\ \[Xi]2 + \(-7\)\ x\ y\ \[Xi]2 \
+ x\^2\ y\ \[Xi]2 + 
        x\^3\ y\ \[Xi]2 + \(-2\)\ y\^2\ \[Xi]2 + \(-2\)\ x\ y\^2\ \[Xi]2 + 
        2\ x\^2\ y\^2\ \[Xi]2, \(-3\)\ x + x\^2\ y, x + y + x\ y}\)]]], "Text"],

Cell["The Groebner basis:", "Text"],

Cell[TextData[Cell[BoxData[
    \({1}\)]]], "Text"],

Cell[TextData[{
  "Hence, ",
  Cell[TextData[{
    "(",
    ButtonBox[".2",
      ButtonData:>".2",
      ButtonStyle->"Hyperlink"],
    ")"
  }], "Label"],
  " is ",
  "proved."
}], "Text"],

Cell["\<\
Since all of the individual subtheorems are proved, the original formula is \
proved.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Presentation",
WindowToolbars->"EditBar",
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 26}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "cdupre", \
"SFB", "45"}, "Theorema-Short-Demo.nb.ps", CharacterEncoding -> "ISO8859-1"],
"Magnification"->1},
SpellingDictionaries->{"CorrectWords"->{
  "Johannes", "Kepler", "Linz", "Theorema", "Dupre", "Kriftner", "Jebelean", 
    "Nakagawa", "Vasaru", "Windsteiger.", "Theorema's", "Globals", "Tma", 
    "rhs", "lhs", "subtheorems"}},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    AutoItalicWords->{"Theorema"},
    LimitsPositioningTokens->{},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22,
    Background->RGBColor[0, 1, 0]],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Open  ]],
  
  Cell[StyleData["Subsubsubsection"],
    CellDingbat->"\[EmptySmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold",
    Background->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    Background->RGBColor[1, 1, 0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Open  ]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "title"->{
    Cell[1739, 51, 194, 7, 162, "Subtitle",
      CellTags->"title"]},
  "4-ary limit"->{
    Cell[6927, 230, 417, 7, 109, "Input",
      CellTags->{
      "4-ary limit", "distance of sum", "maximum", "sum of sequences"}],
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[42096, 1304, 548, 14, 117, "Input",
      CellTags->{
      "2-ary continuity", "4-ary limit", "continuity", "continuity 2-ary"}],
    Cell[42647, 1320, 613, 16, 117, "Input",
      CellTags->{
      "3-ary continuity", "4-ary limit", "continuity", "continuity3", 
        "continuity 3-ary"}],
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "distance of sum"->{
    Cell[6927, 230, 417, 7, 109, "Input",
      CellTags->{
      "4-ary limit", "distance of sum", "maximum", "sum of sequences"}],
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[46330, 1420, 915, 20, 126, "Input",
      CellTags->{
      "distance of prod", "distance of product", "distance of sum"}],
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "maximum"->{
    Cell[6927, 230, 417, 7, 109, "Input",
      CellTags->{
      "4-ary limit", "distance of sum", "maximum", "sum of sequences"}],
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "sum of sequences"->{
    Cell[6927, 230, 417, 7, 109, "Input",
      CellTags->{
      "4-ary limit", "distance of sum", "maximum", "sum of sequences"}],
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "2-ary limit of sum"->{
    Cell[8774, 292, 466, 12, 132, "Input",
      CellTags->{
      "2-ary limit of sum", "Divides Sum", "greatest common divisor", 
        "Greatest Common Divisor"}],
    Cell[12414, 421, 429, 10, 99, "Input",
      CellTags->{"2-ary limit of sum", "divides difference", "Divides Sum"}],
    Cell[12898, 435, 534, 13, 99, "Input",
      CellTags->{
      "2-ary limit of sum", "common divisors and difference", 
        "divides difference", "Divides Sum"}],
    Cell[13493, 452, 560, 12, 159, "Input",
      CellTags->{
      "2-ary limit of sum", "divides difference", "Divides Sum", 
        "Euclid's Theorem"}],
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "Divides Sum"->{
    Cell[8774, 292, 466, 12, 132, "Input",
      CellTags->{
      "2-ary limit of sum", "Divides Sum", "greatest common divisor", 
        "Greatest Common Divisor"}],
    Cell[12414, 421, 429, 10, 99, "Input",
      CellTags->{"2-ary limit of sum", "divides difference", "Divides Sum"}],
    Cell[12898, 435, 534, 13, 99, "Input",
      CellTags->{
      "2-ary limit of sum", "common divisors and difference", 
        "divides difference", "Divides Sum"}],
    Cell[13493, 452, 560, 12, 159, "Input",
      CellTags->{
      "2-ary limit of sum", "divides difference", "Divides Sum", 
        "Euclid's Theorem"}]},
  "greatest common divisor"->{
    Cell[8774, 292, 466, 12, 132, "Input",
      CellTags->{
      "2-ary limit of sum", "Divides Sum", "greatest common divisor", 
        "Greatest Common Divisor"}]},
  "Greatest Common Divisor"->{
    Cell[8774, 292, 466, 12, 132, "Input",
      CellTags->{
      "2-ary limit of sum", "Divides Sum", "greatest common divisor", 
        "Greatest Common Divisor"}]},
  "divides difference"->{
    Cell[12414, 421, 429, 10, 99, "Input",
      CellTags->{"2-ary limit of sum", "divides difference", "Divides Sum"}],
    Cell[12898, 435, 534, 13, 99, "Input",
      CellTags->{
      "2-ary limit of sum", "common divisors and difference", 
        "divides difference", "Divides Sum"}],
    Cell[13493, 452, 560, 12, 159, "Input",
      CellTags->{
      "2-ary limit of sum", "divides difference", "Divides Sum", 
        "Euclid's Theorem"}],
    Cell[16307, 556, 629, 16, 99, "Input",
      CellTags->"divides difference"],
    Cell[17046, 579, 536, 13, 109, "Input",
      CellTags->{"divides", "divides difference"}],
    Cell[17703, 599, 604, 15, 99, "Input",
      CellTags->{"distributivity", "divides", "divides difference"}]},
  "common divisors and difference"->{
    Cell[12898, 435, 534, 13, 99, "Input",
      CellTags->{
      "2-ary limit of sum", "common divisors and difference", 
        "divides difference", "Divides Sum"}]},
  "Euclid's Theorem"->{
    Cell[13493, 452, 560, 12, 159, "Input",
      CellTags->{
      "2-ary limit of sum", "divides difference", "Divides Sum", 
        "Euclid's Theorem"}]},
  "divides"->{
    Cell[17046, 579, 536, 13, 109, "Input",
      CellTags->{"divides", "divides difference"}],
    Cell[17703, 599, 604, 15, 99, "Input",
      CellTags->{"distributivity", "divides", "divides difference"}]},
  "distributivity"->{
    Cell[17703, 599, 604, 15, 99, "Input",
      CellTags->{"distributivity", "divides", "divides difference"}]},
  "2-ary limit"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[37082, 1140, 390, 10, 117, "Input",
      CellTags->{"2-ary limit", "3-ary limit"}],
    Cell[40120, 1239, 482, 11, 148, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit of sum: variant", "positiveness"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "3-ary limit"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[37082, 1140, 390, 10, 117, "Input",
      CellTags->{"2-ary limit", "3-ary limit"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "3-ary limit of sum"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "4-ary limit of sum"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[44068, 1360, 1016, 22, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum",
         "continuity 2-ary", "continuity 3-ary", "limit of sum"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "fsum"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[45890, 1406, 437, 12, 79, "Input",
      CellTags->{"fprod", "fsum", "product of functions"}],
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "Limit of a Sequence"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}]},
  "limit of sum"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[44068, 1360, 1016, 22, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum",
         "continuity 2-ary", "continuity 3-ary", "limit of sum"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}]},
  "lim sum"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}]},
  "max-greater"->{
    Cell[22484, 746, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[23176, 770, 725, 15, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[24160, 795, 724, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[25425, 823, 806, 17, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26234, 842, 715, 15, 91, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[26952, 859, 699, 15, 117, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[28918, 912, 850, 20, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[29965, 940, 822, 17, 144, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[30790, 959, 714, 16, 109, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[31792, 988, 647, 16, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[32442, 1006, 983, 22, 126, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[33428, 1030, 750, 17, 79, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[34363, 1057, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[35765, 1100, 371, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}],
    Cell[40760, 1261, 414, 10, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater"}],
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}],
    Cell[51665, 1572, 338, 6, 70, "Subsubsection",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[52162, 1585, 1170, 31, 184, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "Limit of a Sequence", "limit of sum", 
        "lim sum", "max-greater", "maximum", "sum of sequences"}],
    Cell[53695, 1630, 372, 7, 49, "Input",
      CellTags->{
      "2-ary limit", "2-ary limit of sum", "3-ary limit", 
        "3-ary limit of sum", "4-ary limit", "4-ary limit of sum", 
        "distance of sum", "fsum", "max-greater", "maximum", 
        "sum of sequences"}]},
  "3-ary continuity of sum: variant"->{
    Cell[38808, 1200, 427, 11, 117, "Input",
      CellTags->{
      "3-ary continuity of sum: variant", "3-ary limit of sum: variant", 
        "positiveness"}]},
  "3-ary limit of sum: variant"->{
    Cell[38808, 1200, 427, 11, 117, "Input",
      CellTags->{
      "3-ary continuity of sum: variant", "3-ary limit of sum: variant", 
        "positiveness"}],
    Cell[39335, 1217, 612, 14, 144, "Input",
      CellTags->"3-ary limit of sum: variant"],
    Cell[40120, 1239, 482, 11, 148, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit of sum: variant", "positiveness"}]},
  "positiveness"->{
    Cell[38808, 1200, 427, 11, 117, "Input",
      CellTags->{
      "3-ary continuity of sum: variant", "3-ary limit of sum: variant", 
        "positiveness"}],
    Cell[40120, 1239, 482, 11, 148, "Input",
      CellTags->{
      "2-ary limit", "3-ary limit of sum: variant", "positiveness"}]},
  "2-ary continuity"->{
    Cell[42096, 1304, 548, 14, 117, "Input",
      CellTags->{
      "2-ary continuity", "4-ary limit", "continuity", "continuity 2-ary"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "continuity"->{
    Cell[42096, 1304, 548, 14, 117, "Input",
      CellTags->{
      "2-ary continuity", "4-ary limit", "continuity", "continuity 2-ary"}],
    Cell[42647, 1320, 613, 16, 117, "Input",
      CellTags->{
      "3-ary continuity", "4-ary limit", "continuity", "continuity3", 
        "continuity 3-ary"}],
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}],
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}]},
  "continuity 2-ary"->{
    Cell[42096, 1304, 548, 14, 117, "Input",
      CellTags->{
      "2-ary continuity", "4-ary limit", "continuity", "continuity 2-ary"}],
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}],
    Cell[44068, 1360, 1016, 22, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum",
         "continuity 2-ary", "continuity 3-ary", "limit of sum"}],
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}]},
  "3-ary continuity"->{
    Cell[42647, 1320, 613, 16, 117, "Input",
      CellTags->{
      "3-ary continuity", "4-ary limit", "continuity", "continuity3", 
        "continuity 3-ary"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "continuity3"->{
    Cell[42647, 1320, 613, 16, 117, "Input",
      CellTags->{
      "3-ary continuity", "4-ary limit", "continuity", "continuity3", 
        "continuity 3-ary"}],
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}]},
  "continuity 3-ary"->{
    Cell[42647, 1320, 613, 16, 117, "Input",
      CellTags->{
      "3-ary continuity", "4-ary limit", "continuity", "continuity3", 
        "continuity 3-ary"}],
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}],
    Cell[44068, 1360, 1016, 22, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum",
         "continuity 2-ary", "continuity 3-ary", "limit of sum"}],
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}]},
  "4-ary continuity"->{
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}],
    Cell[44068, 1360, 1016, 22, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum",
         "continuity 2-ary", "continuity 3-ary", "limit of sum"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "continuity4"->{
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}]},
  "continuity 4-ary"->{
    Cell[43263, 1338, 780, 18, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
        "continuity3", "continuity 3-ary", "continuity4", 
        "continuity 4-ary"}],
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}]},
  "4-ary continuity of product"->{
    Cell[44068, 1360, 1016, 22, 126, "Input",
      CellTags->{
      "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum",
         "continuity 2-ary", "continuity 3-ary", "limit of sum"}],
    Cell[45665, 1399, 210, 4, 37, "Message",
      CellTags->"4-ary continuity of product"],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "fprod"->{
    Cell[45890, 1406, 437, 12, 79, "Input",
      CellTags->{"fprod", "fsum", "product of functions"}]},
  "product of functions"->{
    Cell[45890, 1406, 437, 12, 79, "Input",
      CellTags->{"fprod", "fsum", "product of functions"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "distance of prod"->{
    Cell[46330, 1420, 915, 20, 126, "Input",
      CellTags->{
      "distance of prod", "distance of product", "distance of sum"}]},
  "distance of product"->{
    Cell[46330, 1420, 915, 20, 126, "Input",
      CellTags->{
      "distance of prod", "distance of product", "distance of sum"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "minimum"->{
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}],
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "min-lower"->{
    Cell[47248, 1442, 558, 14, 79, "Input",
      CellTags->{
      "continuity", "continuity 2-ary", "continuity 3-ary", 
        "continuity 4-ary", "distance of sum", "fsum", "max-greater", 
        "minimum", "min-lower"}]},
  "continuity of 4-ary product"->{
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "continuity prod 4-ary"->{
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "continuity sum 4-ary"->{
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "cont sum"->{
    Cell[47809, 1458, 1324, 35, 184, "Input",
      CellTags->{
      "2-ary continuity", "3-ary continuity", "4-ary continuity", 
        "4-ary continuity of product", "4-ary limit", 
        "continuity of 4-ary product", "continuity prod 4-ary", 
        "continuity sum 4-ary", "cont sum", "distance of product", 
        "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
        "minimum", "product of functions"}]},
  "Classes Modulo a Predicate"->{
    Cell[55208, 1678, 289, 7, 49, "Input",
      CellTags->{
      "Classes Modulo a Predicate", "Classes Modulo Symmetric Predicates", 
        "Symmetry"}],
    Cell[57853, 1757, 604, 15, 112, "Input",
      CellTags->{
      "Classes Modulo a Predicate", "equivalence class", "Equivalence class", 
        "Equivalence Classes"}],
    Cell[58518, 1776, 857, 19, 91, "Input",
      CellTags->{
      "Classes Modulo a Predicate", 
        "Classes Modulo Predicates with Special Properties", 
        "Classes Modulo Reflexive Predicates", 
        "Classes Modulo Symmetric Predicates", "equivalence class", 
        "Equivalence class", "Equivalence Classes"}]},
  "Classes Modulo Symmetric Predicates"->{
    Cell[55208, 1678, 289, 7, 49, "Input",
      CellTags->{
      "Classes Modulo a Predicate", "Classes Modulo Symmetric Predicates", 
        "Symmetry"}],
    Cell[58518, 1776, 857, 19, 91, "Input",
      CellTags->{
      "Classes Modulo a Predicate", 
        "Classes Modulo Predicates with Special Properties", 
        "Classes Modulo Reflexive Predicates", 
        "Classes Modulo Symmetric Predicates", "equivalence class", 
        "Equivalence class", "Equivalence Classes"}]},
  "Symmetry"->{
    Cell[55208, 1678, 289, 7, 49, "Input",
      CellTags->{
      "Classes Modulo a Predicate", "Classes Modulo Symmetric Predicates", 
        "Symmetry"}],
    Cell[57007, 1729, 568, 14, 91, "Input",
      CellTags->{
      "is symmetric", "is\[Dash]symmetric", "Reflexivity", "Symmetry"}]},
  "is symmetric"->{
    Cell[57007, 1729, 568, 14, 91, "Input",
      CellTags->{
      "is symmetric", "is\[Dash]symmetric", "Reflexivity", "Symmetry"}]},
  "is\[Dash]symmetric"->{
    Cell[57007, 1729, 568, 14, 91, "Input",
      CellTags->{
      "is symmetric", "is\[Dash]symmetric", "Reflexivity", "Symmetry"}]},
  "Reflexivity"->{
    Cell[57007, 1729, 568, 14, 91, "Input",
      CellTags->{
      "is symmetric", "is\[Dash]symmetric", "Reflexivity", "Symmetry"}]},
  "equivalence class"->{
    Cell[57853, 1757, 604, 15, 112, "Input",
      CellTags->{
      "Classes Modulo a Predicate", "equivalence class", "Equivalence class", 
        "Equivalence Classes"}],
    Cell[58518, 1776, 857, 19, 91, "Input",
      CellTags->{
      "Classes Modulo a Predicate", 
        "Classes Modulo Predicates with Special Properties", 
        "Classes Modulo Reflexive Predicates", 
        "Classes Modulo Symmetric Predicates", "equivalence class", 
        "Equivalence class", "Equivalence Classes"}]},
  "Equivalence class"->{
    Cell[57853, 1757, 604, 15, 112, "Input",
      CellTags->{
      "Classes Modulo a Predicate", "equivalence class", "Equivalence class", 
        "Equivalence Classes"}],
    Cell[58518, 1776, 857, 19, 91, "Input",
      CellTags->{
      "Classes Modulo a Predicate", 
        "Classes Modulo Predicates with Special Properties", 
        "Classes Modulo Reflexive Predicates", 
        "Classes Modulo Symmetric Predicates", "equivalence class", 
        "Equivalence class", "Equivalence Classes"}]},
  "Equivalence Classes"->{
    Cell[57853, 1757, 604, 15, 112, "Input",
      CellTags->{
      "Classes Modulo a Predicate", "equivalence class", "Equivalence class", 
        "Equivalence Classes"}],
    Cell[58518, 1776, 857, 19, 91, "Input",
      CellTags->{
      "Classes Modulo a Predicate", 
        "Classes Modulo Predicates with Special Properties", 
        "Classes Modulo Reflexive Predicates", 
        "Classes Modulo Symmetric Predicates", "equivalence class", 
        "Equivalence class", "Equivalence Classes"}]},
  "Classes Modulo Predicates with Special Properties"->{
    Cell[58518, 1776, 857, 19, 91, "Input",
      CellTags->{
      "Classes Modulo a Predicate", 
        "Classes Modulo Predicates with Special Properties", 
        "Classes Modulo Reflexive Predicates", 
        "Classes Modulo Symmetric Predicates", "equivalence class", 
        "Equivalence class", "Equivalence Classes"}]},
  "Classes Modulo Reflexive Predicates"->{
    Cell[58518, 1776, 857, 19, 91, "Input",
      CellTags->{
      "Classes Modulo a Predicate", 
        "Classes Modulo Predicates with Special Properties", 
        "Classes Modulo Reflexive Predicates", 
        "Classes Modulo Symmetric Predicates", "equivalence class", 
        "Equivalence class", "Equivalence Classes"}]},
  "addition"->{
    Cell[61144, 1855, 359, 8, 109, "Input",
      CellTags->"addition"],
    Cell[64892, 1988, 439, 11, 117, "Input",
      CellTags->{"addition", "Addition", "Multiplication"}]},
  "Addition"->{
    Cell[64892, 1988, 439, 11, 117, "Input",
      CellTags->{"addition", "Addition", "Multiplication"}],
    Cell[65666, 2016, 444, 13, 79, "Input",
      CellTags->{
      "Addition", "comm\[RawStar]", "comm+", "commutativity of addition", 
        "Multiplication"}],
    Cell[66113, 2031, 464, 9, 139, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", 
        "commutativity of addition", "left addition", "Multiplication"}],
    Cell[69628, 2136, 387, 8, 109, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", "left addition", 
        "Multiplication"}]},
  "Multiplication"->{
    Cell[64892, 1988, 439, 11, 117, "Input",
      CellTags->{"addition", "Addition", "Multiplication"}],
    Cell[65666, 2016, 444, 13, 79, "Input",
      CellTags->{
      "Addition", "comm\[RawStar]", "comm+", "commutativity of addition", 
        "Multiplication"}],
    Cell[66113, 2031, 464, 9, 139, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", 
        "commutativity of addition", "left addition", "Multiplication"}],
    Cell[69628, 2136, 387, 8, 109, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", "left addition", 
        "Multiplication"}],
    Cell[75831, 2296, 655, 17, 182, "Input",
      CellTags->{
      "Multiplication", "Some Equational Properties of Multiplication"}],
    Cell[76626, 2320, 479, 13, 79, "Input",
      CellTags->{
      "Associativity of Multiplication", "Associativity of Multiplicatios", 
        "Multiplication"}]},
  "comm\[RawStar]"->{
    Cell[65666, 2016, 444, 13, 79, "Input",
      CellTags->{
      "Addition", "comm\[RawStar]", "comm+", "commutativity of addition", 
        "Multiplication"}],
    Cell[66113, 2031, 464, 9, 139, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", 
        "commutativity of addition", "left addition", "Multiplication"}],
    Cell[69628, 2136, 387, 8, 109, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", "left addition", 
        "Multiplication"}]},
  "comm+"->{
    Cell[65666, 2016, 444, 13, 79, "Input",
      CellTags->{
      "Addition", "comm\[RawStar]", "comm+", "commutativity of addition", 
        "Multiplication"}],
    Cell[66113, 2031, 464, 9, 139, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", 
        "commutativity of addition", "left addition", "Multiplication"}],
    Cell[69628, 2136, 387, 8, 109, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", "left addition", 
        "Multiplication"}]},
  "commutativity of addition"->{
    Cell[65666, 2016, 444, 13, 79, "Input",
      CellTags->{
      "Addition", "comm\[RawStar]", "comm+", "commutativity of addition", 
        "Multiplication"}],
    Cell[66113, 2031, 464, 9, 139, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", 
        "commutativity of addition", "left addition", "Multiplication"}]},
  "assoc+"->{
    Cell[66113, 2031, 464, 9, 139, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", 
        "commutativity of addition", "left addition", "Multiplication"}],
    Cell[69628, 2136, 387, 8, 109, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", "left addition", 
        "Multiplication"}]},
  "left addition"->{
    Cell[66113, 2031, 464, 9, 139, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", 
        "commutativity of addition", "left addition", "Multiplication"}],
    Cell[69628, 2136, 387, 8, 109, "Input",
      CellTags->{
      "Addition", "assoc+", "comm\[RawStar]", "comm+", "left addition", 
        "Multiplication"}]},
  "Equational Properties of Addition"->{
    Cell[75026, 2275, 735, 17, 245, "Input",
      CellTags->"Equational Properties of Addition"],
    Cell[78884, 2388, 614, 15, 182, "Input",
      CellTags->"Equational Properties of Addition"],
    Cell[79965, 2418, 593, 12, 169, "Input",
      CellTags->"Equational Properties of Addition"],
    Cell[86833, 2605, 172, 4, 83, "Subsection",
      CellTags->{"Equational Properties of Addition", "Test"}]},
  "Some Equational Properties of Multiplication"->{
    Cell[75831, 2296, 655, 17, 182, "Input",
      CellTags->{
      "Multiplication", "Some Equational Properties of Multiplication"}]},
  "Associativity of Multiplication"->{
    Cell[76626, 2320, 479, 13, 79, "Input",
      CellTags->{
      "Associativity of Multiplication", "Associativity of Multiplicatios", 
        "Multiplication"}]},
  "Associativity of Multiplicatios"->{
    Cell[76626, 2320, 479, 13, 79, "Input",
      CellTags->{
      "Associativity of Multiplication", "Associativity of Multiplicatios", 
        "Multiplication"}]},
  "Test"->{
    Cell[84858, 2550, 972, 19, 212, "Input",
      CellTags->"Test"],
    Cell[86833, 2605, 172, 4, 83, "Subsection",
      CellTags->{"Equational Properties of Addition", "Test"}]},
  "PauleSchorn"->{
    Cell[88585, 2660, 603, 15, 211, "Input",
      InitializationCell->True,
      CellTags->"PauleSchorn"],
    Cell[89191, 2677, 413, 9, 289, "Input",
      InitializationCell->True,
      CellTags->"PauleSchorn"]},
  "Gauss"->{
    Cell[89641, 2691, 82, 2, 70, "Subsubsection",
      CellTags->"Gauss"],
    Cell[89874, 2700, 246, 8, 124, "Input",
      CellTags->"Gauss"]},
  "SIAM series"->{
    Cell[100393, 2996, 378, 9, 135, "Input",
      CellTags->"SIAM series"]},
  "math"->{
    Cell[133635, 3939, 680, 16, 274, "Input",
      CellTags->{"math", "Mathematica"}]},
  "Mathematica"->{
    Cell[133635, 3939, 680, 16, 274, "Input",
      CellTags->{"math", "Mathematica"}],
    Cell[134318, 3957, 163, 4, 49, "Input",
      CellTags->"Mathematica"]},
  "Mathematica Polynomials"->{
    Cell[135096, 3982, 2246, 44, 832, "Input",
      CellTags->"Mathematica Polynomials"]},
  "\[DoubleStruckCapitalM]\[DoubleStruckCapitalP]"->{
    Cell[137620, 4039, 339, 9, 79, "Input",
      CellTags->{
      "\[DoubleStruckCapitalM]\[DoubleStruckCapitalP]", 
        "\[DoubleStruckCapitalP]"}]},
  "\[DoubleStruckCapitalP]"->{
    Cell[137620, 4039, 339, 9, 79, "Input",
      CellTags->{
      "\[DoubleStruckCapitalM]\[DoubleStruckCapitalP]", 
        "\[DoubleStruckCapitalP]"}],
    Cell[138120, 4055, 398, 10, 117, "Input",
      CellTags->{"T", "\[DoubleStruckCapitalP]"}],
    Cell[144301, 4259, 481, 12, 148, "Input",
      CellTags->{"RD", "RDMP", "T", "\[DoubleStruckCapitalP]"}]},
  "T"->{
    Cell[138120, 4055, 398, 10, 117, "Input",
      CellTags->{"T", "\[DoubleStruckCapitalP]"}],
    Cell[144301, 4259, 481, 12, 148, "Input",
      CellTags->{"RD", "RDMP", "T", "\[DoubleStruckCapitalP]"}]},
  "Reduction Domain"->{
    Cell[141844, 4195, 1499, 32, 366, "Input",
      CellTags->"Reduction Domain"]},
  "RDMP"->{
    Cell[143851, 4242, 333, 10, 79, "Input",
      CellTags->"RDMP"],
    Cell[144301, 4259, 481, 12, 148, "Input",
      CellTags->{"RD", "RDMP", "T", "\[DoubleStruckCapitalP]"}]},
  "RD"->{
    Cell[144301, 4259, 481, 12, 148, "Input",
      CellTags->{"RD", "RDMP", "T", "\[DoubleStruckCapitalP]"}]},
  "computing-session"->{
    Cell[145526, 4302, 137, 3, 74, "Subsubsection",
      CellTags->"computing-session"]},
  "sets"->{
    Cell[146202, 4327, 117, 3, 70, "Input",
      CellTags->"sets"],
    Cell[146402, 4338, 121, 3, 70, "Input",
      CellTags->"sets"]},
  "divdiff"->{
    Cell[153337, 4681, 2306, 67, 48, "Conclusion",
      CellTags->"divdiff"]},
  "div:"->{
    Cell[155687, 4752, 1727, 51, 59, "Assumption",
      CellTags->"div:"]},
  "distr"->{
    Cell[157417, 4805, 3167, 89, 48, "Assumption",
      CellTags->"distr"]},
  "1"->{
    Cell[160615, 4898, 763, 26, 36, "Assumption",
      CellTags->"1"],
    Cell[186748, 5807, 1425, 44, 36, "Assumption",
      CellTags->"1"],
    Cell[218973, 6901, 1145, 36, 36, "Assumption",
      CellTags->"1"],
    Cell[238635, 7593, 849, 28, 36, "Assumption",
      CellTags->"1"],
    Cell[272768, 8761, 1457, 44, 37, "Assumption",
      CellTags->"1"],
    Cell[317366, 10170, 849, 28, 36, "Assumption",
      CellTags->"1"],
    Cell[348484, 11157, 331, 12, 36, "Assumption",
      CellTags->"1"],
    Cell[366422, 11843, 762, 26, 45, "Conclusion",
      CellTags->"1"],
    Cell[396183, 13100, 762, 26, 45, "Conclusion",
      CellTags->"1"],
    Cell[520306, 18102, 1350, 42, 49, "Conclusion",
      CellTags->"1"],
    Cell[642356, 22102, 1350, 42, 49, "Conclusion",
      CellTags->"1"]},
  "2"->{
    Cell[161408, 4928, 932, 31, 36, "Conclusion",
      CellTags->"2"],
    Cell[188203, 5855, 1480, 46, 36, "Conclusion",
      CellTags->"2"],
    Cell[220148, 6941, 1123, 36, 36, "Conclusion",
      CellTags->"2"],
    Cell[239514, 7625, 806, 27, 36, "Conclusion",
      CellTags->"2"],
    Cell[274255, 8809, 2578, 71, 37, "Conclusion",
      CellTags->"2"],
    Cell[318245, 10202, 806, 27, 36, "Conclusion",
      CellTags->"2"],
    Cell[348845, 11173, 1809, 52, 48, "Conclusion",
      CellTags->"2"],
    Cell[374440, 12216, 1031, 33, 45, "Assumption",
      CellTags->"2"],
    Cell[404201, 13473, 1031, 33, 45, "Assumption",
      CellTags->"2"],
    Cell[525016, 18299, 1635, 49, 49, "Assumption",
      CellTags->"2"],
    Cell[647066, 22299, 1635, 49, 49, "Assumption",
      CellTags->"2"]},
  "3"->{
    Cell[163573, 5022, 864, 29, 49, "Assumption",
      CellTags->"3"],
    Cell[190016, 5923, 1563, 45, 45, "Assumption",
      CellTags->"3"],
    Cell[221604, 6999, 981, 32, 45, "Assumption",
      CellTags->"3"],
    Cell[240653, 7674, 1152, 35, 45, "Assumption",
      CellTags->"3"],
    Cell[277166, 8902, 2072, 57, 49, "Assumption",
      CellTags->"3"],
    Cell[319379, 10251, 2303, 65, 61, "Assumption",
      CellTags->"3"],
    Cell[350685, 11229, 693, 23, 39, "Assumption",
      CellTags->"3"],
    Cell[375552, 12256, 1126, 36, 45, "Conclusion",
      CellTags->"3"],
    Cell[405313, 13513, 1126, 36, 45, "Conclusion",
      CellTags->"3"],
    Cell[526732, 18355, 1734, 52, 49, "Conclusion",
      CellTags->"3"],
    Cell[648782, 22355, 1734, 52, 49, "Conclusion",
      CellTags->"3"]},
  "4"->{
    Cell[164652, 5065, 573, 21, 36, "Assumption",
      CellTags->"4"],
    Cell[191912, 5990, 1565, 45, 45, "Assumption",
      CellTags->"4"],
    Cell[222800, 7045, 739, 25, 36, "Assumption",
      CellTags->"4"],
    Cell[242138, 7731, 1152, 35, 45, "Assumption",
      CellTags->"4"],
    Cell[279571, 8981, 2072, 57, 49, "Assumption",
      CellTags->"4"],
    Cell[321909, 10330, 2205, 63, 66, "Assumption",
      CellTags->"4"],
    Cell[351408, 11256, 693, 23, 39, "Conclusion",
      CellTags->"4"],
    Cell[367578, 11890, 481, 17, 36, "Conclusion",
      CellTags->"4"],
    Cell[397339, 13147, 481, 17, 36, "Conclusion",
      CellTags->"4"],
    Cell[521882, 18158, 908, 30, 36, "Conclusion",
      CellTags->"4"],
    Cell[643932, 22158, 908, 30, 36, "Conclusion",
      CellTags->"4"]},
  "5"->{
    Cell[165560, 5108, 864, 29, 49, "Assumption",
      CellTags->"5"],
    Cell[193815, 6057, 2571, 69, 45, "Conclusion",
      CellTags->"5"],
    Cell[223872, 7092, 983, 32, 45, "Assumption",
      CellTags->"5"],
    Cell[243628, 7788, 1550, 45, 45, "Conclusion",
      CellTags->"5"],
    Cell[281981, 9060, 4450, 110, 49, "Conclusion",
      CellTags->"5"],
    Cell[324443, 10415, 2303, 65, 61, "Assumption",
      CellTags->"5"],
    Cell[352778, 11310, 1225, 38, 52, "Assumption",
      CellTags->"5"],
    Cell[369106, 11958, 721, 25, 45, "Conclusion",
      CellTags->"5"],
    Cell[398867, 13215, 721, 25, 45, "Conclusion",
      CellTags->"5"],
    Cell[528682, 18421, 1245, 39, 36, "Conclusion",
      CellTags->"5"],
    Cell[650732, 22421, 1245, 39, 36, "Conclusion",
      CellTags->"5"]},
  "6"->{
    Cell[166639, 5151, 573, 21, 36, "Assumption",
      CellTags->"6"],
    Cell[196417, 6130, 641, 22, 36, "Assumption",
      CellTags->"6"],
    Cell[225070, 7138, 741, 25, 36, "Assumption",
      CellTags->"6"],
    Cell[245209, 7837, 309, 12, 36, "Assumption",
      CellTags->"6"],
    Cell[286462, 9174, 888, 28, 36, "Assumption",
      CellTags->"6"],
    Cell[326973, 10494, 2205, 63, 66, "Assumption",
      CellTags->"6"],
    Cell[354186, 11362, 587, 21, 36, "Assumption",
      CellTags->"6"],
    Cell[370215, 12007, 176, 8, 36, "Conclusion",
      CellTags->"6"],
    Cell[399976, 13264, 176, 8, 36, "Conclusion",
      CellTags->"6"],
    Cell[536259, 18704, 2226, 65, 49, "Conclusion",
      CellTags->"6"],
    Cell[658353, 22704, 2226, 65, 49, "Conclusion",
      CellTags->"6"]},
  "7"->{
    Cell[167719, 5202, 950, 32, 36, "Assumption",
      CellTags->"7"],
    Cell[197088, 6156, 1499, 45, 36, "Conclusion",
      CellTags->"7"],
    Cell[226316, 7193, 1480, 46, 36, "Assumption",
      CellTags->"7"],
    Cell[245548, 7853, 947, 31, 36, "Conclusion",
      CellTags->"7"],
    Cell[287380, 9206, 2861, 78, 37, "Conclusion",
      CellTags->"7"],
    Cell[329512, 10579, 2890, 78, 61, "Conclusion",
      CellTags->"7"],
    Cell[355106, 11405, 1573, 48, 48, "Assumption",
      CellTags->"7"],
    Cell[371309, 12070, 444, 16, 36, "Assumption",
      CellTags->"7"],
    Cell[401070, 13327, 444, 16, 36, "Assumption",
      CellTags->"7"],
    Cell[538873, 18793, 1492, 45, 49, "Conclusion",
      CellTags->"7"],
    Cell[660967, 22793, 1492, 45, 49, "Conclusion",
      CellTags->"7"]},
  "8"->{
    Cell[169013, 5256, 1043, 34, 49, "Conclusion",
      CellTags->"8"],
    Cell[199040, 6226, 765, 26, 36, "Assumption",
      CellTags->"8"],
    Cell[228134, 7261, 1527, 47, 45, "Conclusion",
      CellTags->"8"],
    Cell[246820, 7906, 609, 21, 36, "Assumption",
      CellTags->"8"],
    Cell[290572, 9306, 1267, 38, 36, "Assumption",
      CellTags->"8"],
    Cell[332433, 10661, 309, 12, 36, "Assumption",
      CellTags->"8"],
    Cell[357004, 11475, 587, 21, 36, "Assumption",
      CellTags->"8"],
    Cell[371834, 12093, 529, 19, 36, "Conclusion",
      CellTags->"8"],
    Cell[401595, 13350, 529, 19, 36, "Conclusion",
      CellTags->"8"],
    Cell[545882, 19090, 2109, 60, 49, "Assumption",
      CellTags->"8"],
    Cell[667976, 23090, 2109, 60, 49, "Assumption",
      CellTags->"8"]},
  "lim+"->{
    Cell[171491, 5370, 4369, 121, 49, "Conclusion",
      CellTags->"lim+"],
    Cell[212362, 6711, 4369, 121, 49, "Assumption",
      CellTags->"lim+"]},
  "l4:"->{
    Cell[175904, 5495, 3175, 86, 53, "Assumption",
      CellTags->"l4:"]},
  "+:"->{
    Cell[179082, 5583, 1915, 58, 49, "Assumption",
      CellTags->"+:"]},
  "| + |"->{
    Cell[181000, 5643, 3711, 100, 49, "Assumption",
      CellTags->"| + |"]},
  "\[GreaterEqual]max "->{
    Cell[184714, 5745, 2003, 58, 48, "Assumption",
      CellTags->"\[GreaterEqual]max "]},
  "9"->{
    Cell[200134, 6274, 850, 27, 36, "Assumption",
      CellTags->"9"],
    Cell[247754, 7949, 609, 21, 36, "Assumption",
      CellTags->"9"],
    Cell[292168, 9366, 1039, 32, 37, "Assumption",
      CellTags->"9"],
    Cell[332796, 10677, 2079, 59, 63, "Conclusion",
      CellTags->"9"],
    Cell[359632, 11576, 1225, 38, 52, "Conclusion",
      CellTags->"9"],
    Cell[377072, 12313, 805, 27, 36, "Conclusion",
      CellTags->"9"],
    Cell[406833, 13570, 805, 27, 36, "Conclusion",
      CellTags->"9"],
    Cell[548072, 19157, 2310, 65, 49, "Conclusion",
      CellTags->"9"],
    Cell[670166, 23157, 2310, 65, 49, "Conclusion",
      CellTags->"9"]},
  "10"->{
    Cell[201313, 6323, 854, 27, 36, "Assumption",
      CellTags->"10"],
    Cell[248692, 7992, 346, 13, 41, "Assumption",
      CellTags->"10"],
    Cell[293536, 9420, 1041, 32, 37, "Assumption",
      CellTags->"10"],
    Cell[335213, 10758, 2271, 63, 63, "Conclusion",
      CellTags->"10"],
    Cell[361112, 11629, 589, 21, 36, "Conclusion",
      CellTags->"10"],
    Cell[379472, 12408, 1194, 38, 45, "Conclusion",
      CellTags->"10"],
    Cell[409233, 13665, 1194, 38, 45, "Conclusion",
      CellTags->"10"],
    Cell[540591, 18852, 1149, 37, 36, "Conclusion",
      CellTags->"10"],
    Cell[662685, 22852, 1149, 37, 36, "Conclusion",
      CellTags->"10"]},
  "11"->{
    Cell[204352, 6433, 1657, 48, 36, "Conclusion",
      CellTags->"11"],
    Cell[249365, 8027, 648, 22, 41, "Assumption",
      CellTags->"11"],
    Cell[298205, 9572, 2075, 60, 37, "Conclusion",
      CellTags->"11"],
    Cell[337871, 10843, 2863, 72, 67, "Conclusion",
      CellTags->"11"],
    Cell[381063, 12470, 611, 21, 36, "Conclusion",
      CellTags->"11"],
    Cell[410824, 13727, 611, 21, 36, "Conclusion",
      CellTags->"11"],
    Cell[672692, 23236, 1880, 56, 36, "Conclusion",
      CellTags->"11"]},
  "l3+"->{
    Cell[208951, 6613, 3367, 94, 49, "Conclusion",
      CellTags->"l3+"],
    Cell[234664, 7472, 3116, 87, 49, "Assumption",
      CellTags->"l3+"]},
  "l3:"->{
    Cell[216734, 6834, 2208, 63, 53, "Assumption",
      CellTags->"l3:"]},
  "l2+"->{
    Cell[230130, 7338, 2386, 69, 49, "Conclusion",
      CellTags->"l2+"],
    Cell[303713, 9780, 2386, 69, 49, "Conclusion",
      CellTags->"l2+"]},
  "l2:"->{
    Cell[232560, 7411, 2101, 59, 53, "Assumption",
      CellTags->"l2:"]},
  "/2>"->{
    Cell[237783, 7561, 821, 28, 45, "Assumption",
      CellTags->"/2>"]},
  "12"->{
    Cell[250340, 8071, 648, 22, 41, "Assumption",
      CellTags->"12"],
    Cell[383941, 12598, 864, 28, 36, "Assumption",
      CellTags->"12"],
    Cell[413702, 13855, 864, 28, 36, "Assumption",
      CellTags->"12"],
    Cell[691870, 23896, 3167, 84, 49, "Conclusion",
      CellTags->"12"]},
  "13"->{
    Cell[251326, 8115, 1227, 38, 41, "Conclusion",
      CellTags->"13"],
    Cell[384886, 12633, 955, 31, 36, "Conclusion",
      CellTags->"13"],
    Cell[414647, 13890, 955, 31, 36, "Conclusion",
      CellTags->"13"],
    Cell[695427, 24004, 2031, 57, 36, "Conclusion",
      CellTags->"13"]},
  "cont[ \[RawStar] ]"->{
    Cell[255097, 8275, 5530, 142, 81, "Conclusion",
      CellTags->"cont[ \[RawStar] ]"]},
  "c4:"->{
    Cell[260671, 8421, 3761, 98, 59, "Assumption",
      CellTags->"c4:"]},
  "f\[RawStar]g"->{
    Cell[264435, 8521, 1917, 58, 49, "Assumption",
      CellTags->"f\[RawStar]g"]},
  "| \[RawStar] |"->{
    Cell[266355, 8581, 4448, 116, 48, "Assumption",
      CellTags->"| \[RawStar] |"]},
  "min<"->{
    Cell[270806, 8699, 1931, 58, 48, "Assumption",
      CellTags->"min<"]},
  "l"->{
    Cell[306143, 9853, 3451, 90, 82, "Assumption",
      CellTags->"l"]},
  "dist+"->{
    Cell[309597, 9945, 3814, 101, 49, "Assumption",
      CellTags->"dist+"]},
  "f+g"->{
    Cell[313414, 10048, 1917, 58, 49, "Assumption",
      CellTags->"f+g"]},
  "max\[GreaterEqual]"->{
    Cell[315334, 10108, 2001, 58, 48, "Assumption",
      CellTags->"max\[GreaterEqual]"]},
  "symm\[Implies]\[LeftFloor]\[RightFloor]"->{
    Cell[341401, 10955, 2636, 69, 57, "Conclusion",
      CellTags->"symm\[Implies]\[LeftFloor]\[RightFloor]"]},
  "symm:"->{
    Cell[344081, 11028, 2313, 63, 57, "Assumption",
      CellTags->"symm:"]},
  "\[LeftFloor] \[RightFloor]:"->{
    Cell[346397, 11093, 2056, 60, 57, "Assumption",
      CellTags->"\[LeftFloor] \[RightFloor]:"]},
  " + = "->{
    Cell[362274, 11686, 1166, 38, 48, "Conclusion",
      CellTags->" + = "],
    Cell[392035, 12943, 1166, 38, 48, "Conclusion",
      CellTags->" + = "],
    Cell[428955, 14514, 1166, 38, 48, "Conclusion",
      CellTags->" + = "],
    Cell[491722, 17034, 1166, 38, 48, "Conclusion",
      CellTags->" + = "]},
  " +0:"->{
    Cell[363484, 11728, 727, 25, 45, "Assumption",
      CellTags->" +0:"],
    Cell[393245, 12985, 727, 25, 45, "Assumption",
      CellTags->" +0:"],
    Cell[422449, 14222, 727, 25, 45, "Assumption",
      CellTags->" +0:"],
    Cell[430891, 14583, 727, 25, 45, "Assumption",
      CellTags->" +0:"],
    Cell[464288, 15942, 727, 25, 45, "Assumption",
      CellTags->" +0:"],
    Cell[494975, 17147, 727, 25, 45, "Assumption",
      CellTags->" +0:"]},
  " + .:"->{
    Cell[364214, 11755, 1320, 42, 48, "Assumption",
      CellTags->" + .:"],
    Cell[393975, 13012, 1320, 42, 48, "Assumption",
      CellTags->" + .:"],
    Cell[423179, 14249, 1320, 42, 48, "Assumption",
      CellTags->" + .:"],
    Cell[431621, 14610, 1320, 42, 48, "Assumption",
      CellTags->" + .:"],
    Cell[465018, 15969, 1320, 42, 48, "Assumption",
      CellTags->" + .:"],
    Cell[495705, 17174, 1320, 42, 48, "Assumption",
      CellTags->" + .:"]},
  "14"->{
    Cell[383019, 12556, 572, 20, 36, "Conclusion",
      CellTags->"14"],
    Cell[412780, 13813, 572, 20, 36, "Conclusion",
      CellTags->"14"],
    Cell[701908, 24246, 2668, 74, 36, "Assumption",
      CellTags->"14"]},
  "15"->{
    Cell[386493, 12702, 570, 20, 36, "Conclusion",
      CellTags->"15"],
    Cell[416254, 13959, 570, 20, 36, "Conclusion",
      CellTags->"15"],
    Cell[704657, 24327, 2889, 80, 36, "Conclusion",
      CellTags->"15"]},
  "18"->{
    Cell[388846, 12808, 572, 20, 36, "Conclusion",
      CellTags->"18"],
    Cell[418607, 14065, 572, 20, 36, "Conclusion",
      CellTags->"18"],
    Cell[556949, 19501, 1880, 56, 36, "Assumption",
      CellTags->"18"]},
  "16"->{
    Cell[389768, 12850, 807, 27, 36, "Assumption",
      CellTags->"16"],
    Cell[419529, 14107, 807, 27, 36, "Assumption",
      CellTags->"16"]},
  "17"->{
    Cell[390656, 12884, 894, 30, 36, "Conclusion",
      CellTags->"17"],
    Cell[420417, 14141, 894, 30, 36, "Conclusion",
      CellTags->"17"],
    Cell[550770, 19246, 1510, 46, 36, "Conclusion",
      CellTags->"17"]},
  "19"->{
    Cell[421682, 14193, 723, 25, 45, "Conclusion",
      CellTags->"19"],
    Cell[430165, 14556, 723, 25, 45, "Assumption",
      CellTags->"19"],
    Cell[463562, 15915, 723, 25, 45, "Assumption",
      CellTags->"19"],
    Cell[494249, 17120, 723, 25, 45, "Assumption",
      CellTags->"19"],
    Cell[558910, 19564, 2011, 60, 36, "Conclusion",
      CellTags->"19"]},
  "20"->{
    Cell[424889, 14315, 178, 8, 36, "Conclusion",
      CellTags->"20"],
    Cell[433829, 14698, 764, 26, 45, "Conclusion",
      CellTags->"20"]},
  "21"->{
    Cell[425987, 14378, 446, 16, 36, "Assumption",
      CellTags->"21"],
    Cell[437383, 14862, 1033, 33, 45, "Assumption",
      CellTags->"21"]},
  "22"->{
    Cell[426514, 14401, 531, 19, 36, "Conclusion",
      CellTags->"22"],
    Cell[438497, 14902, 1128, 36, 45, "Conclusion",
      CellTags->"22"]},
  "23"->{
    Cell[434999, 14745, 490, 18, 36, "Conclusion",
      CellTags->"23"]},
  "24"->{
    Cell[440021, 14959, 807, 27, 36, "Conclusion",
      CellTags->"24"]},
  "25"->{
    Cell[442423, 15054, 1194, 38, 45, "Conclusion",
      CellTags->"25"]},
  "26"->{
    Cell[444014, 15116, 611, 21, 36, "Conclusion",
      CellTags->"26"]},
  "27"->{
    Cell[446448, 15227, 864, 28, 36, "Assumption",
      CellTags->"27"]},
  "28"->{
    Cell[447393, 15262, 955, 31, 36, "Conclusion",
      CellTags->"28"]},
  "29"->{
    Cell[450974, 15404, 1077, 33, 36, "Conclusion",
      CellTags->"29"]},
  "30"->{
    Cell[452729, 15476, 570, 20, 36, "Conclusion",
      CellTags->"30"]},
  "31"->{
    Cell[455083, 15585, 807, 27, 36, "Assumption",
      CellTags->"31"]},
  "32"->{
    Cell[455971, 15619, 894, 30, 36, "Conclusion",
      CellTags->"32"]},
  "33"->{
    Cell[460730, 15813, 1077, 33, 36, "Conclusion",
      CellTags->"33"]},
  "34"->{
    Cell[462204, 15869, 1314, 42, 48, "Conclusion",
      CellTags->"34"],
    Cell[492932, 17076, 1314, 42, 48, "Assumption",
      CellTags->"34"]},
  "35"->{
    Cell[466728, 16035, 863, 29, 45, "Conclusion",
      CellTags->"35"],
    Cell[497421, 17240, 764, 26, 45, "Conclusion",
      CellTags->"35"]},
  "38"->{
    Cell[467809, 16078, 569, 19, 36, "Conclusion",
      CellTags->"38"],
    Cell[498413, 17280, 490, 18, 36, "Conclusion",
      CellTags->"38"]},
  "39"->{
    Cell[469539, 16151, 770, 26, 45, "Conclusion",
      CellTags->"39"],
    Cell[503009, 17473, 814, 28, 36, "Conclusion",
      CellTags->"39"]},
  "40"->{
    Cell[470699, 16201, 192, 8, 36, "Conclusion",
      CellTags->"40"]},
  "41"->{
    Cell[471832, 16264, 489, 17, 36, "Assumption",
      CellTags->"41"]},
  "42"->{
    Cell[472402, 16288, 617, 21, 36, "Conclusion",
      CellTags->"42"]},
  "36"->{
    Cell[475008, 16403, 1187, 37, 45, "Assumption",
      CellTags->"36"],
    Cell[500539, 17383, 1033, 33, 45, "Assumption",
      CellTags->"36"]},
  "37"->{
    Cell[476276, 16447, 1335, 41, 45, "Conclusion",
      CellTags->"37"],
    Cell[501653, 17423, 1128, 36, 45, "Conclusion",
      CellTags->"37"]},
  "43"->{
    Cell[477829, 16502, 993, 31, 36, "Conclusion",
      CellTags->"43"]},
  "44"->{
    Cell[480695, 16608, 1406, 42, 45, "Conclusion",
      CellTags->"44"]},
  "45"->{
    Cell[482491, 16674, 796, 26, 36, "Conclusion",
      CellTags->"45"]},
  "46"->{
    Cell[485444, 16800, 1059, 33, 36, "Assumption",
      CellTags->"46"]},
  "47"->{
    Cell[486584, 16840, 1154, 36, 36, "Conclusion",
      CellTags->"47"]},
  "( \[RawStar] ) \[RawStar] "->{
    Cell[507030, 17645, 1781, 54, 49, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] "],
    Cell[632029, 21741, 1781, 54, 49, "Conclusion",
      CellTags->"( \[RawStar] ) \[RawStar] "]},
  " \[RawStar]0"->{
    Cell[508855, 17703, 605, 22, 45, "Assumption",
      CellTags->" \[RawStar]0"],
    Cell[633854, 21799, 605, 22, 45, "Assumption",
      CellTags->" \[RawStar]0"]},
  " \[RawStar]  ^+"->{
    Cell[509463, 17727, 1396, 44, 48, "Assumption",
      CellTags->" \[RawStar]  ^+"],
    Cell[634462, 21823, 1396, 44, 48, "Assumption",
      CellTags->" \[RawStar]  ^+"]},
  "0\[RawStar]"->{
    Cell[510862, 17773, 598, 21, 45, "Assumption",
      CellTags->"0\[RawStar]"],
    Cell[635861, 21869, 598, 21, 45, "Assumption",
      CellTags->"0\[RawStar]"]},
  " ^+\[RawStar]"->{
    Cell[511463, 17796, 1392, 44, 48, "Assumption",
      CellTags->" ^+\[RawStar]"],
    Cell[636462, 21892, 1392, 44, 48, "Assumption",
      CellTags->" ^+\[RawStar]"]},
  " +0"->{
    Cell[512858, 17842, 725, 25, 45, "Assumption",
      CellTags->" +0"],
    Cell[637857, 21938, 725, 25, 45, "Assumption",
      CellTags->" +0"]},
  " + ^+"->{
    Cell[513586, 17869, 1320, 42, 48, "Assumption",
      CellTags->" + ^+"],
    Cell[638585, 21965, 1320, 42, 48, "Assumption",
      CellTags->" + ^+"]},
  "0+ "->{
    Cell[514909, 17913, 725, 25, 45, "Assumption",
      CellTags->"0+ "],
    Cell[639908, 22009, 725, 25, 45, "Assumption",
      CellTags->"0+ "]},
  "^++ "->{
    Cell[515637, 17940, 1318, 42, 48, "Assumption",
      CellTags->"^++ "],
    Cell[640636, 22036, 1318, 42, 48, "Assumption",
      CellTags->"^++ "]},
  " + "->{
    Cell[516958, 17984, 1162, 38, 48, "Assumption",
      CellTags->" + "]},
  "( + ) + "->{
    Cell[518123, 18024, 1781, 54, 49, "Assumption",
      CellTags->"( + ) + "]},
  ""->{
    Cell[746072, 25492, 8137, 194, 113, "Conclusion",
      CellTags->""]},
  ".1"->{
    Cell[754708, 25704, 3676, 96, 49, "Conclusion",
      CellTags->".1"]},
  ".2"->{
    Cell[758387, 25802, 5234, 134, 82, "Conclusion",
      CellTags->".2"]},
  ".1.structure"->{
    Cell[763942, 25954, 334, 10, 49, "Conclusion",
      CellTags->".1.structure"]},
  ".1.implication"->{
    Cell[767396, 26063, 309, 9, 49, "Conclusion",
      CellTags->".1.implication"]},
  ".1.not-exists"->{
    Cell[767912, 26085, 329, 10, 52, "Conclusion",
      CellTags->".1.not-exists"]},
  ".1.not-exists-slack"->{
    Cell[768553, 26112, 375, 11, 52, "Conclusion",
      CellTags->".1.not-exists-slack"]},
  ".2.structure"->{
    Cell[770155, 26178, 358, 10, 49, "Conclusion",
      CellTags->".2.structure"]},
  ".2.implication"->{
    Cell[774936, 26324, 352, 10, 49, "Conclusion",
      CellTags->".2.implication"]},
  ".2.not-exists"->{
    Cell[775495, 26347, 391, 11, 52, "Conclusion",
      CellTags->".2.not-exists"]},
  ".2.not-exists-slack"->{
    Cell[776207, 26375, 423, 11, 52, "Conclusion",
      CellTags->".2.not-exists-slack"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"title", 803518, 27343},
  {"4-ary limit", 803608, 27346},
  {"distance of sum", 810521, 27477},
  {"maximum", 817255, 27604},
  {"sum of sequences", 822954, 27710},
  {"2-ary limit of sum", 828655, 27816},
  {"Divides Sum", 835076, 27938},
  {"greatest common divisor", 835727, 27953},
  {"Greatest Common Divisor", 835928, 27958},
  {"divides difference", 836124, 27963},
  {"common divisors and difference", 836904, 27980},
  {"Euclid's Theorem", 837100, 27985},
  {"divides", 837274, 27990},
  {"distributivity", 837506, 27995},
  {"2-ary limit", 837639, 27998},
  {"3-ary limit", 843668, 28111},
  {"3-ary limit of sum", 849571, 28221},
  {"4-ary limit of sum", 855380, 28329},
  {"fsum", 861385, 28441},
  {"Limit of a Sequence", 867969, 28564},
  {"limit of sum", 872971, 28655},
  {"lim sum", 878620, 28758},
  {"max-greater", 884063, 28857},
  {"3-ary continuity of sum: variant", 890556, 28978},
  {"3-ary limit of sum: variant", 890755, 28983},
  {"positiveness", 891165, 28993},
  {"2-ary continuity", 891486, 29001},
  {"continuity", 892087, 29013},
  {"continuity 2-ary", 892872, 29031},
  {"3-ary continuity", 893703, 29049},
  {"continuity3", 894329, 29062},
  {"continuity 3-ary", 894746, 29072},
  {"4-ary continuity", 895601, 29091},
  {"continuity4", 896501, 29109},
  {"continuity 4-ary", 896754, 29115},
  {"4-ary continuity of product", 897246, 29126},
  {"fprod", 898005, 29141},
  {"product of functions", 898138, 29144},
  {"distance of prod", 898709, 29155},
  {"distance of product", 898870, 29159},
  {"minimum", 899461, 29171},
  {"min-lower", 900149, 29185},
  {"continuity of 4-ary product", 900413, 29191},
  {"continuity prod 4-ary", 900885, 29200},
  {"continuity sum 4-ary", 901356, 29209},
  {"cont sum", 901815, 29218},
  {"Classes Modulo a Predicate", 902292, 29227},
  {"Classes Modulo Symmetric Predicates", 903002, 29243},
  {"Symmetry", 903510, 29255},
  {"is symmetric", 903825, 29263},
  {"is\[Dash]symmetric", 903987, 29267},
  {"Reflexivity", 904142, 29271},
  {"equivalence class", 904303, 29275},
  {"Equivalence class", 904836, 29287},
  {"Equivalence Classes", 905371, 29299},
  {"Classes Modulo Predicates with Special Properties", 905936, 29311},
  {"Classes Modulo Reflexive Predicates", 906312, 29319},
  {"addition", 906661, 29327},
  {"Addition", 906857, 29332},
  {"Multiplication", 907506, 29347},
  {"comm\[RawStar]", 908459, 29369},
  {"comm+", 908993, 29382},
  {"commutativity of addition", 909547, 29395},
  {"assoc+", 909919, 29404},
  {"left addition", 910296, 29413},
  {"Equational Properties of Addition", 910693, 29422},
  {"Some Equational Properties of Multiplication", 911155, 29431},
  {"Associativity of Multiplication", 911332, 29435},
  {"Associativity of Multiplicatios", 911539, 29440},
  {"Test", 911719, 29445},
  {"PauleSchorn", 911921, 29450},
  {"Gauss", 912152, 29457},
  {"SIAM series", 912318, 29462},
  {"math", 912408, 29465},
  {"Mathematica", 912516, 29468},
  {"Mathematica Polynomials", 912712, 29473},
  {"\[DoubleStruckCapitalM]\[DoubleStruckCapitalP]", 912858, 29476},
  {"\[DoubleStruckCapitalP]", 913046, 29481},
  {"T", 913420, 29490},
  {"Reduction Domain", 913653, 29495},
  {"RDMP", 913750, 29498},
  {"RD", 913942, 29503},
  {"computing-session", 914079, 29506},
  {"sets", 914182, 29509},
  {"divdiff", 914336, 29514},
  {"div:", 914428, 29517},
  {"distr", 914518, 29520},
  {"1", 914605, 29523},
  {"2", 915418, 29546},
  {"3", 916234, 29569},
  {"4", 917050, 29592},
  {"5", 917862, 29615},
  {"6", 918678, 29638},
  {"7", 919487, 29661},
  {"8", 920302, 29684},
  {"lim+", 921118, 29707},
  {"l4:", 921284, 29712},
  {"+:", 921370, 29715},
  {"| + |", 921458, 29718},
  {"\[GreaterEqual]max ", 921564, 29721},
  {"9", 921665, 29724},
  {"10", 922335, 29743},
  {"11", 923015, 29762},
  {"l3+", 923546, 29777},
  {"l3:", 923708, 29782},
  {"l2+", 923795, 29785},
  {"l2:", 923957, 29790},
  {"/2>", 924044, 29793},
  {"12", 924129, 29796},
  {"13", 924436, 29805},
  {"cont[ \[RawStar] ]", 924760, 29814},
  {"c4:", 924863, 29817},
  {"f\[RawStar]g", 924959, 29820},
  {"| \[RawStar] |", 925066, 29823},
  {"min<", 925166, 29826},
  {"l", 925252, 29829},
  {"dist+", 925339, 29832},
  {"f+g", 925429, 29835},
  {"max\[GreaterEqual]", 925532, 29838},
  {"symm\[Implies]\[LeftFloor]\[RightFloor]", 925671, 29841},
  {"symm:", 925797, 29844},
  {"\[LeftFloor] \[RightFloor]:", 925911, 29847},
  {" + = ", 926025, 29850},
  {" +0:", 926350, 29859},
  {" + .:", 926820, 29872},
  {"14", 927299, 29885},
  {"15", 927533, 29892},
  {"18", 927767, 29899},
  {"16", 928001, 29906},
  {"17", 928160, 29911},
  {"19", 928394, 29918},
  {"20", 928776, 29929},
  {"21", 928934, 29934},
  {"22", 929094, 29939},
  {"23", 929254, 29944},
  {"24", 929339, 29947},
  {"25", 929424, 29950},
  {"26", 929510, 29953},
  {"27", 929595, 29956},
  {"28", 929680, 29959},
  {"29", 929765, 29962},
  {"30", 929851, 29965},
  {"31", 929936, 29968},
  {"32", 930021, 29971},
  {"33", 930106, 29974},
  {"34", 930192, 29977},
  {"35", 930353, 29982},
  {"38", 930512, 29987},
  {"39", 930671, 29992},
  {"40", 930830, 29997},
  {"41", 930914, 30000},
  {"42", 930999, 30003},
  {"36", 931084, 30006},
  {"37", 931245, 30011},
  {"43", 931406, 30016},
  {"44", 931491, 30019},
  {"45", 931577, 30022},
  {"46", 931662, 30025},
  {"47", 931748, 30028},
  {"( \[RawStar] ) \[RawStar] ", 931858, 30031},
  {" \[RawStar]0", 932077, 30036},
  {" \[RawStar]  ^+", 932269, 30041},
  {"0\[RawStar]", 932465, 30046},
  {" ^+\[RawStar]", 932653, 30051},
  {" +0", 932837, 30056},
  {" + ^+", 933001, 30061},
  {"0+ ", 933169, 30066},
  {"^++ ", 933332, 30071},
  {" + ", 933498, 30076},
  {"( + ) + ", 933591, 30079},
  {"", 933681, 30082},
  {".1", 933767, 30085},
  {".2", 933853, 30088},
  {".1.structure", 933950, 30091},
  {".1.implication", 934057, 30094},
  {".1.not-exists", 934164, 30097},
  {".1.not-exists-slack", 934277, 30100},
  {".2.structure", 934389, 30103},
  {".2.implication", 934496, 30106},
  {".2.not-exists", 934604, 30109},
  {".2.not-exists-slack", 934717, 30112}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 194, 7, 162, "Subtitle",
  CellTags->"title"],
Cell[1936, 60, 210, 4, 124, "Subsubtitle"],
Cell[2149, 66, 311, 11, 121, "Text"],
Cell[2463, 79, 461, 11, 121, "Text"],
Cell[2927, 92, 90, 4, 57, "Text"],
Cell[3020, 98, 257, 7, 89, "Text"],

Cell[CellGroupData[{
Cell[3302, 109, 66, 1, 83, "Subsection"],
Cell[3371, 112, 495, 13, 153, "Text"],
Cell[3869, 127, 469, 12, 121, "Text"],
Cell[4341, 141, 586, 15, 153, "Text"],
Cell[4930, 158, 234, 6, 89, "Text"],
Cell[5167, 166, 528, 13, 153, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5732, 184, 74, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[5831, 189, 59, 1, 70, "Subsubsection"],
Cell[5893, 192, 133, 5, 57, "Text"],

Cell[CellGroupData[{
Cell[6051, 201, 75, 2, 49, "Input"],
Cell[6129, 205, 183, 3, 67, "Print"]
}, Open  ]],
Cell[6327, 211, 252, 6, 89, "Text"],
Cell[6582, 219, 125, 3, 49, "Input"],
Cell[6710, 224, 214, 4, 49, "Input"],
Cell[6927, 230, 417, 7, 109, "Input",
  CellTags->{
  "4-ary limit", "distance of sum", "maximum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[7381, 242, 72, 1, 70, "Subsubsection"],
Cell[7456, 245, 164, 5, 57, "Text"],
Cell[7623, 252, 76, 1, 57, "Text"],
Cell[7702, 255, 95, 1, 57, "Text"],
Cell[7800, 258, 78, 1, 57, "Text"],
Cell[7881, 261, 138, 3, 57, "Text"],
Cell[8022, 266, 39, 0, 57, "Text"],
Cell[8064, 268, 398, 8, 121, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8499, 281, 55, 1, 70, "Subsubsection"],
Cell[8557, 284, 214, 6, 89, "Text"],
Cell[8774, 292, 466, 12, 132, "Input",
  CellTags->{
  "2-ary limit of sum", "Divides Sum", "greatest common divisor", 
    "Greatest Common Divisor"}],
Cell[9243, 306, 612, 15, 153, "Text"],

Cell[CellGroupData[{
Cell[9880, 325, 137, 3, 49, "Input"],
Cell[10020, 330, 35, 1, 49, "Output"]
}, Open  ]],
Cell[10070, 334, 429, 9, 153, "Text"],
Cell[10502, 345, 87, 2, 57, "Text"],

Cell[CellGroupData[{
Cell[10614, 351, 156, 4, 49, "Input"],
Cell[10773, 357, 68, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10878, 363, 158, 4, 41, "Input"],
Cell[11039, 369, 68, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11144, 375, 160, 4, 41, "Input"],
Cell[11307, 381, 70, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11414, 387, 162, 4, 41, "Input"],
Cell[11579, 393, 70, 1, 49, "Output"]
}, Open  ]],
Cell[11664, 397, 483, 11, 144, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12184, 413, 61, 1, 70, "Subsubsection"],
Cell[12248, 416, 163, 3, 89, "Text"],
Cell[12414, 421, 429, 10, 99, "Input",
  CellTags->{"2-ary limit of sum", "divides difference", "Divides Sum"}],
Cell[12846, 433, 49, 0, 57, "Text"],
Cell[12898, 435, 534, 13, 99, "Input",
  CellTags->{
  "2-ary limit of sum", "common divisors and difference", 
    "divides difference", "Divides Sum"}],
Cell[13435, 450, 55, 0, 57, "Text"],
Cell[13493, 452, 560, 12, 159, "Input",
  CellTags->{
  "2-ary limit of sum", "divides difference", "Divides Sum", 
    "Euclid's Theorem"}],
Cell[14056, 466, 212, 6, 57, "Text"],
Cell[14271, 474, 119, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[14415, 481, 150, 4, 69, "Input"],
Cell[14568, 487, 68, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14673, 493, 152, 4, 69, "Input"],
Cell[14828, 499, 69, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14934, 505, 154, 4, 69, "Input"],
Cell[15091, 511, 70, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15198, 517, 156, 4, 69, "Input"],
Cell[15357, 523, 70, 1, 49, "Output"]
}, Open  ]],
Cell[15442, 527, 114, 3, 57, "Text"],
Cell[15559, 532, 295, 6, 141, "Text"],
Cell[15857, 540, 61, 0, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15955, 545, 83, 1, 41, "Subsubsection"],
Cell[16041, 548, 263, 6, 89, "Text"],
Cell[16307, 556, 629, 16, 99, "Input",
  CellTags->"divides difference"],
Cell[16939, 574, 104, 3, 57, "Text"],
Cell[17046, 579, 536, 13, 109, "Input",
  CellTags->{"divides", "divides difference"}],
Cell[17585, 594, 115, 3, 57, "Text"],
Cell[17703, 599, 604, 15, 99, "Input",
  CellTags->{"distributivity", "divides", "divides difference"}],
Cell[18310, 616, 386, 10, 121, "Text"],

Cell[CellGroupData[{
Cell[18721, 630, 261, 6, 129, "Input"],
Cell[18985, 638, 89, 1, 49, "Output"]
}, Open  ]],
Cell[19089, 642, 53, 0, 57, "Text"],
Cell[19145, 644, 172, 6, 57, "Text"],
Cell[19320, 652, 251, 7, 89, "Text"],
Cell[19574, 661, 186, 6, 57, "Text"],
Cell[19763, 669, 1312, 25, 345, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21124, 700, 59, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[21208, 705, 72, 1, 70, "Subsubsection"],
Cell[21283, 708, 233, 6, 89, "Text"],
Cell[21519, 716, 662, 10, 217, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22218, 731, 50, 1, 70, "Subsubsection"],
Cell[22271, 734, 113, 3, 57, "Text"],
Cell[22387, 739, 60, 2, 49, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22484, 746, 338, 6, 70, "Subsubsection",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[22825, 754, 326, 12, 89, "Text"],

Cell[CellGroupData[{
Cell[23176, 770, 725, 15, 126, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[23904, 787, 183, 3, 67, "Message"]
}, Open  ]],
Cell[24102, 793, 55, 0, 57, "Text"],
Cell[24160, 795, 724, 16, 109, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[24887, 813, 535, 8, 185, "Text"],
Cell[25425, 823, 806, 17, 117, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[26234, 842, 715, 15, 91, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[26952, 859, 699, 15, 117, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[27654, 876, 245, 4, 89, "Text"],
Cell[27902, 882, 768, 20, 185, "Text"],
Cell[28673, 904, 220, 4, 89, "Text"],

Cell[CellGroupData[{
Cell[28918, 912, 850, 20, 126, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[29771, 934, 179, 3, 67, "Message"]
}, Open  ]],
Cell[29965, 940, 822, 17, 144, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[30790, 959, 714, 16, 109, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[31541, 980, 88, 1, 70, "Subsubsection"],
Cell[31632, 983, 157, 3, 89, "Text"],
Cell[31792, 988, 647, 16, 79, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[32442, 1006, 983, 22, 126, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[33428, 1030, 750, 17, 79, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[34181, 1049, 179, 6, 57, "Text"],
Cell[34363, 1057, 1170, 31, 184, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[35536, 1090, 204, 6, 89, "Text"],

Cell[CellGroupData[{
Cell[35765, 1100, 371, 7, 49, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "max-greater", "maximum", "sum of sequences"}],
Cell[36139, 1109, 89, 1, 49, "Output"]
}, Open  ]],
Cell[36243, 1113, 595, 14, 153, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36875, 1132, 88, 1, 70, "Subsubsection"],
Cell[36966, 1135, 113, 3, 57, "Text"],
Cell[37082, 1140, 390, 10, 117, "Input",
  CellTags->{"2-ary limit", "3-ary limit"}],
Cell[37475, 1152, 130, 5, 57, "Text"],

Cell[CellGroupData[{
Cell[37630, 1161, 234, 6, 49, "Input"],
Cell[37867, 1169, 89, 1, 49, "Output"]
}, Open  ]],
Cell[37971, 1173, 595, 14, 153, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38603, 1192, 88, 1, 70, "Subsubsection"],
Cell[38694, 1195, 111, 3, 57, "Text"],
Cell[38808, 1200, 427, 11, 117, "Input",
  CellTags->{
  "3-ary continuity of sum: variant", "3-ary limit of sum: variant", 
    "positiveness"}],
Cell[39238, 1213, 94, 2, 57, "Text"],
Cell[39335, 1217, 612, 14, 144, "Input",
  CellTags->"3-ary limit of sum: variant"],
Cell[39950, 1233, 94, 2, 57, "Text"],
Cell[40047, 1237, 70, 0, 57, "Text"],
Cell[40120, 1239, 482, 11, 148, "Input",
  CellTags->{"2-ary limit", "3-ary limit of sum: variant", "positiveness"}],
Cell[40605, 1252, 130, 5, 57, "Text"],

Cell[CellGroupData[{
Cell[40760, 1261, 414, 10, 49, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "max-greater"}],
Cell[41177, 1273, 89, 1, 49, "Output"]
}, Open  ]],
Cell[41281, 1277, 602, 14, 153, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41920, 1296, 66, 1, 70, "Subsubsection"],
Cell[41989, 1299, 104, 3, 57, "Text"],
Cell[42096, 1304, 548, 14, 117, "Input",
  CellTags->{
  "2-ary continuity", "4-ary limit", "continuity", "continuity 2-ary"}],
Cell[42647, 1320, 613, 16, 117, "Input",
  CellTags->{
  "3-ary continuity", "4-ary limit", "continuity", "continuity3", 
    "continuity 3-ary"}],
Cell[43263, 1338, 780, 18, 126, "Input",
  CellTags->{
  "4-ary continuity", "4-ary limit", "continuity", "continuity 2-ary", 
    "continuity3", "continuity 3-ary", "continuity4", "continuity 4-ary"}],

Cell[CellGroupData[{
Cell[44068, 1360, 1016, 22, 126, "Input",
  CellTags->{
  "4-ary continuity", "4-ary continuity of product", "4-ary limit of sum", 
    "continuity 2-ary", "continuity 3-ary", "limit of sum"}],
Cell[45087, 1384, 195, 3, 37, "Message"],
Cell[45285, 1389, 195, 3, 37, "Message"],
Cell[45483, 1394, 179, 3, 37, "Message"],
Cell[45665, 1399, 210, 4, 37, "Message",
  CellTags->"4-ary continuity of product"]
}, Open  ]],
Cell[45890, 1406, 437, 12, 79, "Input",
  CellTags->{"fprod", "fsum", "product of functions"}],
Cell[46330, 1420, 915, 20, 126, "Input",
  CellTags->{"distance of prod", "distance of product", "distance of sum"}],
Cell[47248, 1442, 558, 14, 79, "Input",
  CellTags->{
  "continuity", "continuity 2-ary", "continuity 3-ary", "continuity 4-ary", 
    "distance of sum", "fsum", "max-greater", "minimum", "min-lower"}],
Cell[47809, 1458, 1324, 35, 184, "Input",
  CellTags->{
  "2-ary continuity", "3-ary continuity", "4-ary continuity", 
    "4-ary continuity of product", "4-ary limit", 
    "continuity of 4-ary product", "continuity prod 4-ary", 
    "continuity sum 4-ary", "cont sum", "distance of product", 
    "distance of sum", "fsum", "limit of sum", "lim sum", "max-greater", 
    "minimum", "product of functions"}],

Cell[CellGroupData[{
Cell[49158, 1497, 196, 4, 79, "Input"],
Cell[49357, 1503, 89, 1, 49, "Output"]
}, Open  ]],
Cell[49461, 1507, 598, 13, 185, "Text"],
Cell[50062, 1522, 218, 6, 89, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[50329, 1534, 113, 3, 83, "Subsection"],

Cell[CellGroupData[{
Cell[50467, 1541, 72, 1, 70, "Subsubsection"],
Cell[50542, 1544, 575, 13, 185, "Text"],
Cell[51120, 1559, 508, 8, 185, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51665, 1572, 338, 6, 70, "Subsubsection",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}],
Cell[52006, 1580, 153, 3, 89, "Text"],
Cell[52162, 1585, 1170, 31, 184, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "Limit of a Sequence", "limit of sum", "lim sum", "max-greater", 
    "maximum", "sum of sequences"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[53369, 1621, 64, 1, 70, "Subsubsection"],
Cell[53436, 1624, 256, 4, 121, "Text"],
Cell[53695, 1630, 372, 7, 49, "Input",
  CellTags->{
  "2-ary limit", "2-ary limit of sum", "3-ary limit", "3-ary limit of sum", 
    "4-ary limit", "4-ary limit of sum", "distance of sum", "fsum", 
    "max-greater", "maximum", "sum of sequences"}],
Cell[54070, 1639, 641, 14, 185, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[54760, 1659, 69, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[54854, 1664, 56, 1, 70, "Subsubsection"],
Cell[54913, 1667, 178, 5, 57, "Text"],
Cell[55094, 1674, 111, 2, 49, "Input"],
Cell[55208, 1678, 289, 7, 49, "Input",
  CellTags->{
  "Classes Modulo a Predicate", "Classes Modulo Symmetric Predicates", 
    "Symmetry"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[55534, 1690, 72, 1, 70, "Subsubsection"],
Cell[55609, 1693, 596, 11, 185, "Text"],
Cell[56208, 1706, 416, 8, 153, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56661, 1719, 69, 1, 70, "Subsubsection"],
Cell[56733, 1722, 271, 5, 121, "Text"],
Cell[57007, 1729, 568, 14, 91, "Input",
  CellTags->{
  "is symmetric", "is\[Dash]symmetric", "Reflexivity", "Symmetry"}],
Cell[57578, 1745, 144, 3, 57, "Text"],
Cell[57725, 1750, 125, 5, 57, "Text"],
Cell[57853, 1757, 604, 15, 112, "Input",
  CellTags->{
  "Classes Modulo a Predicate", "equivalence class", "Equivalence class", 
    "Equivalence Classes"}],
Cell[58460, 1774, 55, 0, 57, "Text"],
Cell[58518, 1776, 857, 19, 91, "Input",
  CellTags->{
  "Classes Modulo a Predicate", 
    "Classes Modulo Predicates with Special Properties", 
    "Classes Modulo Reflexive Predicates", 
    "Classes Modulo Symmetric Predicates", "equivalence class", 
    "Equivalence class", "Equivalence Classes"}],
Cell[59378, 1797, 108, 4, 57, "Text"],

Cell[CellGroupData[{
Cell[59511, 1805, 348, 6, 109, "Input"],
Cell[59862, 1813, 89, 1, 49, "Output"]
}, Open  ]],
Cell[59966, 1817, 205, 4, 89, "Text"],
Cell[60174, 1823, 638, 14, 185, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[60861, 1843, 87, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[60973, 1848, 67, 1, 70, "Subsubsection"],
Cell[61043, 1851, 98, 2, 57, "Text"],
Cell[61144, 1855, 359, 8, 109, "Input",
  CellTags->"addition"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61540, 1868, 72, 1, 70, "Subsubsection"],
Cell[61615, 1871, 707, 15, 185, "Text"],
Cell[62325, 1888, 305, 11, 89, "Text"],
Cell[62633, 1901, 302, 11, 57, "Text"],
Cell[62938, 1914, 130, 3, 57, "Text"],
Cell[63071, 1919, 294, 9, 89, "Text"],
Cell[63368, 1930, 460, 16, 89, "Text"],
Cell[63831, 1948, 580, 21, 121, "Text"],
Cell[64414, 1971, 210, 4, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64661, 1980, 77, 1, 70, "Subsubsection"],
Cell[64741, 1983, 148, 3, 89, "Text"],
Cell[64892, 1988, 439, 11, 117, "Input",
  CellTags->{"addition", "Addition", "Multiplication"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[65368, 2004, 60, 1, 70, "Subsubsection"],
Cell[65431, 2007, 232, 7, 89, "Text"],
Cell[65666, 2016, 444, 13, 79, "Input",
  CellTags->{
  "Addition", "comm\[RawStar]", "comm+", "commutativity of addition", 
    "Multiplication"}],
Cell[66113, 2031, 464, 9, 139, "Input",
  CellTags->{
  "Addition", "assoc+", "comm\[RawStar]", "comm+", 
    "commutativity of addition", "left addition", "Multiplication"}],
Cell[66580, 2042, 432, 14, 49, "Input"],
Cell[67015, 2058, 578, 13, 153, "Text"],
Cell[67596, 2073, 396, 10, 121, "Text"],
Cell[67995, 2085, 432, 14, 49, "Input"],
Cell[68430, 2101, 132, 3, 57, "Text"],
Cell[68565, 2106, 76, 2, 59, "Input"],
Cell[68644, 2110, 575, 11, 185, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69256, 2126, 81, 1, 70, "Subsubsection"],
Cell[69340, 2129, 285, 5, 121, "Text"],
Cell[69628, 2136, 387, 8, 109, "Input",
  CellTags->{
  "Addition", "assoc+", "comm\[RawStar]", "comm+", "left addition", 
    "Multiplication"}],
Cell[70018, 2146, 1340, 27, 345, "Text"],
Cell[71361, 2175, 98, 1, 57, "Text"],
Cell[71462, 2178, 95, 1, 57, "Text"],
Cell[71560, 2181, 267, 6, 89, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[71876, 2193, 90, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[71991, 2198, 72, 1, 70, "Subsubsection"],
Cell[72066, 2201, 397, 11, 121, "Text"],
Cell[72466, 2214, 495, 10, 153, "Text"],
Cell[72964, 2226, 112, 3, 57, "Text"],
Cell[73079, 2231, 532, 8, 185, "Text"],
Cell[73614, 2241, 686, 10, 217, "Text"],
Cell[74303, 2253, 489, 10, 153, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74829, 2268, 120, 3, 70, "Subsubsection"],
Cell[74952, 2273, 71, 0, 57, "Text"],
Cell[75026, 2275, 735, 17, 245, "Input",
  CellTags->"Equational Properties of Addition"],
Cell[75764, 2294, 64, 0, 57, "Text"],
Cell[75831, 2296, 655, 17, 182, "Input",
  CellTags->{
  "Multiplication", "Some Equational Properties of Multiplication"}],
Cell[76489, 2315, 134, 3, 57, "Text"],
Cell[76626, 2320, 479, 13, 79, "Input",
  CellTags->{
  "Associativity of Multiplication", "Associativity of Multiplicatios", 
    "Multiplication"}],

Cell[CellGroupData[{
Cell[77130, 2337, 433, 10, 139, "Input"],
Cell[77566, 2349, 89, 1, 49, "Output"]
}, Open  ]],
Cell[77670, 2353, 592, 13, 153, "Text"],
Cell[78265, 2368, 365, 6, 121, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78667, 2379, 103, 2, 70, "Subsubsection"],
Cell[78773, 2383, 108, 3, 57, "Text"],
Cell[78884, 2388, 614, 15, 182, "Input",
  CellTags->"Equational Properties of Addition"],
Cell[79501, 2405, 439, 9, 153, "Text"],

Cell[CellGroupData[{
Cell[79965, 2418, 593, 12, 169, "Input",
  CellTags->"Equational Properties of Addition"],
Cell[80561, 2432, 89, 1, 49, "Output"]
}, Open  ]],
Cell[80665, 2436, 611, 13, 185, "Text"],
Cell[81279, 2451, 435, 9, 153, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81763, 2466, 99, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[81887, 2471, 72, 1, 70, "Subsubsection"],
Cell[81962, 2474, 528, 8, 185, "Text"],
Cell[82493, 2484, 1478, 27, 409, "Text"],
Cell[83974, 2513, 241, 6, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84252, 2524, 71, 1, 70, "Subsubsection"],
Cell[84326, 2527, 151, 5, 57, "Text"],
Cell[84480, 2534, 151, 3, 49, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[84668, 2542, 52, 1, 70, "Subsubsection"],
Cell[84723, 2545, 132, 3, 57, "Text"],
Cell[84858, 2550, 972, 19, 212, "Input",
  CellTags->"Test"],
Cell[85833, 2571, 89, 2, 57, "Text"],

Cell[CellGroupData[{
Cell[85947, 2577, 136, 3, 49, "Input"],
Cell[86086, 2582, 89, 1, 49, "Output"]
}, Open  ]],
Cell[86190, 2586, 594, 13, 153, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[86833, 2605, 172, 4, 83, "Subsection",
  CellTags->{"Equational Properties of Addition", "Test"}],

Cell[CellGroupData[{
Cell[87030, 2613, 72, 1, 70, "Subsubsection"],
Cell[87105, 2616, 580, 9, 185, "Text"],
Cell[87688, 2627, 264, 5, 121, "Text"],
Cell[87955, 2634, 226, 6, 89, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88218, 2645, 56, 1, 70, "Subsubsection"],
Cell[88277, 2648, 41, 0, 57, "Text"],
Cell[88321, 2650, 134, 3, 49, "Input",
  InitializationCell->True],
Cell[88458, 2655, 124, 3, 57, "Text"],
Cell[88585, 2660, 603, 15, 211, "Input",
  InitializationCell->True,
  CellTags->"PauleSchorn"],
Cell[89191, 2677, 413, 9, 289, "Input",
  InitializationCell->True,
  CellTags->"PauleSchorn"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89641, 2691, 82, 2, 70, "Subsubsection",
  CellTags->"Gauss"],
Cell[89726, 2695, 145, 3, 89, "Text"],
Cell[89874, 2700, 246, 8, 124, "Input",
  CellTags->"Gauss"],
Cell[90123, 2710, 949, 20, 249, "Text"],

Cell[CellGroupData[{
Cell[91097, 2734, 185, 3, 49, "Input"],
Cell[91285, 2739, 2206, 59, 135, "Print"],
Cell[93494, 2800, 2850, 74, 180, "Print"],
Cell[96347, 2876, 1998, 52, 196, "Print"]
}, Open  ]],
Cell[98360, 2931, 90, 2, 57, "Text"],

Cell[CellGroupData[{
Cell[98475, 2937, 1304, 35, 81, "Input"],
Cell[99782, 2974, 35, 1, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[99866, 2981, 65, 1, 70, "Subsubsection"],
Cell[99934, 2984, 414, 8, 153, "Text"],
Cell[100351, 2994, 39, 0, 57, "Text"],
Cell[100393, 2996, 378, 9, 135, "Input",
  CellTags->"SIAM series"],
Cell[100774, 3007, 47, 0, 57, "Text"],

Cell[CellGroupData[{
Cell[100846, 3011, 198, 4, 49, "Input"],
Cell[101047, 3017, 6225, 165, 140, "Print"],
Cell[107275, 3184, 7185, 194, 191, "Print"],
Cell[114463, 3380, 8971, 241, 234, "Print"]
}, Open  ]],
Cell[123449, 3624, 108, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[123582, 3631, 5846, 155, 112, "Input"],
Cell[129431, 3788, 35, 1, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[129527, 3796, 194, 9, 83, "Subsection"],

Cell[CellGroupData[{
Cell[129746, 3809, 72, 1, 70, "Subsubsection"],
Cell[129821, 3812, 211, 6, 89, "Text"],
Cell[130035, 3820, 205, 7, 57, "Text"],
Cell[130243, 3829, 345, 8, 89, "Text"],
Cell[130591, 3839, 903, 20, 217, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131531, 3864, 61, 1, 70, "Subsubsection"],
Cell[131595, 3867, 134, 3, 57, "Text"],
Cell[131732, 3872, 60, 2, 49, "Input"],
Cell[131795, 3876, 350, 6, 109, "Input"],
Cell[132148, 3884, 243, 7, 199, "Input"],
Cell[132394, 3893, 201, 5, 139, "Input"],

Cell[CellGroupData[{
Cell[132620, 3902, 229, 5, 139, "Input"],
Cell[132852, 3909, 195, 3, 67, "Message"]
}, Open  ]],
Cell[133062, 3915, 78, 2, 49, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133177, 3922, 145, 6, 70, "Subsubsection"],
Cell[133325, 3930, 307, 7, 121, "Text"],
Cell[133635, 3939, 680, 16, 274, "Input",
  CellTags->{"math", "Mathematica"}],
Cell[134318, 3957, 163, 4, 49, "Input",
  CellTags->"Mathematica"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134518, 3966, 61, 1, 70, "Subsubsection"],
Cell[134582, 3969, 511, 11, 153, "Text"],
Cell[135096, 3982, 2246, 44, 832, "Input",
  CellTags->"Mathematica Polynomials"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137379, 4031, 85, 1, 70, "Subsubsection"],
Cell[137467, 4034, 150, 3, 57, "Text"],
Cell[137620, 4039, 339, 9, 79, "Input",
  CellTags->{
  "\[DoubleStruckCapitalM]\[DoubleStruckCapitalP]", 
    "\[DoubleStruckCapitalP]"}],
Cell[137962, 4050, 155, 3, 57, "Text"],
Cell[138120, 4055, 398, 10, 117, "Input",
  CellTags->{"T", "\[DoubleStruckCapitalP]"}],
Cell[138521, 4067, 532, 10, 153, "Text"],
Cell[139056, 4079, 147, 4, 60, "Input"],
Cell[139206, 4085, 161, 5, 57, "Text"],

Cell[CellGroupData[{
Cell[139392, 4094, 183, 4, 63, "Input"],
Cell[139578, 4100, 393, 14, 34, "Message"],
Cell[139974, 4116, 407, 16, 34, "Message"],
Cell[140384, 4134, 54, 1, 68, "Output"]
}, Open  ]],
Cell[140453, 4138, 185, 4, 89, "Text"],
Cell[140641, 4144, 85, 2, 49, "Input"],

Cell[CellGroupData[{
Cell[140751, 4150, 183, 4, 67, "Input"],
Cell[140937, 4156, 48, 1, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141022, 4162, 206, 4, 64, "Input"],
Cell[141231, 4168, 39, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141307, 4174, 174, 3, 64, "Input"],
Cell[141484, 4179, 38, 1, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[141571, 4186, 61, 1, 70, "Subsubsection"],
Cell[141635, 4189, 206, 4, 89, "Text"],
Cell[141844, 4195, 1499, 32, 366, "Input",
  CellTags->"Reduction Domain"],
Cell[143346, 4229, 381, 6, 121, "Text"],
Cell[143730, 4237, 118, 3, 57, "Text"],
Cell[143851, 4242, 333, 10, 79, "Input",
  CellTags->"RDMP"],
Cell[144187, 4254, 111, 3, 57, "Text"],
Cell[144301, 4259, 481, 12, 148, "Input",
  CellTags->{"RD", "RDMP", "T", "\[DoubleStruckCapitalP]"}],

Cell[CellGroupData[{
Cell[144807, 4275, 239, 5, 64, "Input"],
Cell[145049, 4282, 72, 1, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145158, 4288, 232, 5, 64, "Input"],
Cell[145393, 4295, 84, 1, 51, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[145526, 4302, 137, 3, 74, "Subsubsection",
  CellTags->"computing-session"],
Cell[145666, 4307, 358, 10, 121, "Text"],
Cell[146027, 4319, 75, 2, 49, "Input"],
Cell[146105, 4323, 72, 0, 57, "Text"],

Cell[CellGroupData[{
Cell[146202, 4327, 117, 3, 70, "Input",
  CellTags->"sets"],
Cell[146322, 4332, 43, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146402, 4338, 121, 3, 70, "Input",
  CellTags->"sets"],
Cell[146526, 4343, 43, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146606, 4349, 108, 2, 70, "Input"],
Cell[146717, 4353, 62, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146816, 4359, 86, 2, 49, "Input"],
Cell[146905, 4363, 38, 1, 49, "Output"]
}, Open  ]],
Cell[146958, 4367, 99, 2, 57, "Text"],

Cell[CellGroupData[{
Cell[147082, 4373, 68, 2, 49, "Input"],
Cell[147153, 4377, 43, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147233, 4383, 68, 2, 49, "Input"],
Cell[147304, 4387, 43, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147384, 4393, 80, 2, 49, "Input"],
Cell[147467, 4397, 39, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147543, 4403, 78, 2, 49, "Input"],
Cell[147624, 4407, 38, 1, 49, "Output"]
}, Open  ]],
Cell[147677, 4411, 75, 0, 57, "Text"],
Cell[147755, 4413, 371, 8, 145, "Input"],
Cell[148129, 4423, 289, 7, 89, "Text"],

Cell[CellGroupData[{
Cell[148443, 4434, 85, 2, 49, "Input"],
Cell[148531, 4438, 40, 1, 49, "Output"]
}, Open  ]],
Cell[148586, 4442, 133, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[148744, 4449, 69, 2, 49, "Input"],
Cell[148816, 4453, 50, 1, 49, "Output"]
}, Open  ]],
Cell[148881, 4457, 121, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[149027, 4464, 93, 2, 49, "Input"],
Cell[149123, 4468, 38, 1, 49, "Output"]
}, Open  ]],
Cell[149176, 4472, 55, 0, 57, "Text"],

Cell[CellGroupData[{
Cell[149256, 4476, 76, 2, 49, "Input"],
Cell[149335, 4480, 38, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149410, 4486, 73, 2, 49, "Input"],
Cell[149486, 4490, 38, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149561, 4496, 78, 2, 49, "Input"],
Cell[149642, 4500, 39, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149718, 4506, 124, 3, 49, "Input"],
Cell[149845, 4511, 38, 1, 49, "Output"]
}, Open  ]],
Cell[149898, 4515, 131, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[150054, 4522, 149, 3, 49, "Input"],
Cell[150206, 4527, 35, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150278, 4533, 103, 2, 49, "Input"],
Cell[150384, 4537, 35, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150456, 4543, 100, 2, 49, "Input"],
Cell[150559, 4547, 35, 1, 49, "Output"]
}, Open  ]],
Cell[150609, 4551, 110, 3, 57, "Text"],

Cell[CellGroupData[{
Cell[150744, 4558, 63, 2, 49, "Input"],
Cell[150810, 4562, 35, 1, 49, "Output"]
}, Open  ]],
Cell[150860, 4566, 98, 2, 57, "Text"],
Cell[150961, 4570, 488, 10, 181, "Input"],
Cell[151452, 4582, 287, 9, 89, "Text"],

Cell[CellGroupData[{
Cell[151764, 4595, 74, 2, 49, "Input"],
Cell[151841, 4599, 38, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151916, 4605, 75, 2, 49, "Input"],
Cell[151994, 4609, 43, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152074, 4615, 92, 2, 79, "Input"],
Cell[152169, 4619, 56, 1, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152262, 4625, 84, 2, 49, "Input"],
Cell[152349, 4629, 182, 3, 79, "Output"]
}, Open  ]],
Cell[152546, 4635, 140, 5, 57, "Text"],
Cell[152689, 4642, 78, 2, 49, "Input"],
Cell[152770, 4646, 96, 2, 57, "Text"],

Cell[CellGroupData[{
Cell[152891, 4652, 84, 2, 49, "Input"],
Cell[152978, 4656, 65, 1, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[153104, 4664, 47, 3, 124, "Subsubtitle"],

Cell[CellGroupData[{
Cell[153176, 4671, 45, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[153246, 4676, 63, 1, 70, "Subsubsection"],
Cell[153312, 4679, 22, 0, 57, "Text"],
Cell[153337, 4681, 2306, 67, 48, "Conclusion",
  CellTags->"divdiff"],
Cell[155646, 4750, 38, 0, 57, "Text"],
Cell[155687, 4752, 1727, 51, 59, "Assumption",
  CellTags->"div:"],
Cell[157417, 4805, 3167, 89, 48, "Assumption",
  CellTags->"distr"],
Cell[160587, 4896, 25, 0, 57, "Text"],
Cell[160615, 4898, 763, 26, 36, "Assumption",
  CellTags->"1"],
Cell[161381, 4926, 24, 0, 57, "Text"],
Cell[161408, 4928, 932, 31, 36, "Conclusion",
  CellTags->"2"],
Cell[162343, 4961, 210, 10, 57, "Text"],
Cell[162556, 4973, 682, 27, 57, "Text"],
Cell[163241, 5002, 329, 18, 57, "Text"],
Cell[163573, 5022, 864, 29, 49, "Assumption",
  CellTags->"3"],
Cell[164440, 5053, 209, 10, 57, "Text"],
Cell[164652, 5065, 573, 21, 36, "Assumption",
  CellTags->"4"],
Cell[165228, 5088, 329, 18, 57, "Text"],
Cell[165560, 5108, 864, 29, 49, "Assumption",
  CellTags->"5"],
Cell[166427, 5139, 209, 10, 57, "Text"],
Cell[166639, 5151, 573, 21, 36, "Assumption",
  CellTags->"6"],
Cell[167215, 5174, 501, 26, 57, "Text"],
Cell[167719, 5202, 950, 32, 36, "Assumption",
  CellTags->"7"],
Cell[168672, 5236, 338, 18, 57, "Text"],
Cell[169013, 5256, 1043, 34, 49, "Conclusion",
  CellTags->"8"],
Cell[170059, 5292, 345, 18, 57, "Text"],
Cell[170407, 5312, 523, 22, 57, "Text"],
Cell[170933, 5336, 349, 18, 57, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[171331, 5360, 51, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[171407, 5365, 56, 1, 70, "Subsubsection"],
Cell[171466, 5368, 22, 0, 57, "Text"],
Cell[171491, 5370, 4369, 121, 49, "Conclusion",
  CellTags->"lim+"],
Cell[175863, 5493, 38, 0, 57, "Text"],
Cell[175904, 5495, 3175, 86, 53, "Assumption",
  CellTags->"l4:"],
Cell[179082, 5583, 1915, 58, 49, "Assumption",
  CellTags->"+:"],
Cell[181000, 5643, 3711, 100, 49, "Assumption",
  CellTags->"| + |"],
Cell[184714, 5745, 2003, 58, 48, "Assumption",
  CellTags->"\[GreaterEqual]max "],
Cell[186720, 5805, 25, 0, 57, "Text"],
Cell[186748, 5807, 1425, 44, 36, "Assumption",
  CellTags->"1"],
Cell[188176, 5853, 24, 0, 57, "Text"],
Cell[188203, 5855, 1480, 46, 36, "Conclusion",
  CellTags->"2"],
Cell[189686, 5903, 327, 18, 57, "Text"],
Cell[190016, 5923, 1563, 45, 45, "Assumption",
  CellTags->"3"],
Cell[191582, 5970, 327, 18, 57, "Text"],
Cell[191912, 5990, 1565, 45, 45, "Assumption",
  CellTags->"4"],
Cell[193480, 6037, 332, 18, 57, "Text"],
Cell[193815, 6057, 2571, 69, 45, "Conclusion",
  CellTags->"5"],
Cell[196389, 6128, 25, 0, 57, "Text"],
Cell[196417, 6130, 641, 22, 36, "Assumption",
  CellTags->"6"],
Cell[197061, 6154, 24, 0, 57, "Text"],
Cell[197088, 6156, 1499, 45, 36, "Conclusion",
  CellTags->"7"],
Cell[198590, 6203, 447, 21, 57, "Text"],
Cell[199040, 6226, 765, 26, 36, "Assumption",
  CellTags->"8"],
Cell[199808, 6254, 323, 18, 57, "Text"],
Cell[200134, 6274, 850, 27, 36, "Assumption",
  CellTags->"9"],
Cell[200987, 6303, 323, 18, 57, "Text"],
Cell[201313, 6323, 854, 27, 36, "Assumption",
  CellTags->"10"],
Cell[202170, 6352, 330, 18, 57, "Text"],
Cell[202503, 6372, 1642, 47, 57, "Text"],
Cell[204148, 6421, 201, 10, 57, "Text"],
Cell[204352, 6433, 1657, 48, 36, "Conclusion",
  CellTags->"11"],
Cell[206012, 6483, 212, 10, 57, "Text"],
Cell[206227, 6495, 948, 33, 57, "Text"],
Cell[207178, 6530, 347, 18, 57, "Text"],
Cell[207528, 6550, 950, 33, 57, "Text"],
Cell[208481, 6585, 349, 18, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208867, 6608, 56, 1, 70, "Subsubsection"],
Cell[208926, 6611, 22, 0, 57, "Text"],
Cell[208951, 6613, 3367, 94, 49, "Conclusion",
  CellTags->"l3+"],
Cell[212321, 6709, 38, 0, 57, "Text"],
Cell[212362, 6711, 4369, 121, 49, "Assumption",
  CellTags->"lim+"],
Cell[216734, 6834, 2208, 63, 53, "Assumption",
  CellTags->"l3:"],
Cell[218945, 6899, 25, 0, 57, "Text"],
Cell[218973, 6901, 1145, 36, 36, "Assumption",
  CellTags->"1"],
Cell[220121, 6939, 24, 0, 57, "Text"],
Cell[220148, 6941, 1123, 36, 36, "Conclusion",
  CellTags->"2"],
Cell[221274, 6979, 327, 18, 57, "Text"],
Cell[221604, 6999, 981, 32, 45, "Assumption",
  CellTags->"3"],
Cell[222588, 7033, 209, 10, 57, "Text"],
Cell[222800, 7045, 739, 25, 36, "Assumption",
  CellTags->"4"],
Cell[223542, 7072, 327, 18, 57, "Text"],
Cell[223872, 7092, 983, 32, 45, "Assumption",
  CellTags->"5"],
Cell[224858, 7126, 209, 10, 57, "Text"],
Cell[225070, 7138, 741, 25, 36, "Assumption",
  CellTags->"6"],
Cell[225814, 7165, 499, 26, 57, "Text"],
Cell[226316, 7193, 1480, 46, 36, "Assumption",
  CellTags->"7"],
Cell[227799, 7241, 332, 18, 57, "Text"],
Cell[228134, 7261, 1527, 47, 45, "Conclusion",
  CellTags->"8"],
Cell[229664, 7310, 345, 18, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230046, 7333, 56, 1, 70, "Subsubsection"],
Cell[230105, 7336, 22, 0, 57, "Text"],
Cell[230130, 7338, 2386, 69, 49, "Conclusion",
  CellTags->"l2+"],
Cell[232519, 7409, 38, 0, 57, "Text"],
Cell[232560, 7411, 2101, 59, 53, "Assumption",
  CellTags->"l2:"],
Cell[234664, 7472, 3116, 87, 49, "Assumption",
  CellTags->"l3+"],
Cell[237783, 7561, 821, 28, 45, "Assumption",
  CellTags->"/2>"],
Cell[238607, 7591, 25, 0, 57, "Text"],
Cell[238635, 7593, 849, 28, 36, "Assumption",
  CellTags->"1"],
Cell[239487, 7623, 24, 0, 57, "Text"],
Cell[239514, 7625, 806, 27, 36, "Conclusion",
  CellTags->"2"],
Cell[240323, 7654, 327, 18, 57, "Text"],
Cell[240653, 7674, 1152, 35, 45, "Assumption",
  CellTags->"3"],
Cell[241808, 7711, 327, 18, 57, "Text"],
Cell[242138, 7731, 1152, 35, 45, "Assumption",
  CellTags->"4"],
Cell[243293, 7768, 332, 18, 57, "Text"],
Cell[243628, 7788, 1550, 45, 45, "Conclusion",
  CellTags->"5"],
Cell[245181, 7835, 25, 0, 57, "Text"],
Cell[245209, 7837, 309, 12, 36, "Assumption",
  CellTags->"6"],
Cell[245521, 7851, 24, 0, 57, "Text"],
Cell[245548, 7853, 947, 31, 36, "Conclusion",
  CellTags->"7"],
Cell[246498, 7886, 319, 18, 57, "Text"],
Cell[246820, 7906, 609, 21, 36, "Assumption",
  CellTags->"8"],
Cell[247432, 7929, 319, 18, 57, "Text"],
Cell[247754, 7949, 609, 21, 36, "Assumption",
  CellTags->"9"],
Cell[248366, 7972, 323, 18, 57, "Text"],
Cell[248692, 7992, 346, 13, 41, "Assumption",
  CellTags->"10"],
Cell[249041, 8007, 321, 18, 57, "Text"],
Cell[249365, 8027, 648, 22, 41, "Assumption",
  CellTags->"11"],
Cell[250016, 8051, 321, 18, 57, "Text"],
Cell[250340, 8071, 648, 22, 41, "Assumption",
  CellTags->"12"],
Cell[250991, 8095, 332, 18, 57, "Text"],
Cell[251326, 8115, 1227, 38, 41, "Conclusion",
  CellTags->"13"],
Cell[252556, 8155, 212, 10, 57, "Text"],
Cell[252771, 8167, 744, 28, 59, "Text"],
Cell[253518, 8197, 349, 18, 57, "Text"],
Cell[253870, 8217, 744, 28, 59, "Text"],
Cell[254617, 8247, 349, 18, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[255003, 8270, 66, 1, 70, "Subsubsection"],
Cell[255072, 8273, 22, 0, 57, "Text"],
Cell[255097, 8275, 5530, 142, 81, "Conclusion",
  CellTags->"cont[ \[RawStar] ]"],
Cell[260630, 8419, 38, 0, 57, "Text"],
Cell[260671, 8421, 3761, 98, 59, "Assumption",
  CellTags->"c4:"],
Cell[264435, 8521, 1917, 58, 49, "Assumption",
  CellTags->"f\[RawStar]g"],
Cell[266355, 8581, 4448, 116, 48, "Assumption",
  CellTags->"| \[RawStar] |"],
Cell[270806, 8699, 1931, 58, 48, "Assumption",
  CellTags->"min<"],
Cell[272740, 8759, 25, 0, 57, "Text"],
Cell[272768, 8761, 1457, 44, 37, "Assumption",
  CellTags->"1"],
Cell[274228, 8807, 24, 0, 57, "Text"],
Cell[274255, 8809, 2578, 71, 37, "Conclusion",
  CellTags->"2"],
Cell[276836, 8882, 327, 18, 57, "Text"],
Cell[277166, 8902, 2072, 57, 49, "Assumption",
  CellTags->"3"],
Cell[279241, 8961, 327, 18, 57, "Text"],
Cell[279571, 8981, 2072, 57, 49, "Assumption",
  CellTags->"4"],
Cell[281646, 9040, 332, 18, 57, "Text"],
Cell[281981, 9060, 4450, 110, 49, "Conclusion",
  CellTags->"5"],
Cell[286434, 9172, 25, 0, 57, "Text"],
Cell[286462, 9174, 888, 28, 36, "Assumption",
  CellTags->"6"],
Cell[287353, 9204, 24, 0, 57, "Text"],
Cell[287380, 9206, 2861, 78, 37, "Conclusion",
  CellTags->"7"],
Cell[290244, 9286, 325, 18, 57, "Text"],
Cell[290572, 9306, 1267, 38, 36, "Assumption",
  CellTags->"8"],
Cell[291842, 9346, 323, 18, 57, "Text"],
Cell[292168, 9366, 1039, 32, 37, "Assumption",
  CellTags->"9"],
Cell[293210, 9400, 323, 18, 57, "Text"],
Cell[293536, 9420, 1041, 32, 37, "Assumption",
  CellTags->"10"],
Cell[294580, 9454, 332, 18, 57, "Text"],
Cell[294915, 9474, 3083, 84, 57, "Text"],
Cell[298001, 9560, 201, 10, 57, "Text"],
Cell[298205, 9572, 2075, 60, 37, "Conclusion",
  CellTags->"11"],
Cell[300283, 9634, 212, 10, 57, "Text"],
Cell[300498, 9646, 1137, 38, 57, "Text"],
Cell[301638, 9686, 347, 18, 57, "Text"],
Cell[301988, 9706, 1137, 38, 57, "Text"],
Cell[303128, 9746, 349, 18, 57, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[303526, 9770, 69, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[303620, 9775, 65, 1, 70, "Subsubsection"],
Cell[303688, 9778, 22, 0, 57, "Text"],
Cell[303713, 9780, 2386, 69, 49, "Conclusion",
  CellTags->"l2+"],
Cell[306102, 9851, 38, 0, 57, "Text"],
Cell[306143, 9853, 3451, 90, 82, "Assumption",
  CellTags->"l"],
Cell[309597, 9945, 3814, 101, 49, "Assumption",
  CellTags->"dist+"],
Cell[313414, 10048, 1917, 58, 49, "Assumption",
  CellTags->"f+g"],
Cell[315334, 10108, 2001, 58, 48, "Assumption",
  CellTags->"max\[GreaterEqual]"],
Cell[317338, 10168, 25, 0, 57, "Text"],
Cell[317366, 10170, 849, 28, 36, "Assumption",
  CellTags->"1"],
Cell[318218, 10200, 24, 0, 57, "Text"],
Cell[318245, 10202, 806, 27, 36, "Conclusion",
  CellTags->"2"],
Cell[319054, 10231, 322, 18, 57, "Text"],
Cell[319379, 10251, 2303, 65, 61, "Assumption",
  CellTags->"3"],
Cell[321685, 10318, 221, 10, 57, "Text"],
Cell[321909, 10330, 2205, 63, 66, "Assumption",
  CellTags->"4"],
Cell[324117, 10395, 323, 18, 57, "Text"],
Cell[324443, 10415, 2303, 65, 61, "Assumption",
  CellTags->"5"],
Cell[326749, 10482, 221, 10, 57, "Text"],
Cell[326973, 10494, 2205, 63, 66, "Assumption",
  CellTags->"6"],
Cell[329181, 10559, 328, 18, 57, "Text"],
Cell[329512, 10579, 2890, 78, 61, "Conclusion",
  CellTags->"7"],
Cell[332405, 10659, 25, 0, 57, "Text"],
Cell[332433, 10661, 309, 12, 36, "Assumption",
  CellTags->"8"],
Cell[332745, 10675, 48, 0, 57, "Text"],
Cell[332796, 10677, 2079, 59, 63, "Conclusion",
  CellTags->"9"],
Cell[334878, 10738, 332, 18, 57, "Text"],
Cell[335213, 10758, 2271, 63, 63, "Conclusion",
  CellTags->"10"],
Cell[337487, 10823, 381, 18, 57, "Text"],
Cell[337871, 10843, 2863, 72, 67, "Conclusion",
  CellTags->"11"],
Cell[340737, 10917, 413, 22, 57, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[341199, 10945, 69, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[341293, 10950, 80, 1, 70, "Subsubsection"],
Cell[341376, 10953, 22, 0, 57, "Text"],
Cell[341401, 10955, 2636, 69, 57, "Conclusion",
  CellTags->"symm\[Implies]\[LeftFloor]\[RightFloor]"],
Cell[344040, 11026, 38, 0, 57, "Text"],
Cell[344081, 11028, 2313, 63, 57, "Assumption",
  CellTags->"symm:"],
Cell[346397, 11093, 2056, 60, 57, "Assumption",
  CellTags->"\[LeftFloor] \[RightFloor]:"],
Cell[348456, 11155, 25, 0, 57, "Text"],
Cell[348484, 11157, 331, 12, 36, "Assumption",
  CellTags->"1"],
Cell[348818, 11171, 24, 0, 57, "Text"],
Cell[348845, 11173, 1809, 52, 48, "Conclusion",
  CellTags->"2"],
Cell[350657, 11227, 25, 0, 57, "Text"],
Cell[350685, 11229, 693, 23, 39, "Assumption",
  CellTags->"3"],
Cell[351381, 11254, 24, 0, 57, "Text"],
Cell[351408, 11256, 693, 23, 39, "Conclusion",
  CellTags->"4"],
Cell[352104, 11281, 671, 27, 57, "Text"],
Cell[352778, 11310, 1225, 38, 52, "Assumption",
  CellTags->"5"],
Cell[354006, 11350, 177, 10, 57, "Text"],
Cell[354186, 11362, 587, 21, 36, "Assumption",
  CellTags->"6"],
Cell[354776, 11385, 327, 18, 57, "Text"],
Cell[355106, 11405, 1573, 48, 48, "Assumption",
  CellTags->"7"],
Cell[356682, 11455, 319, 18, 57, "Text"],
Cell[357004, 11475, 587, 21, 36, "Assumption",
  CellTags->"8"],
Cell[357594, 11498, 680, 27, 57, "Text"],
Cell[358277, 11527, 1156, 35, 67, "Text"],
Cell[359436, 11564, 193, 10, 57, "Text"],
Cell[359632, 11576, 1225, 38, 52, "Conclusion",
  CellTags->"9"],
Cell[360860, 11616, 249, 11, 57, "Text"],
Cell[361112, 11629, 589, 21, 36, "Conclusion",
  CellTags->"10"],
Cell[361704, 11652, 343, 18, 57, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[362096, 11676, 67, 1, 83, "Subsection"],

Cell[CellGroupData[{
Cell[362188, 11681, 58, 1, 70, "Subsubsection"],
Cell[362249, 11684, 22, 0, 57, "Text"],
Cell[362274, 11686, 1166, 38, 48, "Conclusion",
  CellTags->" + = "],
Cell[363443, 11726, 38, 0, 57, "Text"],
Cell[363484, 11728, 727, 25, 45, "Assumption",
  CellTags->" +0:"],
Cell[364214, 11755, 1320, 42, 48, "Assumption",
  CellTags->" + .:"],
Cell[365537, 11799, 129, 3, 57, "Text"],
Cell[365669, 11804, 43, 0, 57, "Text"],
Cell[365715, 11806, 258, 11, 57, "Text"],
Cell[365976, 11819, 43, 0, 57, "Text"],
Cell[366022, 11821, 362, 18, 57, "Text"],
Cell[366387, 11841, 32, 0, 57, "Text"],
Cell[366422, 11843, 762, 26, 45, "Conclusion",
  CellTags->"1"],
Cell[367187, 11871, 129, 3, 57, "Text"],
Cell[367319, 11876, 43, 0, 57, "Text"],
Cell[367365, 11878, 210, 10, 57, "Text"],
Cell[367578, 11890, 481, 17, 36, "Conclusion",
  CellTags->"4"],
Cell[368062, 11909, 32, 0, 57, "Text"],
Cell[368097, 11911, 47, 0, 57, "Text"],
Cell[368147, 11913, 244, 9, 57, "Text"],
Cell[368394, 11924, 47, 0, 57, "Text"],
Cell[368444, 11926, 395, 18, 57, "Text"],
Cell[368842, 11946, 209, 8, 57, "Text"],
Cell[369054, 11956, 49, 0, 57, "Text"],
Cell[369106, 11958, 721, 25, 45, "Conclusion",
  CellTags->"5"],
Cell[369830, 11985, 347, 18, 57, "Text"],
Cell[370180, 12005, 32, 0, 57, "Text"],
Cell[370215, 12007, 176, 8, 36, "Conclusion",
  CellTags->"6"],
Cell[370394, 12017, 200, 10, 57, "Text"],
Cell[370597, 12029, 47, 0, 57, "Text"],
Cell[370647, 12031, 267, 14, 57, "Text"],
Cell[370917, 12047, 112, 5, 57, "Text"],
Cell[371032, 12054, 47, 0, 57, "Text"],
Cell[371082, 12056, 112, 5, 57, "Text"],
Cell[371197, 12063, 31, 0, 57, "Text"],
Cell[371231, 12065, 75, 3, 57, "Text"],
Cell[371309, 12070, 444, 16, 36, "Assumption",
  CellTags->"7"],
Cell[371756, 12088, 75, 3, 57, "Text"],
Cell[371834, 12093, 529, 19, 36, "Conclusion",
  CellTags->"8"],
Cell[372366, 12114, 200, 10, 57, "Text"],
Cell[372569, 12126, 47, 0, 57, "Text"],
Cell[372619, 12128, 435, 19, 57, "Text"],
Cell[373057, 12149, 466, 20, 57, "Text"],
Cell[373526, 12171, 245, 9, 57, "Text"],
Cell[373774, 12182, 47, 0, 57, "Text"],
Cell[373824, 12184, 245, 9, 57, "Text"],
Cell[374072, 12195, 44, 0, 57, "Text"],
Cell[374119, 12197, 206, 10, 77, "Text"],
Cell[374328, 12209, 31, 0, 57, "Text"],
Cell[374362, 12211, 75, 3, 57, "Text"],
Cell[374440, 12216, 1031, 33, 45, "Assumption",
  CellTags->"2"],
Cell[375474, 12251, 75, 3, 57, "Text"],
Cell[375552, 12256, 1126, 36, 45, "Conclusion",
  CellTags->"3"],
Cell[376681, 12294, 129, 3, 57, "Text"],
Cell[376813, 12299, 43, 0, 57, "Text"],
Cell[376859, 12301, 210, 10, 57, "Text"],
Cell[377072, 12313, 805, 27, 36, "Conclusion",
  CellTags->"9"],
Cell[377880, 12342, 32, 0, 57, "Text"],
Cell[377915, 12344, 47, 0, 57, "Text"],
Cell[377965, 12346, 396, 14, 57, "Text"],
Cell[378364, 12362, 47, 0, 57, "Text"],
Cell[378414, 12364, 549, 23, 57, "Text"],
Cell[378966, 12389, 451, 15, 57, "Text"],
Cell[379420, 12406, 49, 0, 57, "Text"],
Cell[379472, 12408, 1194, 38, 45, "Conclusion",
  CellTags->"10"],
Cell[380669, 12448, 356, 18, 57, "Text"],
Cell[381028, 12468, 32, 0, 57, "Text"],
Cell[381063, 12470, 611, 21, 36, "Conclusion",
  CellTags->"11"],
Cell[381677, 12493, 179, 10, 57, "Text"],
Cell[381859, 12505, 47, 0, 57, "Text"],
Cell[381909, 12507, 433, 19, 57, "Text"],
Cell[382345, 12528, 245, 9, 57, "Text"],
Cell[382593, 12539, 47, 0, 57, "Text"],
Cell[382643, 12541, 321, 11, 57, "Text"],
Cell[382967, 12554, 49, 0, 57, "Text"],
Cell[383019, 12556, 572, 20, 36, "Conclusion",
  CellTags->"14"],
Cell[383594, 12578, 232, 11, 57, "Text"],
Cell[383829, 12591, 31, 0, 57, "Text"],
Cell[383863, 12593, 75, 3, 57, "Text"],
Cell[383941, 12598, 864, 28, 36, "Assumption",
  CellTags->"12"],
Cell[384808, 12628, 75, 3, 57, "Text"],
Cell[384886, 12633, 955, 31, 36, "Conclusion",
  CellTags->"13"],
Cell[385844, 12666, 208, 10, 77, "Text"],
Cell[386055, 12678, 43, 0, 57, "Text"],
Cell[386101, 12680, 354, 18, 57, "Text"],
Cell[386458, 12700, 32, 0, 57, "Text"],
Cell[386493, 12702, 570, 20, 36, "Conclusion",
  CellTags->"15"],
Cell[387066, 12724, 179, 10, 57, "Text"],
Cell[387248, 12736, 47, 0, 57, "Text"],
Cell[387298, 12738, 433, 19, 57, "Text"],
Cell[387734, 12759, 245, 9, 57, "Text"],
Cell[387982, 12770, 47, 0, 57, "Text"],
Cell[388032, 12772, 435, 19, 57, "Text"],
Cell[388470, 12793, 321, 11, 57, "Text"],
Cell[388794, 12806, 49, 0, 57, "Text"],
Cell[388846, 12808, 572, 20, 36, "Conclusion",
  CellTags->"18"],
Cell[389421, 12830, 232, 11, 57, "Text"],
Cell[389656, 12843, 31, 0, 57, "Text"],
Cell[389690, 12845, 75, 3, 57, "Text"],
Cell[389768, 12850, 807, 27, 36, "Assumption",
  CellTags->"16"],
Cell[390578, 12879, 75, 3, 57, "Text"],
Cell[390656, 12884, 894, 30, 36, "Conclusion",
  CellTags->"17"],
Cell[391553, 12916, 208, 10, 77, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[391810, 12932, 69, 1, 103, "Subsection"],

Cell[CellGroupData[{
Cell[391904, 12937, 103, 2, 90, "Subsubsection"],
Cell[392010, 12941, 22, 0, 57, "Text"],
Cell[392035, 12943, 1166, 38, 48, "Conclusion",
  CellTags->" + = "],
Cell[393204, 12983, 38, 0, 57, "Text"],
Cell[393245, 12985, 727, 25, 45, "Assumption",
  CellTags->" +0:"],
Cell[393975, 13012, 1320, 42, 48, "Assumption",
  CellTags->" + .:"],
Cell[395298, 13056, 129, 3, 57, "Text"],
Cell[395430, 13061, 43, 0, 57, "Text"],
Cell[395476, 13063, 258, 11, 57, "Text"],
Cell[395737, 13076, 43, 0, 57, "Text"],
Cell[395783, 13078, 362, 18, 57, "Text"],
Cell[396148, 13098, 32, 0, 57, "Text"],
Cell[396183, 13100, 762, 26, 45, "Conclusion",
  CellTags->"1"],
Cell[396948, 13128, 129, 3, 57, "Text"],
Cell[397080, 13133, 43, 0, 57, "Text"],
Cell[397126, 13135, 210, 10, 57, "Text"],
Cell[397339, 13147, 481, 17, 36, "Conclusion",
  CellTags->"4"],
Cell[397823, 13166, 32, 0, 57, "Text"],
Cell[397858, 13168, 47, 0, 57, "Text"],
Cell[397908, 13170, 244, 9, 57, "Text"],
Cell[398155, 13181, 47, 0, 57, "Text"],
Cell[398205, 13183, 395, 18, 57, "Text"],
Cell[398603, 13203, 209, 8, 57, "Text"],
Cell[398815, 13213, 49, 0, 57, "Text"],
Cell[398867, 13215, 721, 25, 45, "Conclusion",
  CellTags->"5"],
Cell[399591, 13242, 347, 18, 57, "Text"],
Cell[399941, 13262, 32, 0, 57, "Text"],
Cell[399976, 13264, 176, 8, 36, "Conclusion",
  CellTags->"6"],
Cell[400155, 13274, 200, 10, 57, "Text"],
Cell[400358, 13286, 47, 0, 57, "Text"],
Cell[400408, 13288, 267, 14, 57, "Text"],
Cell[400678, 13304, 112, 5, 57, "Text"],
Cell[400793, 13311, 47, 0, 57, "Text"],
Cell[400843, 13313, 112, 5, 57, "Text"],
Cell[400958, 13320, 31, 0, 57, "Text"],
Cell[400992, 13322, 75, 3, 57, "Text"],
Cell[401070, 13327, 444, 16, 36, "Assumption",
  CellTags->"7"],
Cell[401517, 13345, 75, 3, 57, "Text"],
Cell[401595, 13350, 529, 19, 36, "Conclusion",
  CellTags->"8"],
Cell[402127, 13371, 200, 10, 57, "Text"],
Cell[402330, 13383, 47, 0, 57, "Text"],
Cell[402380, 13385, 435, 19, 57, "Text"],
Cell[402818, 13406, 466, 20, 57, "Text"],
Cell[403287, 13428, 245, 9, 57, "Text"],
Cell[403535, 13439, 47, 0, 57, "Text"],
Cell[403585, 13441, 245, 9, 57, "Text"],
Cell[403833, 13452, 44, 0, 57, "Text"],
Cell[403880, 13454, 206, 10, 57, "Text"],
Cell[404089, 13466, 31, 0, 57, "Text"],
Cell[404123, 13468, 75, 3, 57, "Text"],
Cell[404201, 13473, 1031, 33, 45, "Assumption",
  CellTags->"2"],
Cell[405235, 13508, 75, 3, 57, "Text"],
Cell[405313, 13513, 1126, 36, 45, "Conclusion",
  CellTags->"3"],
Cell[406442, 13551, 129, 3, 57, "Text"],
Cell[406574, 13556, 43, 0, 57, "Text"],
Cell[406620, 13558, 210, 10, 57, "Text"],
Cell[406833, 13570, 805, 27, 36, "Conclusion",
  CellTags->"9"],
Cell[407641, 13599, 32, 0, 57, "Text"],
Cell[407676, 13601, 47, 0, 57, "Text"],
Cell[407726, 13603, 396, 14, 57, "Text"],
Cell[408125, 13619, 47, 0, 57, "Text"],
Cell[408175, 13621, 549, 23, 57, "Text"],
Cell[408727, 13646, 451, 15, 57, "Text"],
Cell[409181, 13663, 49, 0, 57, "Text"],
Cell[409233, 13665, 1194, 38, 45, "Conclusion",
  CellTags->"10"],
Cell[410430, 13705, 356, 18, 57, "Text"],
Cell[410789, 13725, 32, 0, 57, "Text"],
Cell[410824, 13727, 611, 21, 36, "Conclusion",
  CellTags->"11"],
Cell[411438, 13750, 179, 10, 57, "Text"],
Cell[411620, 13762, 47, 0, 57, "Text"],
Cell[411670, 13764, 433, 19, 57, "Text"],
Cell[412106, 13785, 245, 9, 57, "Text"],
Cell[412354, 13796, 47, 0, 57, "Text"],
Cell[412404, 13798, 321, 11, 57, "Text"],
Cell[412728, 13811, 49, 0, 57, "Text"],
Cell[412780, 13813, 572, 20, 36, "Conclusion",
  CellTags->"14"],
Cell[413355, 13835, 232, 11, 57, "Text"],
Cell[413590, 13848, 31, 0, 57, "Text"],
Cell[413624, 13850, 75, 3, 57, "Text"],
Cell[413702, 13855, 864, 28, 36, "Assumption",
  CellTags->"12"],
Cell[414569, 13885, 75, 3, 57, "Text"],
Cell[414647, 13890, 955, 31, 36, "Conclusion",
  CellTags->"13"],
Cell[415605, 13923, 208, 10, 77, "Text"],
Cell[415816, 13935, 43, 0, 57, "Text"],
Cell[415862, 13937, 354, 18, 57, "Text"],
Cell[416219, 13957, 32, 0, 57, "Text"],
Cell[416254, 13959, 570, 20, 36, "Conclusion",
  CellTags->"15"],
Cell[416827, 13981, 179, 10, 57, "Text"],
Cell[417009, 13993, 47, 0, 57, "Text"],
Cell[417059, 13995, 433, 19, 57, "Text"],
Cell[417495, 14016, 245, 9, 57, "Text"],
Cell[417743, 14027, 47, 0, 57, "Text"],
Cell[417793, 14029, 435, 19, 57, "Text"],
Cell[418231, 14050, 321, 11, 57, "Text"],
Cell[418555, 14063, 49, 0, 57, "Text"],
Cell[418607, 14065, 572, 20, 36, "Conclusion",
  CellTags->"18"],
Cell[419182, 14087, 232, 11, 57, "Text"],
Cell[419417, 14100, 31, 0, 57, "Text"],
Cell[419451, 14102, 75, 3, 57, "Text"],
Cell[419529, 14107, 807, 27, 36, "Assumption",
  CellTags->"16"],
Cell[420339, 14136, 75, 3, 57, "Text"],
Cell[420417, 14141, 894, 30, 36, "Conclusion",
  CellTags->"17"],
Cell[421314, 14173, 208, 10, 77, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[421559, 14188, 95, 1, 90, "Subsubsection"],
Cell[421657, 14191, 22, 0, 57, "Text"],
Cell[421682, 14193, 723, 25, 45, "Conclusion",
  CellTags->"19"],
Cell[422408, 14220, 38, 0, 57, "Text"],
Cell[422449, 14222, 727, 25, 45, "Assumption",
  CellTags->" +0:"],
Cell[423179, 14249, 1320, 42, 48, "Assumption",
  CellTags->" + .:"],
Cell[424502, 14293, 349, 18, 57, "Text"],
Cell[424854, 14313, 32, 0, 57, "Text"],
Cell[424889, 14315, 178, 8, 36, "Conclusion",
  CellTags->"20"],
Cell[425070, 14325, 202, 10, 57, "Text"],
Cell[425275, 14337, 47, 0, 57, "Text"],
Cell[425325, 14339, 267, 14, 57, "Text"],
Cell[425595, 14355, 112, 5, 57, "Text"],
Cell[425710, 14362, 47, 0, 57, "Text"],
Cell[425760, 14364, 112, 5, 57, "Text"],
Cell[425875, 14371, 31, 0, 57, "Text"],
Cell[425909, 14373, 75, 3, 57, "Text"],
Cell[425987, 14378, 446, 16, 36, "Assumption",
  CellTags->"21"],
Cell[426436, 14396, 75, 3, 57, "Text"],
Cell[426514, 14401, 531, 19, 36, "Conclusion",
  CellTags->"22"],
Cell[427048, 14422, 202, 10, 57, "Text"],
Cell[427253, 14434, 47, 0, 57, "Text"],
Cell[427303, 14436, 435, 19, 57, "Text"],
Cell[427741, 14457, 468, 20, 57, "Text"],
Cell[428212, 14479, 245, 9, 57, "Text"],
Cell[428460, 14490, 47, 0, 57, "Text"],
Cell[428510, 14492, 245, 9, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[428792, 14506, 135, 4, 90, "Subsubsection"],
Cell[428930, 14512, 22, 0, 57, "Text"],
Cell[428955, 14514, 1166, 38, 48, "Conclusion",
  CellTags->" + = "],
Cell[430124, 14554, 38, 0, 57, "Text"],
Cell[430165, 14556, 723, 25, 45, "Assumption",
  CellTags->"19"],
Cell[430891, 14583, 727, 25, 45, "Assumption",
  CellTags->" +0:"],
Cell[431621, 14610, 1320, 42, 48, "Assumption",
  CellTags->" + .:"],
Cell[432944, 14654, 129, 3, 57, "Text"],
Cell[433076, 14659, 43, 0, 57, "Text"],
Cell[433122, 14661, 258, 11, 57, "Text"],
Cell[433383, 14674, 43, 0, 57, "Text"],
Cell[433429, 14676, 362, 18, 57, "Text"],
Cell[433794, 14696, 32, 0, 57, "Text"],
Cell[433829, 14698, 764, 26, 45, "Conclusion",
  CellTags->"20"],
Cell[434596, 14726, 129, 3, 57, "Text"],
Cell[434728, 14731, 43, 0, 57, "Text"],
Cell[434774, 14733, 222, 10, 57, "Text"],
Cell[434999, 14745, 490, 18, 36, "Conclusion",
  CellTags->"23"],
Cell[435492, 14765, 202, 10, 57, "Text"],
Cell[435697, 14777, 47, 0, 57, "Text"],
Cell[435747, 14779, 391, 18, 57, "Text"],
Cell[436141, 14799, 209, 8, 57, "Text"],
Cell[436353, 14809, 47, 0, 57, "Text"],
Cell[436403, 14811, 395, 18, 57, "Text"],
Cell[436801, 14831, 209, 8, 57, "Text"],
Cell[437013, 14841, 44, 0, 57, "Text"],
Cell[437060, 14843, 208, 10, 77, "Text"],
Cell[437271, 14855, 31, 0, 57, "Text"],
Cell[437305, 14857, 75, 3, 57, "Text"],
Cell[437383, 14862, 1033, 33, 45, "Assumption",
  CellTags->"21"],
Cell[438419, 14897, 75, 3, 57, "Text"],
Cell[438497, 14902, 1128, 36, 45, "Conclusion",
  CellTags->"22"],
Cell[439628, 14940, 129, 3, 57, "Text"],
Cell[439760, 14945, 43, 0, 57, "Text"],
Cell[439806, 14947, 212, 10, 57, "Text"],
Cell[440021, 14959, 807, 27, 36, "Conclusion",
  CellTags->"24"],
Cell[440831, 14988, 32, 0, 57, "Text"],
Cell[440866, 14990, 47, 0, 57, "Text"],
Cell[440916, 14992, 396, 14, 57, "Text"],
Cell[441315, 15008, 47, 0, 57, "Text"],
Cell[441365, 15010, 549, 23, 57, "Text"],
Cell[441917, 15035, 451, 15, 57, "Text"],
Cell[442371, 15052, 49, 0, 57, "Text"],
Cell[442423, 15054, 1194, 38, 45, "Conclusion",
  CellTags->"25"],
Cell[443620, 15094, 356, 18, 57, "Text"],
Cell[443979, 15114, 32, 0, 57, "Text"],
Cell[444014, 15116, 611, 21, 36, "Conclusion",
  CellTags->"26"],
Cell[444628, 15139, 202, 10, 57, "Text"],
Cell[444833, 15151, 47, 0, 57, "Text"],
Cell[444883, 15153, 433, 19, 57, "Text"],
Cell[445319, 15174, 245, 9, 57, "Text"],
Cell[445567, 15185, 47, 0, 57, "Text"],
Cell[445617, 15187, 468, 20, 57, "Text"],
Cell[446088, 15209, 245, 9, 57, "Text"],
Cell[446336, 15220, 31, 0, 57, "Text"],
Cell[446370, 15222, 75, 3, 57, "Text"],
Cell[446448, 15227, 864, 28, 36, "Assumption",
  CellTags->"27"],
Cell[447315, 15257, 75, 3, 57, "Text"],
Cell[447393, 15262, 955, 31, 36, "Conclusion",
  CellTags->"28"],
Cell[448351, 15295, 179, 10, 57, "Text"],
Cell[448533, 15307, 47, 0, 57, "Text"],
Cell[448583, 15309, 587, 24, 57, "Text"],
Cell[449173, 15335, 640, 25, 57, "Text"],
Cell[449816, 15362, 557, 18, 57, "Text"],
Cell[450376, 15382, 47, 0, 57, "Text"],
Cell[450426, 15384, 493, 16, 57, "Text"],
Cell[450922, 15402, 49, 0, 57, "Text"],
Cell[450974, 15404, 1077, 33, 36, "Conclusion",
  CellTags->"29"],
Cell[452054, 15439, 232, 11, 57, "Text"],
Cell[452289, 15452, 43, 0, 57, "Text"],
Cell[452335, 15454, 356, 18, 57, "Text"],
Cell[452694, 15474, 32, 0, 57, "Text"],
Cell[452729, 15476, 570, 20, 36, "Conclusion",
  CellTags->"30"],
Cell[453302, 15498, 202, 10, 57, "Text"],
Cell[453507, 15510, 47, 0, 57, "Text"],
Cell[453557, 15512, 433, 19, 57, "Text"],
Cell[453993, 15533, 245, 9, 57, "Text"],
Cell[454241, 15544, 47, 0, 57, "Text"],
Cell[454291, 15546, 429, 19, 57, "Text"],
Cell[454723, 15567, 245, 9, 57, "Text"],
Cell[454971, 15578, 31, 0, 57, "Text"],
Cell[455005, 15580, 75, 3, 57, "Text"],
Cell[455083, 15585, 807, 27, 36, "Assumption",
  CellTags->"31"],
Cell[455893, 15614, 75, 3, 57, "Text"],
Cell[455971, 15619, 894, 30, 36, "Conclusion",
  CellTags->"32"],
Cell[456868, 15651, 179, 10, 57, "Text"],
Cell[457050, 15663, 47, 0, 57, "Text"],
Cell[457100, 15665, 587, 24, 57, "Text"],
Cell[457690, 15691, 640, 25, 57, "Text"],
Cell[458333, 15718, 646, 25, 57, "Text"],
Cell[458982, 15745, 557, 18, 57, "Text"],
Cell[459542, 15765, 47, 0, 57, "Text"],
Cell[459592, 15767, 587, 24, 57, "Text"],
Cell[460182, 15793, 493, 16, 57, "Text"],
Cell[460678, 15811, 49, 0, 57, "Text"],
Cell[460730, 15813, 1077, 33, 36, "Conclusion",
  CellTags->"33"],
Cell[461810, 15848, 232, 11, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[462079, 15864, 97, 1, 90, "Subsubsection"],
Cell[462179, 15867, 22, 0, 57, "Text"],
Cell[462204, 15869, 1314, 42, 48, "Conclusion",
  CellTags->"34"],
Cell[463521, 15913, 38, 0, 57, "Text"],
Cell[463562, 15915, 723, 25, 45, "Assumption",
  CellTags->"19"],
Cell[464288, 15942, 727, 25, 45, "Assumption",
  CellTags->" +0:"],
Cell[465018, 15969, 1320, 42, 48, "Assumption",
  CellTags->" + .:"],
Cell[466341, 16013, 349, 18, 57, "Text"],
Cell[466693, 16033, 32, 0, 57, "Text"],
Cell[466728, 16035, 863, 29, 45, "Conclusion",
  CellTags->"35"],
Cell[467594, 16066, 212, 10, 57, "Text"],
Cell[467809, 16078, 569, 19, 36, "Conclusion",
  CellTags->"38"],
Cell[468381, 16099, 32, 0, 57, "Text"],
Cell[468416, 16101, 47, 0, 57, "Text"],
Cell[468466, 16103, 249, 9, 57, "Text"],
Cell[468718, 16114, 47, 0, 57, "Text"],
Cell[468768, 16116, 468, 20, 57, "Text"],
Cell[469239, 16138, 245, 9, 57, "Text"],
Cell[469487, 16149, 49, 0, 57, "Text"],
Cell[469539, 16151, 770, 26, 45, "Conclusion",
  CellTags->"39"],
Cell[470312, 16179, 349, 18, 57, "Text"],
Cell[470664, 16199, 32, 0, 57, "Text"],
Cell[470699, 16201, 192, 8, 36, "Conclusion",
  CellTags->"40"],
Cell[470894, 16211, 202, 10, 57, "Text"],
Cell[471099, 16223, 47, 0, 57, "Text"],
Cell[471149, 16225, 274, 14, 57, "Text"],
Cell[471426, 16241, 119, 5, 57, "Text"],
Cell[471548, 16248, 47, 0, 57, "Text"],
Cell[471598, 16250, 119, 5, 57, "Text"],
Cell[471720, 16257, 31, 0, 57, "Text"],
Cell[471754, 16259, 75, 3, 57, "Text"],
Cell[471832, 16264, 489, 17, 36, "Assumption",
  CellTags->"41"],
Cell[472324, 16283, 75, 3, 57, "Text"],
Cell[472402, 16288, 617, 21, 36, "Conclusion",
  CellTags->"42"],
Cell[473022, 16311, 202, 10, 57, "Text"],
Cell[473227, 16323, 47, 0, 57, "Text"],
Cell[473277, 16325, 440, 19, 57, "Text"],
Cell[473720, 16346, 473, 20, 57, "Text"],
Cell[474196, 16368, 322, 11, 57, "Text"],
Cell[474521, 16381, 47, 0, 57, "Text"],
Cell[474571, 16383, 322, 11, 57, "Text"],
Cell[474896, 16396, 31, 0, 57, "Text"],
Cell[474930, 16398, 75, 3, 57, "Text"],
Cell[475008, 16403, 1187, 37, 45, "Assumption",
  CellTags->"36"],
Cell[476198, 16442, 75, 3, 57, "Text"],
Cell[476276, 16447, 1335, 41, 45, "Conclusion",
  CellTags->"37"],
Cell[477614, 16490, 212, 10, 57, "Text"],
Cell[477829, 16502, 993, 31, 36, "Conclusion",
  CellTags->"43"],
Cell[478825, 16535, 32, 0, 57, "Text"],
Cell[478860, 16537, 47, 0, 57, "Text"],
Cell[478910, 16539, 477, 16, 57, "Text"],
Cell[479390, 16557, 47, 0, 57, "Text"],
Cell[479440, 16559, 640, 25, 57, "Text"],
Cell[480083, 16586, 557, 18, 57, "Text"],
Cell[480643, 16606, 49, 0, 57, "Text"],
Cell[480695, 16608, 1406, 42, 45, "Conclusion",
  CellTags->"44"],
Cell[482104, 16652, 349, 18, 57, "Text"],
Cell[482456, 16672, 32, 0, 57, "Text"],
Cell[482491, 16674, 796, 26, 36, "Conclusion",
  CellTags->"45"],
Cell[483290, 16702, 202, 10, 57, "Text"],
Cell[483495, 16714, 47, 0, 57, "Text"],
Cell[483545, 16716, 519, 22, 57, "Text"],
Cell[484067, 16740, 322, 11, 57, "Text"],
Cell[484392, 16753, 47, 0, 57, "Text"],
Cell[484442, 16755, 562, 23, 57, "Text"],
Cell[485007, 16780, 322, 11, 57, "Text"],
Cell[485332, 16793, 31, 0, 57, "Text"],
Cell[485366, 16795, 75, 3, 57, "Text"],
Cell[485444, 16800, 1059, 33, 36, "Assumption",
  CellTags->"46"],
Cell[486506, 16835, 75, 3, 57, "Text"],
Cell[486584, 16840, 1154, 36, 36, "Conclusion",
  CellTags->"47"],
Cell[487741, 16878, 202, 10, 57, "Text"],
Cell[487946, 16890, 47, 0, 57, "Text"],
Cell[487996, 16892, 668, 26, 57, "Text"],
Cell[488667, 16920, 729, 27, 57, "Text"],
Cell[489399, 16949, 670, 20, 57, "Text"],
Cell[490072, 16971, 47, 0, 57, "Text"],
Cell[490122, 16973, 756, 28, 57, "Text"],
Cell[490881, 17003, 670, 20, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[491588, 17028, 106, 2, 90, "Subsubsection"],
Cell[491697, 17032, 22, 0, 57, "Text"],
Cell[491722, 17034, 1166, 38, 48, "Conclusion",
  CellTags->" + = "],
Cell[492891, 17074, 38, 0, 57, "Text"],
Cell[492932, 17076, 1314, 42, 48, "Assumption",
  CellTags->"34"],
Cell[494249, 17120, 723, 25, 45, "Assumption",
  CellTags->"19"],
Cell[494975, 17147, 727, 25, 45, "Assumption",
  CellTags->" +0:"],
Cell[495705, 17174, 1320, 42, 48, "Assumption",
  CellTags->" + .:"],
Cell[497028, 17218, 355, 18, 57, "Text"],
Cell[497386, 17238, 32, 0, 57, "Text"],
Cell[497421, 17240, 764, 26, 45, "Conclusion",
  CellTags->"35"],
Cell[498188, 17268, 222, 10, 57, "Text"],
Cell[498413, 17280, 490, 18, 36, "Conclusion",
  CellTags->"38"],
Cell[498906, 17300, 202, 10, 57, "Text"],
Cell[499111, 17312, 47, 0, 57, "Text"],
Cell[499161, 17314, 391, 18, 57, "Text"],
Cell[499555, 17334, 209, 8, 57, "Text"],
Cell[499767, 17344, 47, 0, 57, "Text"],
Cell[499817, 17346, 395, 18, 57, "Text"],
Cell[500215, 17366, 209, 8, 57, "Text"],
Cell[500427, 17376, 31, 0, 57, "Text"],
Cell[500461, 17378, 75, 3, 57, "Text"],
Cell[500539, 17383, 1033, 33, 45, "Assumption",
  CellTags->"36"],
Cell[501575, 17418, 75, 3, 57, "Text"],
Cell[501653, 17423, 1128, 36, 45, "Conclusion",
  CellTags->"37"],
Cell[502784, 17461, 222, 10, 57, "Text"],
Cell[503009, 17473, 814, 28, 36, "Conclusion",
  CellTags->"39"],
Cell[503826, 17503, 202, 10, 57, "Text"],
Cell[504031, 17515, 47, 0, 57, "Text"],
Cell[504081, 17517, 543, 23, 57, "Text"],
Cell[504627, 17542, 598, 24, 57, "Text"],
Cell[505228, 17568, 451, 15, 57, "Text"],
Cell[505682, 17585, 47, 0, 57, "Text"],
Cell[505732, 17587, 549, 23, 57, "Text"],
Cell[506284, 17612, 451, 15, 57, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[506784, 17633, 73, 1, 103, "Subsection"],

Cell[CellGroupData[{
Cell[506882, 17638, 120, 3, 90, "Subsubsection"],
Cell[507005, 17643, 22, 0, 57, "Text"],
Cell[507030, 17645, 1781, 54, 49, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] "],
Cell[508814, 17701, 38, 0, 57, "Text"],
Cell[508855, 17703, 605, 22, 45, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[509463, 17727, 1396, 44, 48, "Assumption",
  CellTags->" \[RawStar]  ^+"],
Cell[510862, 17773, 598, 21, 45, "Assumption",
  CellTags->"0\[RawStar]"],
Cell[511463, 17796, 1392, 44, 48, "Assumption",
  CellTags->" ^+\[RawStar]"],
Cell[512858, 17842, 725, 25, 45, "Assumption",
  CellTags->" +0"],
Cell[513586, 17869, 1320, 42, 48, "Assumption",
  CellTags->" + ^+"],
Cell[514909, 17913, 725, 25, 45, "Assumption",
  CellTags->"0+ "],
Cell[515637, 17940, 1318, 42, 48, "Assumption",
  CellTags->"^++ "],
Cell[516958, 17984, 1162, 38, 48, "Assumption",
  CellTags->" + "],
Cell[518123, 18024, 1781, 54, 49, "Assumption",
  CellTags->"( + ) + "],
Cell[519907, 18080, 361, 18, 57, "Text"],
Cell[520271, 18100, 32, 0, 57, "Text"],
Cell[520306, 18102, 1350, 42, 49, "Conclusion",
  CellTags->"1"],
Cell[521659, 18146, 220, 10, 57, "Text"],
Cell[521882, 18158, 908, 30, 36, "Conclusion",
  CellTags->"4"],
Cell[522793, 18190, 200, 10, 57, "Text"],
Cell[522996, 18202, 47, 0, 57, "Text"],
Cell[523046, 18204, 581, 24, 57, "Text"],
Cell[523630, 18230, 391, 18, 57, "Text"],
Cell[524024, 18250, 112, 5, 57, "Text"],
Cell[524139, 18257, 47, 0, 57, "Text"],
Cell[524189, 18259, 597, 24, 57, "Text"],
Cell[524789, 18285, 112, 5, 57, "Text"],
Cell[524904, 18292, 31, 0, 57, "Text"],
Cell[524938, 18294, 75, 3, 57, "Text"],
Cell[525016, 18299, 1635, 49, 49, "Assumption",
  CellTags->"2"],
Cell[526654, 18350, 75, 3, 57, "Text"],
Cell[526732, 18355, 1734, 52, 49, "Conclusion",
  CellTags->"3"],
Cell[528469, 18409, 210, 10, 57, "Text"],
Cell[528682, 18421, 1245, 39, 36, "Conclusion",
  CellTags->"5"],
Cell[529930, 18462, 32, 0, 57, "Text"],
Cell[529965, 18464, 47, 0, 57, "Text"],
Cell[530015, 18466, 757, 29, 57, "Text"],
Cell[530775, 18497, 892, 33, 57, "Text"],
Cell[531670, 18532, 743, 24, 57, "Text"],
Cell[532416, 18558, 47, 0, 57, "Text"],
Cell[532466, 18560, 753, 29, 57, "Text"],
Cell[533222, 18591, 1039, 38, 57, "Text"],
Cell[534264, 18631, 1043, 38, 57, "Text"],
Cell[535310, 18671, 894, 29, 57, "Text"],
Cell[536207, 18702, 49, 0, 57, "Text"],
Cell[536259, 18704, 2226, 65, 49, "Conclusion",
  CellTags->"6"],
Cell[538488, 18771, 347, 18, 57, "Text"],
Cell[538838, 18791, 32, 0, 57, "Text"],
Cell[538873, 18793, 1492, 45, 49, "Conclusion",
  CellTags->"7"],
Cell[540368, 18840, 220, 10, 57, "Text"],
Cell[540591, 18852, 1149, 37, 36, "Conclusion",
  CellTags->"10"],
Cell[541743, 18891, 202, 10, 57, "Text"],
Cell[541948, 18903, 47, 0, 57, "Text"],
Cell[541998, 18905, 624, 25, 57, "Text"],
Cell[542625, 18932, 401, 18, 57, "Text"],
Cell[543029, 18952, 391, 18, 57, "Text"],
Cell[543423, 18972, 112, 5, 57, "Text"],
Cell[543538, 18979, 47, 0, 57, "Text"],
Cell[543588, 18981, 783, 30, 57, "Text"],
Cell[544374, 19013, 579, 24, 57, "Text"],
Cell[544956, 19039, 428, 19, 57, "Text"],
Cell[545387, 19060, 265, 14, 57, "Text"],
Cell[545655, 19076, 112, 5, 57, "Text"],
Cell[545770, 19083, 31, 0, 57, "Text"],
Cell[545804, 19085, 75, 3, 57, "Text"],
Cell[545882, 19090, 2109, 60, 49, "Assumption",
  CellTags->"8"],
Cell[547994, 19152, 75, 3, 57, "Text"],
Cell[548072, 19157, 2310, 65, 49, "Conclusion",
  CellTags->"9"],
Cell[550385, 19224, 347, 18, 57, "Text"],
Cell[550735, 19244, 32, 0, 57, "Text"],
Cell[550770, 19246, 1510, 46, 36, "Conclusion",
  CellTags->"17"],
Cell[552283, 19294, 202, 10, 57, "Text"],
Cell[552488, 19306, 47, 0, 57, "Text"],
Cell[552538, 19308, 869, 32, 57, "Text"],
Cell[553410, 19342, 112, 5, 57, "Text"],
Cell[553525, 19349, 47, 0, 57, "Text"],
Cell[553575, 19351, 884, 33, 57, "Text"],
Cell[554462, 19386, 872, 33, 57, "Text"],
Cell[555337, 19421, 681, 27, 57, "Text"],
Cell[556021, 19450, 430, 19, 57, "Text"],
Cell[556454, 19471, 265, 14, 57, "Text"],
Cell[556722, 19487, 112, 5, 57, "Text"],
Cell[556837, 19494, 31, 0, 57, "Text"],
Cell[556871, 19496, 75, 3, 57, "Text"],
Cell[556949, 19501, 1880, 56, 36, "Assumption",
  CellTags->"18"],
Cell[558832, 19559, 75, 3, 57, "Text"],
Cell[558910, 19564, 2011, 60, 36, "Conclusion",
  CellTags->"19"],
Cell[560924, 19626, 202, 10, 57, "Text"],
Cell[561129, 19638, 47, 0, 57, "Text"],
Cell[561179, 19640, 1022, 36, 57, "Text"],
Cell[562204, 19678, 1632, 53, 57, "Text"],
Cell[563839, 19733, 1882, 59, 57, "Text"],
Cell[565724, 19794, 2043, 63, 57, "Text"],
Cell[567770, 19859, 2245, 68, 57, "Text"],
Cell[570018, 19929, 2451, 73, 57, "Text"],
Cell[572472, 20004, 2488, 74, 57, "Text"],
Cell[574963, 20080, 2705, 75, 57, "Text"],
Cell[577671, 20157, 2705, 75, 57, "Text"],
Cell[580379, 20234, 2705, 75, 57, "Text"],
Cell[583087, 20311, 2705, 75, 57, "Text"],
Cell[585795, 20388, 2715, 75, 57, "Text"],
Cell[588513, 20465, 2555, 65, 57, "Text"],
Cell[591071, 20532, 47, 0, 57, "Text"],
Cell[591121, 20534, 1213, 42, 57, "Text"],
Cell[592337, 20578, 1445, 48, 57, "Text"],
Cell[593785, 20628, 1882, 59, 57, "Text"],
Cell[595670, 20689, 2043, 63, 57, "Text"],
Cell[597716, 20754, 2245, 68, 57, "Text"],
Cell[599964, 20824, 2453, 73, 57, "Text"],
Cell[602420, 20899, 2481, 73, 57, "Text"],
Cell[604904, 20974, 2705, 75, 57, "Text"],
Cell[607612, 21051, 2705, 75, 57, "Text"],
Cell[610320, 21128, 2705, 75, 57, "Text"],
Cell[613028, 21205, 2705, 75, 57, "Text"],
Cell[615736, 21282, 2705, 75, 57, "Text"],
Cell[618444, 21359, 2715, 75, 57, "Text"],
Cell[621162, 21436, 2704, 74, 57, "Text"],
Cell[623869, 21512, 2727, 75, 57, "Text"],
Cell[626599, 21589, 2704, 74, 57, "Text"],
Cell[629306, 21665, 2555, 65, 57, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[631898, 21735, 103, 2, 90, "Subsubsection"],
Cell[632004, 21739, 22, 0, 57, "Text"],
Cell[632029, 21741, 1781, 54, 49, "Conclusion",
  CellTags->"( \[RawStar] ) \[RawStar] "],
Cell[633813, 21797, 38, 0, 57, "Text"],
Cell[633854, 21799, 605, 22, 45, "Assumption",
  CellTags->" \[RawStar]0"],
Cell[634462, 21823, 1396, 44, 48, "Assumption",
  CellTags->" \[RawStar]  ^+"],
Cell[635861, 21869, 598, 21, 45, "Assumption",
  CellTags->"0\[RawStar]"],
Cell[636462, 21892, 1392, 44, 48, "Assumption",
  CellTags->" ^+\[RawStar]"],
Cell[637857, 21938, 725, 25, 45, "Assumption",
  CellTags->" +0"],
Cell[638585, 21965, 1320, 42, 48, "Assumption",
  CellTags->" + ^+"],
Cell[639908, 22009, 725, 25, 45, "Assumption",
  CellTags->"0+ "],
Cell[640636, 22036, 1318, 42, 48, "Assumption",
  CellTags->"^++ "],
Cell[641957, 22080, 361, 18, 57, "Text"],
Cell[642321, 22100, 32, 0, 57, "Text"],
Cell[642356, 22102, 1350, 42, 49, "Conclusion",
  CellTags->"1"],
Cell[643709, 22146, 220, 10, 57, "Text"],
Cell[643932, 22158, 908, 30, 36, "Conclusion",
  CellTags->"4"],
Cell[644843, 22190, 200, 10, 57, "Text"],
Cell[645046, 22202, 47, 0, 57, "Text"],
Cell[645096, 22204, 581, 24, 57, "Text"],
Cell[645680, 22230, 391, 18, 57, "Text"],
Cell[646074, 22250, 112, 5, 57, "Text"],
Cell[646189, 22257, 47, 0, 57, "Text"],
Cell[646239, 22259, 597, 24, 57, "Text"],
Cell[646839, 22285, 112, 5, 57, "Text"],
Cell[646954, 22292, 31, 0, 57, "Text"],
Cell[646988, 22294, 75, 3, 57, "Text"],
Cell[647066, 22299, 1635, 49, 49, "Assumption",
  CellTags->"2"],
Cell[648704, 22350, 75, 3, 57, "Text"],
Cell[648782, 22355, 1734, 52, 49, "Conclusion",
  CellTags->"3"],
Cell[650519, 22409, 210, 10, 57, "Text"],
Cell[650732, 22421, 1245, 39, 36, "Conclusion",
  CellTags->"5"],
Cell[651980, 22462, 32, 0, 57, "Text"],
Cell[652015, 22464, 47, 0, 57, "Text"],
Cell[652065, 22466, 757, 29, 57, "Text"],
Cell[652825, 22497, 914, 33, 57, "Text"],
Cell[653742, 22532, 743, 24, 57, "Text"],
Cell[654488, 22558, 47, 0, 57, "Text"],
Cell[654538, 22560, 753, 29, 57, "Text"],
Cell[655294, 22591, 1039, 38, 57, "Text"],
Cell[656336, 22631, 1065, 38, 57, "Text"],
Cell[657404, 22671, 894, 29, 57, "Text"],
Cell[658301, 22702, 49, 0, 57, "Text"],
Cell[658353, 22704, 2226, 65, 49, "Conclusion",
  CellTags->"6"],
Cell[660582, 22771, 347, 18, 57, "Text"],
Cell[660932, 22791, 32, 0, 57, "Text"],
Cell[660967, 22793, 1492, 45, 49, "Conclusion",
  CellTags->"7"],
Cell[662462, 22840, 220, 10, 57, "Text"],
Cell[662685, 22852, 1149, 37, 36, "Conclusion",
  CellTags->"10"],
Cell[663837, 22891, 202, 10, 57, "Text"],
Cell[664042, 22903, 47, 0, 57, "Text"],
Cell[664092, 22905, 624, 25, 57, "Text"],
Cell[664719, 22932, 401, 18, 57, "Text"],
Cell[665123, 22952, 391, 18, 57, "Text"],
Cell[665517, 22972, 112, 5, 57, "Text"],
Cell[665632, 22979, 47, 0, 57, "Text"],
Cell[665682, 22981, 783, 30, 57, "Text"],
Cell[666468, 23013, 579, 24, 57, "Text"],
Cell[667050, 23039, 428, 19, 57, "Text"],
Cell[667481, 23060, 265, 14, 57, "Text"],
Cell[667749, 23076, 112, 5, 57, "Text"],
Cell[667864, 23083, 31, 0, 57, "Text"],
Cell[667898, 23085, 75, 3, 57, "Text"],
Cell[667976, 23090, 2109, 60, 49, "Assumption",
  CellTags->"8"],
Cell[670088, 23152, 75, 3, 57, "Text"],
Cell[670166, 23157, 2310, 65, 49, "Conclusion",
  CellTags->"9"],
Cell[672479, 23224, 210, 10, 57, "Text"],
Cell[672692, 23236, 1880, 56, 36, "Conclusion",
  CellTags->"11"],
Cell[674575, 23294, 32, 0, 57, "Text"],
Cell[674610, 23296, 47, 0, 57, "Text"],
Cell[674660, 23298, 998, 35, 57, "Text"],
Cell[675661, 23335, 984, 35, 57, "Text"],
Cell[676648, 23372, 1204, 40, 57, "Text"],
Cell[677855, 23414, 1188, 40, 57, "Text"],
Cell[679046, 23456, 1234, 40, 57, "Text"],
Cell[680283, 23498, 1216, 40, 57, "Text"],
Cell[681502, 23540, 1357, 44, 57, "Text"],
Cell[682862, 23586, 1186, 35, 57, "Text"],
Cell[684051, 23623, 47, 0, 57, "Text"],
Cell[684101, 23625, 1147, 40, 57, "Text"],
Cell[685251, 23667, 1133, 40, 57, "Text"],
Cell[686387, 23709, 1292, 44, 57, "Text"],
Cell[687682, 23755, 1274, 44, 57, "Text"],
Cell[688959, 23801, 1480, 49, 57, "Text"],
Cell[690442, 23852, 1373, 40, 57, "Text"],
Cell[691818, 23894, 49, 0, 57, "Text"],
Cell[691870, 23896, 3167, 84, 49, "Conclusion",
  CellTags->"12"],
Cell[695040, 23982, 349, 18, 57, "Text"],
Cell[695392, 24002, 32, 0, 57, "Text"],
Cell[695427, 24004, 2031, 57, 36, "Conclusion",
  CellTags->"13"],
Cell[697461, 24063, 202, 10, 57, "Text"],
Cell[697666, 24075, 47, 0, 57, "Text"],
Cell[697716, 24077, 1104, 37, 57, "Text"],
Cell[698823, 24116, 116, 5, 57, "Text"],
Cell[698942, 24123, 47, 0, 57, "Text"],
Cell[698992, 24125, 1137, 38, 57, "Text"],
Cell[700132, 24165, 966, 33, 57, "Text"],
Cell[701101, 24200, 295, 14, 57, "Text"],
Cell[701399, 24216, 275, 14, 57, "Text"],
Cell[701677, 24232, 116, 5, 57, "Text"],
Cell[701796, 24239, 31, 0, 57, "Text"],
Cell[701830, 24241, 75, 3, 57, "Text"],
Cell[701908, 24246, 2668, 74, 36, "Assumption",
  CellTags->"14"],
Cell[704579, 24322, 75, 3, 57, "Text"],
Cell[704657, 24327, 2889, 80, 36, "Conclusion",
  CellTags->"15"],
Cell[707549, 24409, 202, 10, 57, "Text"],
Cell[707754, 24421, 47, 0, 57, "Text"],
Cell[707804, 24423, 1433, 46, 57, "Text"],
Cell[709240, 24471, 1419, 46, 57, "Text"],
Cell[710662, 24519, 2390, 68, 57, "Text"],
Cell[713055, 24589, 2573, 69, 57, "Text"],
Cell[715631, 24660, 2841, 71, 57, "Text"],
Cell[718475, 24733, 2791, 71, 57, "Text"],
Cell[721269, 24806, 3055, 75, 57, "Text"],
Cell[724327, 24883, 2918, 66, 57, "Text"],
Cell[727248, 24951, 47, 0, 57, "Text"],
Cell[727298, 24953, 1668, 52, 57, "Text"],
Cell[728969, 25007, 1634, 52, 57, "Text"],
Cell[730606, 25061, 1834, 57, 57, "Text"],
Cell[732443, 25120, 1868, 57, 57, "Text"],
Cell[734314, 25179, 2605, 73, 57, "Text"],
Cell[736922, 25254, 2808, 74, 57, "Text"],
Cell[739733, 25330, 3089, 75, 57, "Text"],
Cell[742825, 25407, 2918, 66, 57, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[745792, 25479, 90, 1, 103, "Subsection"],

Cell[CellGroupData[{
Cell[745907, 25484, 137, 4, 90, "Subsubsection"],
Cell[746047, 25490, 22, 0, 57, "Text"],
Cell[746072, 25492, 8137, 194, 113, "Conclusion",
  CellTags->""],
Cell[754212, 25688, 36, 0, 57, "Text"],
Cell[754251, 25690, 23, 0, 57, "Text"],
Cell[754277, 25692, 382, 8, 185, "Text"],
Cell[754662, 25702, 43, 0, 57, "Text"],
Cell[754708, 25704, 3676, 96, 49, "Conclusion",
  CellTags->".1"],
Cell[758387, 25802, 5234, 134, 82, "Conclusion",
  CellTags->".2"],
Cell[763624, 25938, 70, 0, 57, "Text"],
Cell[763697, 25940, 176, 10, 57, "Text"],
Cell[763876, 25952, 63, 0, 57, "Text"],
Cell[763942, 25954, 334, 10, 49, "Conclusion",
  CellTags->".1.structure"],
Cell[764279, 25966, 21, 0, 57, "Text"],
Cell[764303, 25968, 2890, 82, 116, "Text"],
Cell[767196, 26052, 197, 9, 57, "Text"],
Cell[767396, 26063, 309, 9, 49, "Conclusion",
  CellTags->".1.implication"],
Cell[767708, 26074, 201, 9, 57, "Text"],
Cell[767912, 26085, 329, 10, 52, "Conclusion",
  CellTags->".1.not-exists"],
Cell[768244, 26097, 52, 0, 57, "Text"],
Cell[768299, 26099, 23, 0, 57, "Text"],
Cell[768325, 26101, 225, 9, 57, "Text"],
Cell[768553, 26112, 375, 11, 52, "Conclusion",
  CellTags->".1.not-exists-slack"],
Cell[768931, 26125, 262, 5, 121, "Text"],
Cell[769196, 26132, 91, 1, 49, "Text"],
Cell[769290, 26135, 130, 4, 121, "Text"],
Cell[769423, 26141, 199, 3, 50, "Text"],
Cell[769625, 26146, 35, 0, 57, "Text"],
Cell[769663, 26148, 51, 1, 49, "Text"],
Cell[769717, 26151, 190, 11, 57, "Text"],
Cell[769910, 26164, 176, 10, 57, "Text"],
Cell[770089, 26176, 63, 0, 57, "Text"],
Cell[770155, 26178, 358, 10, 49, "Conclusion",
  CellTags->".2.structure"],
Cell[770516, 26190, 21, 0, 57, "Text"],
Cell[770540, 26192, 4193, 119, 150, "Text"],
Cell[774736, 26313, 197, 9, 57, "Text"],
Cell[774936, 26324, 352, 10, 49, "Conclusion",
  CellTags->".2.implication"],
Cell[775291, 26336, 201, 9, 57, "Text"],
Cell[775495, 26347, 391, 11, 52, "Conclusion",
  CellTags->".2.not-exists"],
Cell[775889, 26360, 52, 0, 57, "Text"],
Cell[775944, 26362, 32, 0, 57, "Text"],
Cell[775979, 26364, 225, 9, 57, "Text"],
Cell[776207, 26375, 423, 11, 52, "Conclusion",
  CellTags->".2.not-exists-slack"],
Cell[776633, 26388, 262, 5, 121, "Text"],
Cell[776898, 26395, 138, 3, 49, "Text"],
Cell[777039, 26400, 130, 4, 121, "Text"],
Cell[777172, 26406, 316, 5, 81, "Text"],
Cell[777491, 26413, 35, 0, 57, "Text"],
Cell[777529, 26415, 51, 1, 49, "Text"],
Cell[777583, 26418, 190, 11, 57, "Text"],
Cell[777776, 26431, 109, 3, 57, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

